@@ -19,13 +19,13 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DateEdit.py 12560 2009-05-21 17:58:31Z gbritton $
+# $Id: DateEdit.py 16467 2011-01-25 12:43:09Z bmcage $
 
 """
 Date editing module for GRAMPS. 
 
 The DateEdit.DateEdit provides visual feedback to the user via a pixamp
-to indicate if the assocated GtkEntry box contains a valid date. Green
+to indicate if the associated GtkEntry box contains a valid date. Green
 means complete and regular date. Yellow means a valid, but not a regular date.
 Red means that the date is not valid, and will be viewed as a text string
 instead of a date.
@@ -55,20 +55,20 @@ __LOG = logging.getLogger(".DateEdit")
 #
 #-------------------------------------------------------------------------
 import gtk
-from gtk import glade
 
 #-------------------------------------------------------------------------
 #
 # gramps modules
 #
 #-------------------------------------------------------------------------
-from TransUtils import sgettext as _
-from gen.lib import Date
+from gen.ggettext import sgettext as _
+from gen.lib.date import Date, NextYear
 import DateHandler
 import const
 import GrampsDisplay
 import ManagedWindow
 from Errors import ValidationError
+from glade import Glade
 
 #-------------------------------------------------------------------------
 #
@@ -90,8 +90,8 @@ QUAL_TEXT = (
     (Date.QUAL_CALCULATED, _('Calculated')) )
 
 CAL_TO_MONTHS_NAMES = { 
-    Date.CAL_GREGORIAN  : DateHandler.displayer.MONS,
-    Date.CAL_JULIAN     : DateHandler.displayer.MONS,
+    Date.CAL_GREGORIAN  : DateHandler.displayer.short_months,
+    Date.CAL_JULIAN     : DateHandler.displayer.short_months,
     Date.CAL_HEBREW     : DateHandler.displayer.hebrew,
     Date.CAL_FRENCH     : DateHandler.displayer.french,
     Date.CAL_PERSIAN    : DateHandler.displayer.persian,
@@ -100,6 +100,7 @@ CAL_TO_MONTHS_NAMES = {
 
 WIKI_HELP_PAGE = '%s_-_Entering_and_Editing_Data:_Detailed_-_part_1' % const.URL_MANUAL_PAGE
 WIKI_HELP_SEC = _('manual|Editing_Dates')
+
 #-------------------------------------------------------------------------
 #
 # DateEdit
@@ -149,6 +150,9 @@ class DateEdit(object):
         # if text could not be parsed it is assumed invalid
         if self.date_obj.get_modifier() == Date.MOD_TEXTONLY:
             return ValidationError(_('Bad Date'))
+        elif (self.date_obj.to_calendar(calendar_name=Date.CAL_GREGORIAN) >
+              NextYear()):
+            return ValidationError(_('Date more than one year in the future'))
 
     def invoke_date_editor(self, obj):
         """
@@ -190,36 +194,36 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
         
         # Create self.date as a copy of the given Date object.
         self.date = Date(date)
-
-        self.top = glade.XML(const.GLADE_FILE, "date_edit","gramps" )
+        
+        self.top = Glade()
 
         self.set_window(
-            self.top.get_widget('date_edit'),
-            self.top.get_widget('title'),
+            self.top.toplevel,
+            self.top.get_object('title'),
             _('Date selection'))            
             
-        self.calendar_box = self.top.get_widget('calendar_box')
+        self.calendar_box = self.top.get_object('calendar_box')
         for name in Date.ui_calendar_names:
-            self.calendar_box.append_text(name)
+            self.calendar_box.get_model().append([name])
 
         self.calendar_box.set_active(self.date.get_calendar())
         self.calendar_box.connect('changed', self.switch_calendar)
 
-        self.quality_box = self.top.get_widget('quality_box')
+        self.quality_box = self.top.get_object('quality_box')
         for item_number in range(len(QUAL_TEXT)):
             self.quality_box.append_text(QUAL_TEXT[item_number][1])
             if self.date.get_quality() == QUAL_TEXT[item_number][0]:
                 self.quality_box.set_active(item_number)
 
-        self.type_box = self.top.get_widget('type_box')
+        self.type_box = self.top.get_object('type_box')
         for item_number in range(len(MOD_TEXT)):
             self.type_box.append_text(MOD_TEXT[item_number][1])
             if self.date.get_modifier() == MOD_TEXT[item_number][0]:
                 self.type_box.set_active(item_number)
         self.type_box.connect('changed', self.switch_type)
 
-        self.start_month_box = self.top.get_widget('start_month_box')
-        self.stop_month_box = self.top.get_widget('stop_month_box')
+        self.start_month_box = self.top.get_object('start_month_box')
+        self.stop_month_box = self.top.get_object('stop_month_box')
         month_names = CAL_TO_MONTHS_NAMES[self.date.get_calendar()]
         for name in month_names:
             self.start_month_box.append_text(name)
@@ -227,18 +231,18 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
         self.start_month_box.set_active(self.date.get_month())
         self.stop_month_box.set_active(self.date.get_stop_month())
         
-        self.start_day = self.top.get_widget('start_day')
+        self.start_day = self.top.get_object('start_day')
         self.start_day.set_value(self.date.get_day())
-        self.start_year = self.top.get_widget('start_year')
+        self.start_year = self.top.get_object('start_year')
         self.start_year.set_value(self.date.get_year())
 
-        self.stop_day = self.top.get_widget('stop_day')
+        self.stop_day = self.top.get_object('stop_day')
         self.stop_day.set_value(self.date.get_stop_day())
-        self.stop_year = self.top.get_widget('stop_year')
+        self.stop_year = self.top.get_object('stop_year')
         self.stop_year.set_value(self.date.get_stop_year())
         
-        self.dual_dated = self.top.get_widget('dualdated')
-        self.new_year = self.top.get_widget('newyear')
+        self.dual_dated = self.top.get_object('dualdated')
+        self.new_year = self.top.get_object('newyear')
         self.new_year.set_active(self.date.get_new_year())
 
         # Disable second date controls if not compound date
@@ -257,7 +261,7 @@ class DateEditorDialog(ManagedWindow.ManagedWindow):
             self.dual_dated.set_sensitive(0)
             self.new_year.set_sensitive(0)
 
-        self.text_entry = self.top.get_widget('date_text_entry')
+        self.text_entry = self.top.get_object('date_text_entry')
         self.text_entry.set_text(self.date.get_text())
 
         if self.date.get_slash():
