@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _DateParser.py 12560 2009-05-21 17:58:31Z gbritton $
+# $Id: _DateParser.py 16640 2011-02-17 08:28:35Z ldnp $
 
 """
 Date parsing class. Serves as the base class for any localized
@@ -96,18 +96,20 @@ def julian_valid(date_tuple):
 
 def swedish_valid(date_tuple):
     """ Checks if date_tuple is a valid date in Swedish Calendar """
-    valid = gregorian_valid(date_tuple)
-    # not sure how <= and >= works with tuples???
+    valid_J = julian_valid(date_tuple)
     date_tuple = (date_tuple[2], date_tuple[1], date_tuple[0])
-    if date_tuple <= (1700, 2, 28):
-        valid = False 
-    if date_tuple == (1700, 2, 29):  # leapday 1700 was skipped
-        valid = False 
-    if date_tuple == (1712, 2, 30):  # extra day was inserted 1712
-        valid = True 
-    if date_tuple >= (1712, 3, 1):   # back to julian
-        valid = False
-    return valid
+    # Swedish calendar starts as Julian 1700-03-01 and ends 1712-03-01 as Julian
+    if date_tuple >= (1700, 2, 29) and  date_tuple < (1712, 3, 1):
+        if date_tuple == (1712, 2, 30):  # extra day was inserted 1712, not valid Julian
+            return True
+        if valid_J:
+            if date_tuple == (1700, 2, 29):  # leapday 1700 was skipped
+                return False
+            return True
+        else:
+            return False
+    else:
+        return False
 
 def french_valid(date_tuple):
     """ Checks if date_tuple is a valid date in French Calendar """
@@ -154,11 +156,17 @@ class DateParser(object):
     modifier_after_to_int = {}
 
     hebrew_to_int = {
-        "tishri"  : 1,   "heshvan" : 2,   "kislev"  : 3,
-        "tevet"   : 4,   "shevat"  : 5,   "adari"   : 6,
-        "adarii"  : 7,   "nisan"   : 8,   "iyyar"   : 9,
-        "sivan"   : 10,  "tammuz"  : 11,  "av"      : 12,
-        "elul"    : 13,
+        u"tishri"  : 1,   u"heshvan" : 2,   u"kislev"  : 3,
+        u"tevet"   : 4,   u"shevat"  : 5,   u"adari"   : 6,
+        u"adarii"  : 7,   u"nisan"   : 8,   u"iyyar"   : 9,
+        u"sivan"   : 10,  u"tammuz"  : 11,  u"av"      : 12,
+        u"elul"    : 13,
+        #alternative spelling
+        u"cheshvan": 2,   u"adar sheni":  7, u"iyar"    : 9,
+        #GEDCOM months
+        u"tsh" : 1, u"csh": 5, u"ksl": 3, u"tvt": 4, u"shv": 5, u"adr": 6, 
+        u"ads" : 7, u"nsn": 8, u"iyr": 9, u"svn":10, u"tmz":11, u"aav":12,
+        u"ell":13,
         }
 
     french_to_int = {
@@ -168,7 +176,15 @@ class DateParser(object):
         u'germinal'     : 7,    u'floréal' : 8,
         u'prairial'     : 9,    u'messidor'   : 10,
         u'thermidor'    : 11,   u'fructidor'  : 12,
-        u'extra'        : 13
+        u'extra'        : 13,
+        #GEDCOM months
+        u'vend'    : 1,    u'brum' : 2,
+        u'frim'    : 3,    u'nivo' : 4,
+        u'pluv'    : 5,    u'vent' : 6,
+        u'germ'    : 7,    u'flor' : 8,
+        u'prai'    : 9,    u'mess' : 10,
+        u'ther'    : 11,   u'fruc' : 12,
+        u'comp'    : 13,
         }
 
     islamic_to_int = {
@@ -202,7 +218,7 @@ class DateParser(object):
         "januari"    :  1, "februari"   :  2,
         "mars"       :  3, "april"      :  4,
         "maj"        :  5, "juni"       :  6,
-        "juli"       :  7, "augisti"    :  8,
+        "juli"       :  7, "augusti"    :  8,
         "september"  :  9, "oktober"    : 10,
         "november"   : 11, "december"   : 12,
         }
@@ -430,7 +446,6 @@ class DateParser(object):
                 m = 0
             else:
                 m = mmap[groups[1].lower()]
-
             d = self._get_int(groups[0])
 
             if groups[2] is None:
@@ -586,11 +601,15 @@ class DateParser(object):
             text_parser = self.parser[cal]
             (text1, bc1) = self.match_bce(match.group('start'))
             start = self._parse_subdate(text1, text_parser)
+            if start == Date.EMPTY and text1 != "":
+                return 0
             if bc1:
                 start = self.invert_year(start)
 
             (text2, bc2) = self.match_bce(match.group('stop'))
             stop = self._parse_subdate(text2, text_parser)
+            if stop == Date.EMPTY and text2 != "":
+                return 0
             if bc2:
                 stop = self.invert_year(stop)
 
@@ -609,11 +628,15 @@ class DateParser(object):
             text_parser = self.parser[cal]
             (text1, bc1) = self.match_bce(match.group('start'))
             start = self._parse_subdate(text1, text_parser)
+            if start == Date.EMPTY and text1 != "":
+                return 0
             if bc1:
                 start = self.invert_year(start)
 
             (text2, bc2) = self.match_bce(match.group('stop'))
             stop = self._parse_subdate(text2, text_parser)
+            if stop == Date.EMPTY and text2 != "":
+                return 0
             if bc2:
                 stop = self.invert_year(stop)
             
@@ -666,7 +689,10 @@ class DateParser(object):
                 start = self._parse_subdate(grps[0], self.parser[cal])
                 mod = self.modifier_after_to_int.get(grps[1].lower(),
                                                      Date.MOD_NONE)
-                if bc:
+                if start == Date.EMPTY:
+                    date.set_modifier(Date.MOD_TEXTONLY)
+                    date.set_text_value(text)
+                elif bc:
                     date.set(qual, mod, cal, self.invert_year(start), newyear=ny)
                 else:
                     date.set(qual, mod, cal, start, newyear=ny)
@@ -676,7 +702,10 @@ class DateParser(object):
             grps = match.groups()
             start = self._parse_subdate(grps[0])
             mod = Date.MOD_ABOUT
-            if bc:
+            if start == Date.EMPTY:
+                date.set_modifier(Date.MOD_TEXTONLY)
+                date.set_text_value(text)
+            elif bc:
                 date.set(qual, mod, cal, self.invert_year(start), newyear=ny)
             else:
                 date.set(qual, mod, cal, start, newyear=ny)
@@ -712,6 +741,8 @@ class DateParser(object):
             if subdate == Date.EMPTY and text != "":
                 date.set_as_text(text)
                 return
+            #else:
+            #    print 'valid subdate', text, subdate
         except:
             date.set_as_text(text)
             return
