@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Date_fr.py 12708 2009-06-25 18:11:37Z romjerome $
+# $Id: _Date_fr.py 15091 2010-04-12 08:38:30Z romjerome $
 
 #-------------------------------------------------------------------------
 #
@@ -50,12 +50,23 @@ from _DateHandler import register_datehandler
 # French parser
 #
 #-------------------------------------------------------------------------
-
-
 class DateParserFR(DateParser):
+    """
+    Convert a text string into a Date object. If the date cannot be
+    converted, the text string is assigned.
+    """
 
     month_to_int = DateParser.month_to_int
 
+    # Custom short months not the same as long months
+
+    month_to_int[u"janv"] = 1
+    month_to_int[u"févr"] = 2
+    month_to_int[u"juil"] = 7
+    month_to_int[u"sept"] = 9
+    month_to_int[u"oct"] = 10
+    month_to_int[u"déc"] = 12
+
     # Add common value
 
     month_to_int[u"bluviose"] = 5
@@ -174,6 +185,16 @@ class DateParserFR(DateParser):
            u"avant J.C"] + DateParser.bce
 
     def init_strings(self):
+        """
+        This method compiles regular expression strings for matching dates.
+        
+        Most of the re's in most languages can stay as is. span and range
+        most likely will need to change. Whatever change is done, this method
+        may be called first as DateParser.init_strings(self) so that the
+        invariant expresions don't need to be repeteadly coded. All differences
+        can be coded after DateParser.init_strings(self) call, that way they
+        override stuff from this method. See DateParserRU() as an example.
+        """
         DateParser.init_strings(self)
 
         # This self._numeric is different from the base
@@ -186,7 +207,8 @@ class DateParserFR(DateParser):
                                  re.IGNORECASE)
 
     # This self._text are different from the base
-        # by adding ".?" after the first date and removing "\s*$" at the end
+    # by adding ".?" after the first date and removing "\s*$" at the end
+
     #gregorian and julian
 
         self._text2 = re.compile('(\d+)?.?\s+?%s\s*((\d+)(/\d+)?)?' %
@@ -217,18 +239,24 @@ class DateParserFR(DateParser):
         self._stext2 = re.compile('(\d+)?.?\s+?%s\s*((\d+)(/\d+)?)?' %
                                   self._smon_str, re.IGNORECASE)
 
-
 #-------------------------------------------------------------------------
 #
 # French display
 #
 #-------------------------------------------------------------------------
-
-
 class DateDisplayFR(DateDisplay):
+    """
+    French language date display class. 
+    """
+    long_months = ( u"", u"janvier", u"février", u"mars", u"avril", u"mai", 
+                    u"juin", u"juillet", u"août", u"septembre", u"octobre", 
+                    u"novembre", u"décembre" )
+    
+    short_months = ( u"", u"janv", u"févr", u"mars", u"avril", u"mai", u"juin", 
+                     u"juil", u"août", u"sept", u"oct", u"nov", u"déc" )
 
-    calendar = ("", u" (Julien)", u" (Hébreu)", u" (Révolutionnaire)",
-                u" (Perse)", u" (Islamique)", u" (Suédois)")
+    calendar = ("", u"Julien", u"Hébreu", u"Révolutionnaire",
+                u"Perse", u"Islamique", u"Suédois")
 
     _mod_str = ("", u"avant ", u"après ", u"vers ", "", "", "")
 
@@ -237,9 +265,13 @@ class DateDisplayFR(DateDisplay):
     _bce_str = u"%s avant le calendrier"
 
     formats = ("AAAA-MM-JJ (ISO)", "Numérique", "Mois Jour, Année",
-               "MOI Jour, Année", "Jour. Mois Année", "Jour. MOI Année")
+               "MOI Jour, Année", "Jour. Mois Année", "Jour. MOI Année",
+               "Jour Mois Année", "Jour MOI Année")
 
     def _display_gregorian(self, date_val):
+        """
+        display gregorian calendar date in different format
+        """
         year = self._slash_year(date_val[2], date_val[3])
         if self.format == 0:
             return self.display_iso(date_val)
@@ -253,8 +285,8 @@ class DateDisplayFR(DateDisplay):
                     value = self._tformat.replace('%m', str(date_val[1]))
                     value = value.replace('%d', str(date_val[0]))
 
-            # base_display :
-            # value = value.replace('%Y', str(abs(date_val[2])))
+                    # base_display :
+                    # value = value.replace('%Y', str(abs(date_val[2])))
                     # value = value.replace('-', '/')
 
                     value = value.replace('%Y', str(date_val[2]))
@@ -266,10 +298,10 @@ class DateDisplayFR(DateDisplay):
                 if date_val[1] == 0:
                     value = year
                 else:
-                    value = "%s %s" % ((self._months)[date_val[1]], year)
+                    value = "%s %s" % (self.long_months[date_val[1]], year)
             else:
-                value = "%s %d, %s" % ((self._months)[date_val[1]],
-                        date_val[0], year)
+                value = "%s %d, %s" % (self.long_months[date_val[1]],
+                                       date_val[0], year)
         elif self.format == 3:
 
             # MON Day, Year
@@ -278,10 +310,10 @@ class DateDisplayFR(DateDisplay):
                 if date_val[1] == 0:
                     value = year
                 else:
-                    value = "%s %s" % ((self.MONS)[date_val[1]], year)
+                    value = "%s %s" % (self.short_months[date_val[1]], year)
             else:
-                value = "%s %d, %s" % ((self.MONS)[date_val[1]],
-                        date_val[0], year)
+                value = "%s %d, %s" % (self.short_months[date_val[1]],
+                                       date_val[0], year)
         elif self.format == 4:
 
             # Day. Month Year
@@ -290,15 +322,17 @@ class DateDisplayFR(DateDisplay):
                 if date_val[1] == 0:
                     value = year
                 else:
-                    value = "%s %s" % ((self._months)[date_val[1]], year)
+                    value = "%s %s" % (self.long_months[date_val[1]], year)
             else:
 
-        # base_display :
-        # value = "%d %s %s" % (date_val[0], self._months[date_val[1]], year)
+                # base_display :
+                # value = "%d %s %s" % (date_val[0], 
+                #                       self.long_months[date_val[1]], year)
 
-                value = "%d. %s %s" % (date_val[0], (self._months)[date_val[1]],
+                value = "%d. %s %s" % (date_val[0], 
+                                       self.long_months[date_val[1]],
                         year)
-        else:
+        elif self.format == 5:
 
             # Day. MON Year
 
@@ -306,14 +340,43 @@ class DateDisplayFR(DateDisplay):
                 if date_val[1] == 0:
                     value = year
                 else:
-                    value = "%s %s" % ((self.MONS)[date_val[1]], year)
+                    value = "%s %s" % (self.short_months[date_val[1]], year)
             else:
 
-        # base_display :
-        # value = "%d %s %s" % (date_val[0], self.MONS[date_val[1]], year)
+                # base_display :
+                # value = "%d %s %s" % (date_val[0], 
+                #                       self.short_months[date_val[1]], year)
 
-                value = "%d. %s %s" % (date_val[0], (self.MONS)[date_val[1]],
-                        year)
+                value = "%d. %s %s" % (date_val[0], 
+                                      self.short_months[date_val[1]], year)
+
+        elif self.format == 6:
+
+            # Day Month Year
+
+            if date_val[0] == 0:
+                if date_val[1] == 0:
+                    value = year
+                else:
+                    value = "%s %s" % (self.long_months[date_val[1]], year)
+            else:
+
+                value = "%d %s %s" % (date_val[0], 
+                                      self.long_months[date_val[1]], year)
+        else:
+
+            # Day MON Year
+
+            if date_val[0] == 0:
+                if date_val[1] == 0:
+                    value = year
+                else:
+                    value = "%s %s" % (self.short_months[date_val[1]], year)
+            else:
+
+                value = "%d %s %s" % (date_val[0], 
+                                      self.short_months[date_val[1]], year)
+                        
         if date_val[2] < 0:
             return self._bce_str % value
         else:
@@ -328,6 +391,7 @@ class DateDisplayFR(DateDisplay):
         cal = date.get_calendar()
         qual = date.get_quality()
         start = date.get_start_date()
+        newyear = date.get_new_year()
 
         qual_str = (self._qual_str)[qual]
 
@@ -336,18 +400,22 @@ class DateDisplayFR(DateDisplay):
         elif start == Date.EMPTY:
             return ""
         elif mod == Date.MOD_SPAN:
-            d1 = (self.display_cal)[cal](start)
-            d2 = (self.display_cal)[cal](date.get_stop_date())
-            return "%s%s %s %s %s%s" % (qual_str, u'de', d1, u'à', d2, (self.calendar)[cal])
+            date1 = self.display_cal[cal](start)
+            date2 = self.display_cal[cal](date.get_stop_date())
+            scal = self.format_extras(cal, newyear)
+            return "%s%s %s %s %s%s" % (qual_str, u'de', date1, u'à', 
+            date2, scal)
         elif mod == Date.MOD_RANGE:
-            d1 = (self.display_cal)[cal](start)
-            d2 = (self.display_cal)[cal](date.get_stop_date())
-            return "%s%s %s %s %s%s" % (qual_str, u'entre', d1, u'et',
-                    d2, (self.calendar)[cal])
+            date1 = self.display_cal[cal](start)
+            date2 = self.display_cal[cal](date.get_stop_date())
+            scal = self.format_extras(cal, newyear)
+            return "%s%s %s %s %s%s" % (qual_str, u'entre', date1, u'et',
+                    date2, scal)
         else:
-            text = (self.display_cal)[date.get_calendar()](start)
-            return "%s%s%s%s" % (qual_str, (self._mod_str)[mod], text, (self.calendar)[cal])
-
+            text = self.display_cal[date.get_calendar()](start)
+            scal = self.format_extras(cal, newyear)
+            return "%s%s%s%s" % (qual_str, (self._mod_str)[mod], text, 
+            scal)
 
 #-------------------------------------------------------------------------
 #
