@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Date_nb.py 11676 2009-01-20 15:38:29Z ldnp $
+# $Id: _Date_nb.py 15091 2010-04-12 08:38:30Z romjerome $
 
 """
 Norwegian-specific classes for parsing and displaying dates.
@@ -106,6 +106,13 @@ class DateDisplayNb(DateDisplay):
     Norwegian language date display class. 
     """
 
+    long_months = ( u"", u"januar", u"februar", u"mars", u"april", u"mai", 
+                    u"juni", u"juli", u"august", u"september", u"oktober", 
+                    u"november", u"desember" )
+    
+    short_months = ( u"", u"jan", u"feb", u"mar", u"apr", u"mai", u"jun", 
+                     u"jul", u"aug", u"sep", u"okt", u"nov", u"des" )
+
     formats = (
         u"ÅÅÅÅ-MM-DD (ISO)", 
         u"Numerisk", 
@@ -117,12 +124,12 @@ class DateDisplayNb(DateDisplay):
 
     calendar = (
         "", 
-        " (juliansk)", 
-        " (hebraisk)", 
-        " (fransk republikansk)", 
-        " (persisk)", 
-        " (islamisk)", 
-        " (svensk)" 
+        "juliansk", 
+        "hebraisk", 
+        "fransk republikansk", 
+        "persisk", 
+        "islamisk", 
+        "svensk" 
         )
     
     _mod_str = ("", u"før ", u"etter ", u"ca ", "", "", "")
@@ -139,6 +146,7 @@ class DateDisplayNb(DateDisplay):
         cal = date.get_calendar()
         qual = date.get_quality()
         start = date.get_start_date()
+        newyear = date.get_new_year()
 
         qual_str = self._qual_str[qual]
 
@@ -149,16 +157,19 @@ class DateDisplayNb(DateDisplay):
         elif mod == Date.MOD_SPAN:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return u"%sfra %s til %s%s" % (qual_str, d1, d2, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return u"%sfra %s til %s%s" % (qual_str, d1, d2, scal)
         elif mod == Date.MOD_RANGE:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
+            scal = self.format_extras(cal, newyear)
             return u"%smellom %s og %s%s" % (qual_str, d1, d2, 
-                                              self.calendar[cal])
+                                              scal)
         else:
             text = self.display_cal[date.get_calendar()](start)
+            scal = self.format_extras(cal, newyear)
             return u"%s%s%s%s" % (qual_str, self._mod_str[mod], 
-                                 text, self.calendar[cal])
+                                 text, scal)
 
 #-------------------------------------------------------------------------
 #
