@@ -21,7 +21,7 @@
 # Portuguese version translated by Duarte Loreto <happyguy_pt@hotmail.com>, 2007.
 # Based on the Spanish file.
 
-# $Id: _Date_pt.py 11676 2009-01-20 15:38:29Z ldnp $
+# $Id: _Date_pt.py 15091 2010-04-12 08:38:30Z romjerome $
 
 """
 Portuguese-specific classes for parsing and displaying dates.
@@ -52,20 +52,26 @@ from _DateHandler import register_datehandler
 class DateParserPT(DateParser):
 
     modifier_to_int = {
-        u'antes de'   : Date.MOD_BEFORE, 
-        u'antes'      : Date.MOD_BEFORE, 
-        u'ant.'       : Date.MOD_BEFORE, 
-        u'ant'        : Date.MOD_BEFORE, 
-        u'após'       : Date.MOD_AFTER,
-        u'aprox.'     : Date.MOD_ABOUT,
-        u'aprox'      : Date.MOD_ABOUT,
-        u'apr.'       : Date.MOD_ABOUT,
-        u'apr'        : Date.MOD_ABOUT,
-        u'cerca de'   : Date.MOD_ABOUT,
-        u'ca.'        : Date.MOD_ABOUT,
-        u'ca'         : Date.MOD_ABOUT,
-        u'c.'         : Date.MOD_ABOUT,
-        u'até'       : Date.MOD_ABOUT,
+        u'antes de'     : Date.MOD_BEFORE, 
+        u'antes'        : Date.MOD_BEFORE, 
+        u'ant.'         : Date.MOD_BEFORE, 
+        u'ant'          : Date.MOD_BEFORE, 
+        u'até'          : Date.MOD_BEFORE,
+        u'depois de'    : Date.MOD_AFTER,
+        u'depois'       : Date.MOD_AFTER,
+        u'dep.'         : Date.MOD_AFTER,
+        u'dep'          : Date.MOD_AFTER,
+        u'aprox.'       : Date.MOD_ABOUT,
+        u'aprox'        : Date.MOD_ABOUT,
+        u'apr.'         : Date.MOD_ABOUT,
+        u'apr'          : Date.MOD_ABOUT,
+        u'cerca de'     : Date.MOD_ABOUT,
+        u'ca.'          : Date.MOD_ABOUT,
+        u'ca'           : Date.MOD_ABOUT,
+        u'c.'           : Date.MOD_ABOUT,
+        u'por volta de' : Date.MOD_ABOUT,
+        u'por volta'    : Date.MOD_ABOUT,
+        u'pvd.'         : Date.MOD_ABOUT,
         }
 
     calendar_to_int = {
@@ -113,14 +119,23 @@ class DateParserPT(DateParser):
 #
 #-------------------------------------------------------------------------
 class DateDisplayPT(DateDisplay):
-
+    """
+    Portuguese language date display class. 
+    """
+    long_months = ( u"", u"Janeiro", u"Fevereiro", u"Março", u"Abril", u"Maio", 
+                    u"Junho", u"Julho", u"Agosto", u"Setembro", u"Outubro", 
+                    u"Novembro", u"Dezembro" )
+    
+    short_months = ( u"", u"Jan", u"Fev", u"Mar", u"Abr", u"Mai", u"Jun", 
+                     u"Jul", u"Ago", u"Set", u"Out", u"Nov", u"Dez" )
+    
     calendar = (
-        "", u" (Juliano)", u" (Hebreu)", 
-        u" (Revolucionário)", u" (Persa)", u" (Islâmico)", 
-        u" (Swedish)" 
+        "", u"Juliano", u"Hebreu", 
+        u"Revolucionário", u"Persa", u"Islâmico", 
+        u"Sueco" 
         )
 
-    _mod_str = ("",u"antes de ",u"depois de ",u"até ","","","")
+    _mod_str = ("",u"antes de ",u"depois de ",u"por volta de ","","","")
 
     _qual_str = ("","estimado ","calculado ")
 
@@ -137,6 +152,7 @@ class DateDisplayPT(DateDisplay):
         cal = date.get_calendar()
         qual = date.get_quality()
         start = date.get_start_date()
+        newyear = date.get_new_year()
 
         qual_str = self._qual_str[qual]
         
@@ -147,14 +163,17 @@ class DateDisplayPT(DateDisplay):
         elif mod == Date.MOD_SPAN:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return "%s%s %s %s %s%s" % (qual_str, u'de', d1, u'a', d2,self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%s%s %s %s %s%s" % (qual_str, u'de', d1, u'a', d2, scal)
         elif mod == Date.MOD_RANGE:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
-            return "%s%s %s %s %s%s" % (qual_str, u'entre', d1, u'e', d2, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%s%s %s %s %s%s" % (qual_str, u'entre', d1, u'e', d2, scal)
         else:
             text = self.display_cal[date.get_calendar()](start)
-            return "%s%s%s%s" % (qual_str, self._mod_str[mod], text, self.calendar[cal])
+            scal = self.format_extras(cal, newyear)
+            return "%s%s%s%s" % (qual_str, self._mod_str[mod], text, scal)
 
 #-------------------------------------------------------------------------
 #
