@@ -184,15 +184,24 @@ class DateParserRU(DateParser):
 #
 #-------------------------------------------------------------------------
 class DateDisplayRU(DateDisplay):
-
+    """
+    Russian language date display class. 
+    """
+    long_months = ( u"", u"января", u"февраля", u"марта", u"апреля", u"мая", 
+                    u"июня", u"июля", u"августа", u"сентября", u"октября", 
+                    u"ноября", u"декабря" )
+    
+    short_months = ( u"", u"янв", u"фев", u"мар", u"апр", u"мая", u"июн", 
+                     u"июл", u"авг", u"сен", u"окт", u"ноя", u"дек" )
+    
     calendar = (
         u"", 
-        u" (юлианский)", 
-        u" (еврейский)", 
-        u" (республиканский)", 
-        u" (персидский)", 
-        u" (исламский)", 
-        u" (Swedish)" 
+        u"юлианский", 
+        u"еврейский", 
+        u"республиканский", 
+        u"персидский", 
+        u"исламский", 
+        u"шведский" 
         )
 
     _mod_str = (
@@ -212,65 +221,65 @@ class DateDisplayRU(DateDisplay):
         )
 
     hebrew = ( u"", 
-        u"Тишрей", 
-        u"Хешван", 
-        u"Кислев", 
-        u"Тевет", 
-        u"Шеват", 
-        u"Адар", 
-        u"Адар бет", 
-        u"Нисан", 
-        u"Ияр", 
-        u"Сиван", 
-        u"Таммуз", 
-        u"Ав", 
-        u"Элул", 
+        u"тишрея", 
+        u"хешвана", 
+        u"кислева", 
+        u"тевета", 
+        u"шевата", 
+        u"адара", 
+        u"адар бета", 
+        u"нисана", 
+        u"ияра", 
+        u"сивана", 
+        u"таммуза", 
+        u"ава", 
+        u"элула", 
         )
 
     islamic = ( u"", 
-        u"Мухаррам", 
-        u"Сафар", 
-        u"Раби-аль-авваль", 
-        u"Раби-ассани", 
-        u"Джумада-аль-уля", 
-        u"Джумада-аль-ахира", 
-        u"Раджаб", 
-        u"Шаабан", 
-        u"Рамадан", 
-        u"Шавваль", 
-        u"Зуль-каада", 
-        u"Зуль-хиджжа", 
+        u"мухаррама", 
+        u"сафара", 
+        u"раби-аль-авваля", 
+        u"раби-ассани", 
+        u"джумада-аль-уля", 
+        u"джумада-аль-ахира", 
+        u"раджаба", 
+        u"шаабана", 
+        u"рамадана", 
+        u"шаввальа", 
+        u"зуль-каада", 
+        u"зуль-хиджжа", 
         )
 
     persian = ( u"", 
-        u"Фарвардин", 
-        u"Урдбихишт", 
-        u"Хурдад", 
-        u"Тир", 
-        u"Мурдад", 
-        u"Шахривар", 
-        u"Михр", 
-        u"Абан", 
-        u"Азар", 
-        u"Дай", 
-        u"Бахман", 
-        u"Исфаидармуз", 
+        u"фарвардина", 
+        u"урдбихишта", 
+        u"хурдада", 
+        u"тира", 
+        u"мурдада", 
+        u"шахривара", 
+        u"михра", 
+        u"абана", 
+        u"азара", 
+        u"дайа", 
+        u"бахмана", 
+        u"исфаидармуза", 
         )
 
     french = ( u"", 
-        u"Вандемьер", 
-        u"Брюмер", 
-        u"Фример", 
-        u"Нивоз", 
-        u"Плювиоз", 
-        u"Вантоз", 
-        u"Жерминаль", 
-        u"Флореаль", 
-        u"Прериаль", 
-        u"Мессидор", 
-        u"Термидор", 
-        u"Фрюктидор", 
-        u"Дополнит."
+        u"вандемьера", 
+        u"брюмера", 
+        u"фримера", 
+        u"нивоза", 
+        u"плювиоза", 
+        u"вантоза", 
+        u"жерминаля", 
+        u"флореаля", 
+        u"прериаля", 
+        u"мессидора", 
+        u"термидора", 
+        u"фрюктидора", 
+        u"дополнит."
         )
 
     def display(self, date):
@@ -281,6 +290,7 @@ class DateDisplayRU(DateDisplay):
         cal = date.get_calendar()
         qual = date.get_quality()
         start = date.get_start_date()
+        newyear = date.get_new_year()
 
         qual_str = self._qual_str[qual]
         
@@ -291,17 +301,20 @@ class DateDisplayRU(DateDisplay):
         elif mod == Date.MOD_SPAN:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
+            scal = self.format_extras(cal, newyear)
             return "%sс %s %s %s%s" % (qual_str, d1, u'по', d2, 
-                                       self.calendar[cal])
+                                       scal)
         elif mod == Date.MOD_RANGE:
             d1 = self.display_cal[cal](start)
             d2 = self.display_cal[cal](date.get_stop_date())
+            scal = self.format_extras(cal, newyear)
             return "%s%s %s %s %s%s" % (qual_str, u'между', d1, u'и', 
-                                        d2, self.calendar[cal])
+                                        d2, scal)
         else:
             text = self.display_cal[date.get_calendar()](start)
+            scal = self.format_extras(cal, newyear)
             return "%s%s%s%s" % (qual_str, self._mod_str[mod], 
-                                 text, self.calendar[cal])
+                                 text, scal)
 
 #-------------------------------------------------------------------------
 #
