@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DisplayState.py 14580 2010-03-02 15:48:05Z nick-h $
+# $Id: DisplayState.py 15858 2010-09-06 15:18:28Z ldnp $
 
 #-------------------------------------------------------------------------
 #
@@ -307,19 +307,30 @@ class WarnHandler(RotateHandler):
         self.button = button
         button.on_clicked(self.display)
         self.timer = None
+        self.last_line = '-1'
 
     def emit(self, record):
-        if self.timer:
-            gobject.source_remove(self.timer)
-        gobject.timeout_add(180*1000, self._clear)
+        if self.timer is None:
+            #check every 3 minutes if warn button can disappear
+            self.timer = gobject.timeout_add(3*60*1000, self._check_clear)
         RotateHandler.emit(self, record)
         self.button.show()
 
+    def _check_clear(self):
+        new_last_line = self.get_buffer()[-1]
+        if self.last_line == new_last_line:
+            #buffer has not changed for 3 minutes, let's clear it:
+            self._clear()
+            return False
+        else:
+            self.last_line = new_last_line
+            return True
+
     def _clear(self):
         self.button.hide()
         self.set_capacity(self._capacity)
+        self.last_line = '-1'
         self.timer = None
-        return False
 
     def display(self, obj):
         obj.hide()
@@ -329,7 +340,6 @@ class WarnHandler(RotateHandler):
         buf = msg.get_buffer()
         for i in self.get_formatted_log():
             buf.insert_at_cursor(i + '\n')
-        self.set_capacity(self._capacity)
         top.run()
         top.destroy()
 
@@ -413,7 +423,7 @@ class DisplayState(gen.utils.Callback):
         navigation type and group.
         """
         history = self.get_history(nav_type, nav_group)
-        return history.present()
+        return history.present() if history else None
 
     def set_active(self, handle, nav_type, nav_group=0):
         """
@@ -421,7 +431,8 @@ class DisplayState(gen.utils.Callback):
         the given handle.
         """
         history = self.get_history(nav_type, nav_group)
-        history.push(handle)
+        if history:
+            history.push(handle)
 
     def set_sensitive(self, state):
         self.window.set_sensitive(state)
