@@ -3,6 +3,7 @@
 #
 # Copyright (C) 2004-2007 Donald N. Allingham
 # Copyright (C) 2008      Brian G. Matherly
+# Copyright (C) 2008      Benny Malengier
 # Contribution  2009 by   Brad Crittenden <brad [AT] bradcrittenden.net>
 #
 # This program is free software; you can redistribute it and/or modify
@@ -92,6 +93,7 @@ class ExportAssistant(gtk.Assistant, ManagedWindow.ManagedWindow) :
     
     """
 
+    #override predefined do_xxx signal handlers
     __gsignals__ = {"apply": "override", "cancel": "override",
                     "close": "override", "prepare": "override"}
                     
@@ -164,6 +166,22 @@ class ExportAssistant(gtk.Assistant, ManagedWindow.ManagedWindow) :
         if isinstance(arg, gtk.Button) and arg.get_label() == 'gtk-go-forward':
             self.forward_button = arg
 
+    def get_cancel_button(self, arg):
+        if isinstance(arg, gtk.HBox):
+            arg.forall(self._cancel_btn)
+
+    def _cancel_btn(self, arg):
+        if isinstance(arg, gtk.Button) and arg.get_label() == 'gtk-cancel':
+            self.cancel_button = arg
+
+    def get_close_button(self, arg):
+        if isinstance(arg, gtk.HBox):
+            arg.forall(self._close_btn)
+
+    def _close_btn(self, arg):
+        if isinstance(arg, gtk.Button) and arg.get_label() == 'gtk-close':
+            self.close_button = arg
+
     def build_menu_names(self, obj):
         """Override ManagedWindow method."""
         return (self.top_title, None)
@@ -382,22 +400,18 @@ class ExportAssistant(gtk.Assistant, ManagedWindow.ManagedWindow) :
         self.set_page_complete(page, False)
         self.set_page_type(page, gtk.ASSISTANT_PAGE_SUMMARY)
 
-        
     def do_apply(self):
         pass
 
-    def do_cancel(self):
-        if self.writestarted :
-            return True
-        else : 
-            self.close()
-
     def do_close(self):
         if self.writestarted :
-            return True
-        else : 
+            pass
+        else :
             self.close()
 
+    def do_cancel(self):
+        self.do_close()
+
     def do_prepare(self, page):
         """
         The "prepare" signal is emitted when a new page is set as the 
@@ -462,7 +476,7 @@ class ExportAssistant(gtk.Assistant, ManagedWindow.ManagedWindow) :
                 #Allow for exotic error: file is still not correct
                 self.check_fileselect(self.chooser, show=False)
                 if self.get_page_complete(self.chooser) :
-                    filename = Utils.get_unicode_path(self.chooser.get_filename())
+                    filename = Utils.get_unicode_path_from_file_chooser(self.chooser.get_filename())
                     name = os.path.split(filename)[1]
                     folder = os.path.split(filename)[0]
                     confirm_text = _(
@@ -536,7 +550,7 @@ class ExportAssistant(gtk.Assistant, ManagedWindow.ManagedWindow) :
         
     def close(self, *obj) :
         #clean up ManagedWindow menu, then destroy window, bring forward parent
-        
+        gtk.Assistant.destroy(self)
         ManagedWindow.ManagedWindow.close(self,*obj)
 
     def get_intro_text(self):
@@ -596,7 +610,7 @@ class ExportAssistant(gtk.Assistant, ManagedWindow.ManagedWindow) :
             hasattr(self.option_box_instance, "no_fileselect")):
             filename = ""
         else:
-            filename = Utils.get_unicode_path(self.chooser.get_filename())
+            filename = Utils.get_unicode_path_from_file_chooser(self.chooser.get_filename())
             config.set('paths.recent-export-dir', os.path.split(filename)[0])
         ix = self.get_selected_format_index()
         config.set('behavior.recent-export-type', ix)
