@@ -3,7 +3,7 @@
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -18,9 +18,9 @@ from Filters.Rules._ChangedSinceBase import ChangedSinceBase
 #
 #-------------------------------------------------------------------------
 class ChangedSince(ChangedSinceBase):
-    """Rule that checks for an event changed after a specific time."""
+    """Rule that checks for an event changed since a specific time."""
 
     name        = _('Events changed after <date time>')
     description = _("Matches event records changed after a specified "
                     "date/time (yyyy-mm-dd hh:mm:ss) or in the range, if a second "
-                    "date/time is given")
+                    "date/time is given.")
