@@ -3,7 +3,7 @@
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -23,4 +23,4 @@ class ChangedSince(ChangedSinceBase):
     name        = _('Media objects changed after <date time>')
     description = _("Matches media objects changed after a specified "
                     "date:time (yyyy-mm-dd hh:mm:ss) or in the range, if a second "
-                    "date:time is given")
+                    "date:time is given.")
