@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _RegExpIdOf.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _RegExpIdOf.py 14091 2010-01-18 04:42:17Z pez4brian $
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -46,5 +46,5 @@ class RegExpIdOf(RegExpIdBase):
     """
 
     name        = _('Media Objects with <Id> matching regular expression')
-    description = _("Matches media objects whose GRAMPS ID matches "
+    description = _("Matches media objects whose Gramps ID matches "
                     "the regular expression")
