@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HaveAltFamilies.py 9912 2008-01-22 09:17:46Z acraphae $
+# $Id: _HaveAltFamilies.py 15368 2010-05-09 13:42:33Z dsblank $
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -48,9 +48,10 @@ class HaveAltFamilies(Rule):
     def apply(self,db,person):
         for fhandle in person.get_parent_family_handle_list():
             family = db.get_family_from_handle(fhandle)
-            ref = [ ref for ref in family.get_child_ref_list() \
-                    if ref.ref == person.handle]
-            if ref[0].get_father_relation() == ChildRefType.ADOPTED \
-                   or ref[0].get_mother_relation() == ChildRefType.ADOPTED:
-                return True
+            if family:
+                ref = [ ref for ref in family.get_child_ref_list() \
+                        if ref.ref == person.handle]
+                if ref[0].get_father_relation() == ChildRefType.ADOPTED \
+                       or ref[0].get_mother_relation() == ChildRefType.ADOPTED:
+                    return True
         return False
