@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _HaveChildren.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: _HaveChildren.py 15375 2010-05-09 15:19:07Z dsblank $
 
 #-------------------------------------------------------------------------
 #
@@ -47,4 +47,4 @@ class HaveChildren(Rule):
     def apply(self,db,person):
         for family_handle in person.get_family_handle_list():
             family = db.get_family_from_handle(family_handle)
-            return len(family.get_child_ref_list()) > 0
+            return (family is not None) and len(family.get_child_ref_list()) > 0
