@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _IsAncestorOfFilterMatch.py 10874 2008-07-17 18:10:32Z gbritton $
+# $Id: _IsAncestorOfFilterMatch.py 15856 2010-09-03 22:56:33Z bmcage $
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -40,7 +40,7 @@ from _MatchesFilter import MatchesFilter
 # IsAncestorOfFilterMatch
 #
 #-------------------------------------------------------------------------
-class IsAncestorOfFilterMatch(IsAncestorOf,MatchesFilter):
+class IsAncestorOfFilterMatch(IsAncestorOf):
     """Rule that checks for a person that is an ancestor of
     someone matched by a filter"""
 
@@ -56,7 +56,7 @@ class IsAncestorOfFilterMatch(IsAncestorOf,MatchesFilter):
     
     def prepare(self,db):
         self.db = db
-        self.map = {}
+        self.map = set()
         try:
             if int(self.list[1]):
                 first = 0
@@ -66,15 +66,14 @@ class IsAncestorOfFilterMatch(IsAncestorOf,MatchesFilter):
             first = 1
             
         filt = MatchesFilter(self.list[0:1])
-        filt.prepare(db)
-        for person_handle in db.get_person_handles(sort_handles=False):
-            person = db.get_person_from_handle( person_handle)
-            if filt.apply (db, person):
-                self.init_ancestor_list (db,person,first)
-        filt.reset()
+        filt.requestprepare(db)
+        for person in db.iter_people():
+            if filt.apply(db, person):
+                self.init_ancestor_list(db, person, first)
+        filt.requestreset()
 
     def reset(self):
-        self.map = {}
+        self.map.clear()
 
     def apply(self,db,person):
         return person.handle in self.map
