@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _IsMoreThanNthGenerationDescendantOf.py 10874 2008-07-17 18:10:32Z gbritton $
+# $Id: _IsMoreThanNthGenerationDescendantOf.py 15368 2010-05-09 13:42:33Z dsblank $
 
 #-------------------------------------------------------------------------
 #
 # Standard Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -50,29 +50,30 @@ class IsMoreThanNthGenerationDescendantOf(Rule):
                  "person at least N generations away")
     
     
-    def prepare(self,db):
+    def prepare(self ,db):
         self.db = db
-        self.map = {}
+        self.map = set()
         try:
             root_person = db.get_person_from_gramps_id(self.list[0])
-            self.init_list(root_person,0)
+            self.init_list(root_person, 0)
         except:
             pass
 
     def reset(self):
-        self.map = {}
+        self.map.clear()
 
     def apply(self,db,person):
         return person.handle in self.map
 
-    def init_list(self,person,gen):
+    def init_list(self, person, gen):
         if not person:
             return
         if gen >= int(self.list[1]):
-            self.map[person.handle] = 1
+            self.map.add(person.handle)
 
         for fam_id in person.get_family_handle_list():
             fam = self.db.get_family_from_handle(fam_id)
-            for child_ref in fam.get_child_ref_list():
-                self.init_list(
-                    self.db.get_person_from_handle(child_ref.ref),gen+1)
+            if fam:
+                for child_ref in fam.get_child_ref_list():
+                    self.init_list(
+                        self.db.get_person_from_handle(child_ref.ref), gen+1)
