@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _IsParentOfFilterMatch.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: _IsParentOfFilterMatch.py 15856 2010-09-03 22:56:33Z bmcage $
 
 #-------------------------------------------------------------------------
 #
@@ -32,6 +32,7 @@ from gen.ggettext import gettext as _
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
+from Filters.Rules import Rule
 from _MatchesFilter import MatchesFilter
 
 #-------------------------------------------------------------------------
@@ -39,7 +40,7 @@ from _MatchesFilter import MatchesFilter
 # IsParentOfFilterMatch
 #
 #-------------------------------------------------------------------------
-class IsParentOfFilterMatch(MatchesFilter):
+class IsParentOfFilterMatch(Rule):
     """Rule that checks for a person that is a parent
     of someone matched by a filter"""
 
@@ -52,11 +53,11 @@ class IsParentOfFilterMatch(MatchesFilter):
         self.db = db
         self.map = set()
         filt = MatchesFilter(self.list)
-        filt.prepare(db)
+        filt.requestprepare(db)
         for person in db.iter_people():
             if filt.apply(db, person):
                 self.init_list(person)
-        filt.reset()
+        filt.requestreset()
 
     def reset(self):
         self.map.clear()
@@ -67,6 +68,9 @@ class IsParentOfFilterMatch(MatchesFilter):
     def init_list(self,person):
         for fam_id in person.get_parent_family_handle_list():
             fam = self.db.get_family_from_handle(fam_id)
-            self.map.update(parent_id
-                for parent_id in [fam.get_father_handle(), fam.get_mother_handle()]
-                    if parent_id)
+            if fam:
+                self.map.update(parent_id
+                                for parent_id in [fam.get_father_handle(), 
+                                                  fam.get_mother_handle()]
+                                if parent_id)
+                
