@@ -25,7 +25,7 @@
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -39,7 +39,7 @@ import gtk
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-import GrampsWidgets
+from gui import widgets
 import gen.lib
 
 from Filters.SideBar import SidebarFilter
@@ -64,11 +64,11 @@ class EventSidebarFilter(SidebarFilter):
         self.filter_event.set_type((gen.lib.EventType.CUSTOM, u''))
         self.etype = gtk.ComboBoxEntry()
        
-        self.event_menu = GrampsWidgets.MonitoredDataType(
+        self.event_menu = widgets.MonitoredDataType(
             self.etype,
             self.filter_event.set_type,
             self.filter_event.get_type)
-
+        
         self.filter_date = gtk.Entry()
         self.filter_place = gtk.Entry()
         self.filter_note = gtk.Entry()
@@ -77,7 +77,7 @@ class EventSidebarFilter(SidebarFilter):
 
         self.generic = gtk.ComboBox()
 
-        SidebarFilter.__init__(self, dbstate, uistate)
+        SidebarFilter.__init__(self, dbstate, uistate, "Event")
 
     def create_widget(self):
         cell = gtk.CellRendererText()
@@ -93,7 +93,7 @@ class EventSidebarFilter(SidebarFilter):
         self.add_text_entry(_('Date'), self.filter_date)
         self.add_text_entry(_('Place'), self.filter_place)
         self.add_text_entry(_('Note'), self.filter_note)
-        self.add_entry(_('Custom filter'), self.generic)
+        self.add_filter_entry(_('Custom filter'), self.generic)
         self.add_entry(None, self.filter_regex)
 
     def clear(self, obj):
