@@ -18,14 +18,14 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _NoteSidebarFilter.py 10694 2008-05-08 19:40:56Z zfoldvar $
+# $Id: _NoteSidebarFilter.py 14248 2010-02-06 16:08:10Z dsblank $
 
 #-------------------------------------------------------------------------
 #
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -39,7 +39,7 @@ import gtk
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-import widgets
+from gui import widgets
 from gen.lib import Note, NoteType
 
 from Filters.SideBar import SidebarFilter
@@ -71,7 +71,7 @@ class NoteSidebarFilter(SidebarFilter):
 
         self.generic = gtk.ComboBox()
 
-        SidebarFilter.__init__(self, dbstate, uistate)
+        SidebarFilter.__init__(self, dbstate, uistate, "Note")
 
     def create_widget(self):
         cell = gtk.CellRendererText()
@@ -84,7 +84,7 @@ class NoteSidebarFilter(SidebarFilter):
         self.add_text_entry(_('ID'), self.filter_id)
         self.add_text_entry(_('Text'), self.filter_text)
         self.add_entry(_('Type'), self.ntype)
-        self.add_entry(_('Custom filter'), self.generic)
+        self.add_filter_entry(_('Custom filter'), self.generic)
         self.add_entry(None, self.filter_regex)
 
     def clear(self, obj):
