@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _FilterList.py 12562 2009-05-22 18:43:40Z gbritton $
+# $Id: _FilterList.py 15939 2010-09-30 10:02:41Z ldnp $
 
 #-------------------------------------------------------------------------
 #
@@ -27,6 +27,7 @@
 #-------------------------------------------------------------------------
 from xml.sax import make_parser, SAXParseException
 import os
+import sys
 
 #-------------------------------------------------------------------------
 #
@@ -84,8 +85,7 @@ class FilterList(object):
         return l.replace('"', '&quot;')
 
     def save(self):
-        f = open(self.file.encode('utf-8'), 'w')
-        
+        f = open(self.file.encode(sys.getfilesystemencoding()), 'w')
         f.write("<?xml version=\"1.0\" encoding=\"utf-8\"?>\n")
         f.write('<filters>\n')
         for namespace in self.filter_namespaces:
