@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: GrampsAboutDialog.py 12069 2009-02-22 10:06:32Z jcreus $
+# $Id: GrampsAboutDialog.py 15440 2010-05-21 14:16:13Z ldnp $
 
 "About dialog"
 
@@ -27,7 +27,10 @@
 # Python modules
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
+import os
+import sys
+import bsddb
 
 ##import logging
 ##_LOG = logging.getLogger(".GrampsAboutDialog")
@@ -37,7 +40,6 @@ try:
 except ImportError:
     from _xmlplus.sax import make_parser, handler, SAXParseException
 
-
 #-------------------------------------------------------------------------
 #
 # Gtk modules
@@ -76,7 +78,7 @@ class GrampsAboutDialog(gtk.AboutDialog):
         self.set_version(const.VERSION)
         self.set_copyright(const.COPYRIGHT_MSG)
         self.set_artists([
-            _("Much of GRAMPS' artwork is either from\n"
+            _("Much of Gramps' artwork is either from\n"
               "the Tango Project or derived from the Tango\n"
               "Project. This artwork is released under the\n"
               "Creative Commons Attribution-ShareAlike 2.5\n"
@@ -90,8 +92,8 @@ class GrampsAboutDialog(gtk.AboutDialog):
         except IOError:
             self.set_license("License file is missing")
 
-        self.set_comments(_(const.COMMENTS))
-        self.set_website_label(_('GRAMPS Homepage'))
+        self.set_comments(_(const.COMMENTS) + self.get_versions())
+        self.set_website_label(_('Gramps Homepage'))
         self.set_website(const.URL_HOMEPAGE)
         
         self.set_authors(_get_authors())
@@ -105,6 +107,33 @@ class GrampsAboutDialog(gtk.AboutDialog):
         self.set_logo(gtk.gdk.pixbuf_new_from_file(const.SPLASH))
         self.set_modal(True)
 
+    def get_versions(self):
+        if hasattr(os, "uname"):
+            operatingsystem = os.uname()[0]
+            distribution = os.uname()[2]
+        else:
+            operatingsystem = sys.platform
+            distribution = " "
+
+        return (("\n\n" +
+                 "GRAMPS: %s \n" +
+                 "Python: %s \n" +
+                 "BSDDB: %s \n" +
+                 "LANG: %s\n" +
+                 "OS: %s\n" +
+                 "Distribution: %s")
+                % (elipses(str(const.VERSION)),
+                   elipses(str(sys.version).replace('\n','')),
+                   elipses(str(bsddb.__version__) + " " + str(bsddb.db.version())),
+                   elipses(os.environ.get('LANG','')),
+                   elipses(operatingsystem),
+                   elipses(distribution)))
+
+def elipses(text):
+    if len(text) > 40:
+        return text[:40] + "..."
+    return text
+
 #-------------------------------------------------------------------------
 #
 # AuthorParser
