@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2010       Michiel D. Nauta
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -26,7 +27,6 @@
 #
 #-------------------------------------------------------------------------
 import gtk
-from gtk import glade
 import pango
 
 #-------------------------------------------------------------------------
@@ -34,16 +34,16 @@ import pango
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-from TransUtils import sgettext as _
+from gen.ggettext import sgettext as _
 import gen.lib
 from ReportBase import ReportUtils
-from BasicUtils import name_displayer
+from gen.display.name import displayer as name_displayer
 import const
 import DateHandler
 from QuestionDialog import ErrorDialog
 import GrampsDisplay
 import ManagedWindow
-import gen.utils
+from glade import Glade
 
 #-------------------------------------------------------------------------
 #
@@ -52,6 +52,7 @@ import gen.utils
 #-------------------------------------------------------------------------
 WIKI_HELP_PAGE = '%s_-_Entering_and_Editing_Data:_Detailed_-_part_3' % const.URL_MANUAL_PAGE
 WIKI_HELP_SEC = _('manual|Merge_People')
+_GLADE_FILE = 'mergedata.glade'
 
 sex = ( _("female"), _("male"), _("unknown"))
 
@@ -60,25 +61,26 @@ class PersonCompare(ManagedWindow.ManagedWindow):
     def __init__(self, dbstate, uistate, person1, person2, update=None) :
 
         ManagedWindow.ManagedWindow.__init__(self, uistate, [], self.__class__)
+        self.glade = Glade(_GLADE_FILE, toplevel='mergedata')
+        window = self.glade.toplevel
 
-        self.glade = glade.XML(const.MERGE_GLADE, "merge")
-        window = self.glade.get_widget('merge')
-        self.text1 = self.glade.get_widget('text1')
-        self.text2 = self.glade.get_widget('text2')
+        window.show()
+        self.text1 = self.glade.get_object('text1')
+        self.text2 = self.glade.get_object('text2')
         self.db = dbstate.db
 
         self.p1 = person1
         self.p2 = person2
         self.update = update
         
-        self.set_window(window, self.glade.get_widget('title'), 
+        self.set_window(window, self.glade.get_object('merge_title'), 
                         _("Compare People"))
         self.display(self.text1.get_buffer(), person1)
         self.display(self.text2.get_buffer(), person2)
 
-        self.glade.get_widget('cancel').connect('clicked', self.close)
-        self.glade.get_widget('close').connect('clicked', self.merge)
-        self.glade.get_widget('help').connect('clicked', self.help)
+        self.glade.get_object('merge_cancel').connect('clicked', self.close)
+        self.glade.get_object('close').connect('clicked', self.merge)
+        self.glade.get_object('merge_help').connect('clicked', self.help)
 
     def help(self, obj):
         """Display the relevant portion of GRAMPS manual"""
@@ -97,7 +99,7 @@ class PersonCompare(ManagedWindow.ManagedWindow):
                   "people, you must first break the relationship between "
                   "them."))
         else:
-            if self.glade.get_widget('select1').get_active():
+            if self.glade.get_object('select1').get_active():
                 merge = MergePeople(self.db, self.p1, self.p2)
             else:
                 merge = MergePeople(self.db, self.p2, self.p1)
@@ -123,20 +125,25 @@ class PersonCompare(ManagedWindow.ManagedWindow):
         title.set_property('weight', pango.WEIGHT_BOLD)
         title.set_property('scale', pango.SCALE_LARGE)
         self.add(tobj, title, name_displayer.display(person))
-        self.add(tobj, normal, "%s:\t%s" % (_('ID'), person.get_gramps_id()))
-        self.add(tobj, normal, "%s:\t%s" % (_('Gender'), sex[person.get_gender()]))
+        self.add(tobj, normal, "%s:\t%s" % (_('ID'), 
+                 person.get_gramps_id()))
+        self.add(tobj, normal, "%s:\t%s" % (_('Gender'), 
+                 sex[person.get_gender()]))
         bref = person.get_birth_ref()
         if bref:
-            self.add(tobj, normal, "%s:\t%s" % (_('Birth'), self.get_event_info(bref.ref)))
+            self.add(tobj, normal, "%s:\t%s" % (_('Birth'), 
+                     self.get_event_info(bref.ref)))
         dref = person.get_death_ref()
         if dref:
-            self.add(tobj, normal, "%s:\t%s" % (_('Death'), self.get_event_info(dref.ref)))
+            self.add(tobj, normal, "%s:\t%s" % (_('Death'), 
+                     self.get_event_info(dref.ref)))
 
         nlist = person.get_alternate_names()
         if len(nlist) > 0:
             self.add(tobj, title, _("Alternate Names"))
             for name in nlist:
-                self.add(tobj, normal, name_displayer.display_name(name))
+                self.add(tobj, normal, 
+                         name_displayer.display_name(name))
 
         elist = person.get_event_ref_list()
         if len(elist) > 0:
@@ -145,7 +152,8 @@ class PersonCompare(ManagedWindow.ManagedWindow):
                 event_handle = event_ref.ref
                 name = str(
                     self.db.get_event_from_handle(event_handle).get_type())
-                self.add(tobj, normal, "%s:\t%s" % (name, self.get_event_info(event_handle)))
+                self.add(tobj, normal, "%s:\t%s" % 
+                            (name, self.get_event_info(event_handle)))
         plist = person.get_parent_family_handle_list()
 
         if len(plist) > 0:
@@ -170,16 +178,19 @@ class PersonCompare(ManagedWindow.ManagedWindow):
                 spouse_id = ReportUtils.find_spouse(person, family)
                 if spouse_id:
                     spouse = self.db.get_person_from_handle(spouse_id)
-                    self.add(tobj, indent, "%s:\t%s" % (_('Spouse'), name_of(spouse)))
+                    self.add(tobj, indent, "%s:\t%s" % (_('Spouse'), 
+                             name_of(spouse)))
                 relstr = str(family.get_relationship())
                 self.add(tobj, indent, "%s:\t%s" % (_('Type'), relstr))
                 event = ReportUtils.find_marriage(self.db, family)
                 if event:
                     self.add(tobj, indent, "%s:\t%s" % (
-                        _('Marriage'), self.get_event_info(event.get_handle())))
+                            _('Marriage'), 
+                            self.get_event_info(event.get_handle())))
                 for child_ref in family.get_child_ref_list():
                     child = self.db.get_person_from_handle(child_ref.ref)
-                    self.add(tobj, indent, "%s:\t%s" % (_('Child'), name_of(child)))
+                    self.add(tobj, indent, "%s:\t%s" % (_('Child'), 
+                             name_of(child)))
         else:
             self.add(tobj, normal, _("No spouses or children found"))
 
@@ -216,15 +227,9 @@ class PersonCompare(ManagedWindow.ManagedWindow):
             date = DateHandler.get_date(event)
             place = self.place_name(event)
             if date:
-                if place:
-                    return "%s, %s" % (date, place)
-                else:
-                    return date
+                return "%s, %s" % (date, place) if place else date
             else:
-                if place:
-                    return place
-                else:
-                    return ""
+                return place if place else ""
         else:
             return ""
 
@@ -280,20 +285,21 @@ class MergePeopleUI(ManagedWindow.ManagedWindow):
 
         ManagedWindow.ManagedWindow.__init__(self, uistate, [], self.__class__)
         
-        glade_xml = glade.XML(const.MERGE_GLADE, 'merge_people')
-        window = glade_xml.get_widget('merge_people')
+        
+        glade_xml = Glade(_GLADE_FILE, toplevel='mergeperson')
+        window = glade_xml.toplevel
 
-        self.set_window(window, glade_xml.get_widget('title'), _("Merge People"))
+        self.set_window(window, glade_xml.get_object('people_title'), _("Merge People"))
 
-        p1 = glade_xml.get_widget('person1')
-        p2 = glade_xml.get_widget('person2')
+        p1 = glade_xml.get_object('person1')
+        p2 = glade_xml.get_object('person2')
         n1 = name_of(person1)
         n2 = name_of(person2)
 
         p1.set_label(n1)
         p2.set_label(n2)
 
-        glade_xml.get_widget('help').connect('clicked', self.help)
+        glade_xml.get_object('people_help').connect('clicked', self.help)
 
         ret = gtk.RESPONSE_HELP
         while ret == gtk.RESPONSE_HELP:
@@ -426,20 +432,24 @@ class MergePeople(object):
         # merge the event lists
         self.merge_event_lists(new)
 
-        gen.utils.set_birth_death_index(self.db, new)
+        self.db.set_birth_death_index(new)
 
-        # copy attributes
-        new.set_attribute_list(self.p1.get_attribute_list() +
+        # add other attributes to new, which may already have
+        # some attributes from the merger
+        map(new.add_attribute, self.p1.get_attribute_list() +
                                self.p2.get_attribute_list())
 
         # copy addresses
-        new.set_address_list(self.p1.get_address_list() + self.p2.get_address_list())
+        new.set_address_list(self.p1.get_address_list() +
+                             self.p2.get_address_list())
 
         # copy urls
-        new.set_url_list(self.p1.get_url_list() + self.p2.get_url_list())
+        new.set_url_list(self.p1.get_url_list() +
+                         self.p2.get_url_list())
 
         # merge LDS
-        new.set_lds_ord_list(self.p1.get_lds_ord_list() + self.p2.get_lds_ord_list())
+        new.set_lds_ord_list(self.p1.get_lds_ord_list() + 
+                             self.p2.get_lds_ord_list())
 
         # privacy
         new.set_privacy(self.p1.get_privacy() or self.p2.get_privacy())
@@ -449,13 +459,12 @@ class MergePeople(object):
                                       self.p2.get_source_references())
 
         # media
-        for photo in self.p1.get_media_list():
-            new.add_media_reference(photo)
-        for photo in self.p2.get_media_list():
-            new.add_media_reference(photo)
+        map(new.add_media_reference, self.p1.get_media_list())
+        map(new.add_media_reference, self.p2.get_media_list())
 
         # note
-        new.set_note_list(self.p1.get_note_list() + self.p2.get_note_list())
+        new.set_note_list(self.p1.get_note_list() + 
+                          self.p2.get_note_list())
         
     def merge_gramps_ids(self, new):
         """
@@ -491,7 +500,8 @@ class MergePeople(object):
         if not p2_name.is_equal(p1_name):
             new.add_alternate_name(p2_name)
             
-        for name in self.p1.get_alternate_names() + self.p2.get_alternate_names():
+        for name in (self.p1.get_alternate_names() + 
+                     self.p2.get_alternate_names()):
             if name.is_equal(p1_name):
                 break
             for item in new.get_alternate_names():
@@ -586,32 +596,69 @@ class MergePeople(object):
                                    self.old_handle, trans)
             new.add_parent_family_handle(family_handle)
                     
+    def merge_childref(self, ref_one, ref_two):
+        """
+        Add the content of two child-references together where ref_one is the
+        preferred.
+
+        Data typically lost is: mrel/frel of ref_two.
+        """
+        self.copy_note(ref_one, ref_two)
+        self.copy_sources(ref_one, ref_two)
+        ref_one.set_privacy(ref_one.get_privacy() or ref_two.get_privacy())
+        one_frel = ref_one.get_father_relation()
+        one_mrel = ref_one.get_mother_relation()
+        two_frel = ref_two.get_father_relation()
+        two_mrel = ref_two.get_mother_relation()
+        if (one_mrel != two_mrel) or (one_frel != two_frel):
+            if one_mrel == gen.lib.ChildRefType.UNKNOWN:
+                ref_one.set_mother_relation(two_mrel)
+            if one_frel == gen.lib.ChildRefType.UNKNOWN:
+                ref_one.set_father_relation(two_frel)
+
     def convert_child_ids(self, fhandle, new_handle, old_handle, trans):
         """
         Search the family associated with fhandle, and replace 
         old handle with the new handle in all child references.
+
+        There are three situations: The child references list contains
+        a reference to new_handle, but not old_handle, vice versa and 
+        references to both new AND old_handle. In the first case nothing needs
+        to be done, in the second case the old_handle needs replacement by
+        new_handle and in the latter case the references must be merged.
+
+        :param fhandle: Handle of the family to process.
+        :type fhandle: database handle
+        :param new_handle: Handle that should replace any old_handle.
+        :type new_handle: database handle
+        :param old_handle: Handle of obsolete person.
+        :type old_handle: database handle
+        :param trans: database transaction
+        :type trans: I don't know, probably string
         """
         family = self.db.get_family_from_handle(fhandle)
         orig_ref_list = family.get_child_ref_list()
         new_ref_list = []
 
-        # loop through original child list. If a handle matches the
-        # old handle, replace it with the new handle if the new handle
-        # is not already in the list
+        old_ref = [x for x in orig_ref_list if x.ref == old_handle]
+        if old_ref:
+            old_ref = old_ref[0]
+        new_ref = [x for x in orig_ref_list if x.ref == new_handle]
+        if new_ref:
+            new_ref = new_ref[0]
 
-        for child_ref in orig_ref_list:
-            if child_ref.ref == old_handle:
-                if new_handle not in [ref.ref for ref in new_ref_list]:
-                    new_ref = gen.lib.ChildRef()
-                    new_ref.ref = new_handle
-                    new_ref_list.append(new_ref)
-            elif child_ref.ref not in [ref.ref for ref in new_ref_list]:
+        if old_ref:
+            for child_ref in orig_ref_list:
+                if child_ref.ref == old_handle:
+                    if new_ref:
+                        continue # go on to child_ref.ref == new_handle
+                    else:
+                        child_ref.ref = new_handle
+                elif child_ref.ref == new_handle:
+                    self.merge_childref(child_ref, old_ref)
                 new_ref_list.append(child_ref)
 
-        # compare the new list with the original list. If this list
-        # is different, we need to save the changes to the database.
-        if [ref.ref for ref in new_ref_list] \
-               != [ref.ref for ref in orig_ref_list]:
+            # save changes to database
             family.set_child_ref_list(new_ref_list)
             self.db.commit_family(family, trans)
     
@@ -641,10 +688,12 @@ class MergePeople(object):
             if tgt_family:
                 # The target family is already a family in the person's
                 # family list. 
-                if tgt_family.get_handle() in self.p1.get_family_handle_list():
+                if tgt_family.get_handle() in \
+                  self.p1.get_family_handle_list():
                     if __debug__:
                         print "Merging existing family"
-                    self.merge_existing_family(new, src_family, tgt_family, trans)
+                    self.merge_existing_family(new, src_family, 
+                                               tgt_family, trans)
                     continue
             
                 # This is the case the family is not already in the person's
@@ -656,7 +705,8 @@ class MergePeople(object):
                     
                     # change parents of the family to point to the new
                     # family
-                    self.adjust_family_pointers(tgt_family, src_family, trans)
+                    self.adjust_family_pointers(tgt_family, src_family, 
+                                                trans)
                                                 
                     new.remove_family_handle(src_handle)
                     self.db.remove_family(src_handle, trans)
@@ -740,7 +790,9 @@ class MergePeople(object):
         while node:
             # data[2] == father_handle field, data[2] == mother_handle field
             (thandle, data) = node
-            if data[2] == fhandle and data[3] == mhandle and thandle != family_handle:
+            if (data[2] == fhandle and 
+              data[3] == mhandle and 
+              thandle != family_handle):
                 myfamily = gen.lib.Family()
                 myfamily.unserialize(data)
                 break
@@ -756,6 +808,27 @@ class MergePeople(object):
         return myfamily
 
     def merge_existing_family(self, new, src_family, tgt_family, trans):
+        """
+        Removes the family object that becomes superfluous because of the
+        merger of a person.
+
+        If a person is merged with another, there can be a situation that two
+        families that are in the database also need to merge; that is one
+        family stays on and receives extra data, the other family is removed.
+        Removal of a family involves removal of parentin attributes in a person,
+        removal of childof attributes from children and actual removal of the
+        family from the db. The merging of data from both families is performed
+        in its own method.
+
+        :param new: The person that is merging.
+        :type new: :class:`~gen.lib.person.Person`
+        :param src_family: Family `new` is a parent in and that will be removed.
+        :type src_family: :class:`~gen.lib.family.Family`
+        :param tgt_family: Family `new` is and will stay a parent in.
+        :type src_family: :class:`~gen.lib.family.Family`
+        :param trans: db-transaction
+        :type trans: I do not know, string probably
+        """
 
         src_family_handle = src_family.get_handle()
         
@@ -768,12 +841,14 @@ class MergePeople(object):
         if father and src_family_handle in father.get_family_handle_list():
             father.remove_family_handle(src_family_handle)
             if __debug__:
-                print "Removed family %s from father %s" % (src_family_handle, father_id)
+                print "Removed family %s from father %s" % \
+                    (src_family_handle, father_id)
             self.db.commit_person(father, trans)
         if mother and src_family_handle in mother.get_family_handle_list():
             mother.remove_family_handle(src_family_handle)
             if __debug__:
-                print "Removed family %s from mother %s" % (src_family_handle, mother_id)
+                print "Removed family %s from mother %s" % \
+                    (src_family_handle, mother_id)
             self.db.commit_person(mother, trans)
                         
         self.merge_family_pair(tgt_family, src_family, trans)
@@ -798,13 +873,38 @@ class MergePeople(object):
             new.add_family_handle(tgt_family.get_handle())
 
     def merge_family_pair(self, tgt_family, src_family, trans):
+        """
+        Add data from src_family to tgt_family.
+
+        This is typically called when src_family is about to be removed because
+        it became superfluous by a person merger. The data transfered from
+        source to target family is everything except id, father and mother.
+        Data typically lost is: marker and rel of the src-family.
+
+        Missing: lds_ord, Merged Gramps ID attribute and privacy; make own patch
+
+        :param tgt_family: Family receiving data from src_family.
+        :type src_family: :class:`~gen.lib.family.Family`
+        :param src_family: Family adding data to tgt_family.
+        :type src_family: :class:`~gen.lib.family.Family`
+        :param trans: db-transaction
+        :type trans: I do not know, string probably
+        """
+        childrefs_in_both = {}
+        tgtlist = tgt_family.get_child_ref_list()
+        for child_ref in src_family.get_child_ref_list():
+            for tgt_child_ref in tgtlist:
+                if tgt_child_ref.ref == child_ref.ref:
+                    childrefs_in_both[child_ref.ref] = tgt_child_ref
+                    break
 
-        tgt_family_child_handles = [ref.ref
-                                    for ref in tgt_family.get_child_ref_list()]
         # copy children from source to target
         for child_ref in src_family.get_child_ref_list():
             child_handle = child_ref.ref
-            if child_handle not in tgt_family_child_handles:
+            if child_handle in childrefs_in_both:
+                tgt_child_ref = childrefs_in_both[child_handle]
+                self.merge_childref(tgt_child_ref, child_ref)
+            else:
                 child = self.db.get_person_from_handle(child_handle)
                 parents = child.get_parent_family_handle_list()
                 tgt_family.add_child_ref(child_ref)
@@ -813,7 +913,8 @@ class MergePeople(object):
                 i = 0
                 for fam in parents[:]:
                     if fam[0] == src_family.get_handle():
-                        parents[i] = (tgt_family.get_handle(), fam[1], fam[2])
+                        parents[i] = (tgt_family.get_handle(), 
+                                      fam[1], fam[2])
                     i += 1
                 self.db.commit_person(child, trans)
 
@@ -829,11 +930,11 @@ class MergePeople(object):
 
         # merge family attributes
 
-        for xdata in src_family.get_attribute_list():
-            tgt_family.add_attribute(xdata)
+        map(tgt_family.add_attribute, src_family.get_attribute_list())
 
         # merge family notes
-        tgt_family.set_note_list(tgt_family.get_note_list() + src_family.get_note_list())
+        tgt_family.set_note_list(tgt_family.get_note_list() + 
+                                 src_family.get_note_list())
 
         # merge family top-level sources
 
@@ -841,8 +942,7 @@ class MergePeople(object):
 
         # merge multimedia objects
 
-        for photo in src_family.get_media_list():
-            tgt_family.add_media_reference(photo)
+        map(tgt_family.add_media_reference, src_family.get_media_list())
 
     def adjust_family_pointers(self, tgt_family, src_family, trans):
         """
@@ -891,7 +991,8 @@ class MergePeople(object):
     def remove_marriage(self, family, person, trans):
         if person:
             person.remove_family_handle(family.get_handle())
-            if family.get_father_handle() is None and family.get_mother_handle() is None:
+            if (family.get_father_handle() is 
+              family.get_mother_handle() is None):
                 self.delete_empty_family(family, trans)
 
     def delete_empty_family(self, family, trans):
