@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _Tool.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: _Tool.py 16836 2011-03-16 21:55:13Z m_d_n $
 
 "ToolGeneration Framework"
 
@@ -259,7 +259,7 @@ def cli_tool(dbstate, name,category,tool_class, options_class, options_str_dict)
 
     # run tool
     try:
-        tool_class(dbstate,None, options_class, name,None)
+        tool_class(dbstate, None, clt.option_class, name, None)
     except:
         log.error("Failed to start tool.", exc_info=True)
 
