@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: _ReportDialog.py 12560 2009-05-21 17:58:31Z gbritton $
+# $Id: _ReportDialog.py 15939 2010-09-30 10:02:41Z ldnp $
 
 #-------------------------------------------------------------------------
 #
@@ -27,8 +27,8 @@
 #
 #-------------------------------------------------------------------------
 import os
-from types import ClassType, InstanceType
-from gettext import gettext as _
+from types import ClassType
+from gen.ggettext import gettext as _
 
 import logging
 LOG = logging.getLogger(".")
@@ -45,18 +45,20 @@ import gtk
 # GRAMPS modules
 #
 #-------------------------------------------------------------------------
-import Config
+import config
 import Errors
 from QuestionDialog import ErrorDialog, OptionDialog
 from ReportBase import (CATEGORY_TEXT, CATEGORY_DRAW, CATEGORY_BOOK, 
                         CATEGORY_CODE, CATEGORY_WEB, CATEGORY_GRAPHVIZ, 
                         standalone_categories)
-import BaseDoc
+from gen.plug.docgen import StyleSheet, StyleSheetList
 import ManagedWindow
 from _StyleComboBox import StyleComboBox
 from _StyleEditor import StyleListDisplay
 from _FileEntry import FileEntry
 from const import URL_MANUAL_PAGE
+import Utils
+
 #-------------------------------------------------------------------------
 #
 # Private Constants
@@ -84,7 +86,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
         for a basic *stand-alone* report."""
         
         self.style_name = "default"
-        self.page_html_added = False
+        self.firstpage_added = False
         self.raw_name = name
         self.dbstate = dbstate
         self.db = dbstate.db
@@ -98,7 +100,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
     def init_options(self, option_class):
         try:
             if (issubclass(option_class, object) or     # New-style class
-              isinstance(options_class, ClassType)):    # Old-style class
+                isinstance(option_class, ClassType)):   # Old-style class
                 self.options = option_class(self.raw_name, self.db)
         except TypeError:
             self.options = option_class
@@ -121,7 +123,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
 
         self.style_name = self.options.handler.get_default_stylesheet_name()
 
-        window = gtk.Dialog('GRAMPS')
+        window = gtk.Dialog('Gramps')
         self.set_window(window, None, self.get_title())
         self.window.set_has_separator(False)
         self.window.set_modal(True)
@@ -176,26 +178,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
         """The window title for this dialog"""
         name = self.report_name
         category = standalone_categories[self.category]
-        return "%s - %s - GRAMPS" % (name, category)
-    
-    #------------------------------------------------------------------------
-    #
-    # Customization hooks for subclasses
-    #
-    #------------------------------------------------------------------------
-    def get_stylesheet_savefile(self):
-        """Where should new styles for this report be saved?  This is
-        the name of an XML file that will be located in the ~/.gramps
-        directory.  This file does not have to exist; it will be
-        created when needed.  All subclasses should probably override
-        this function."""
-        return "basic_report.xml"
-    
-    def get_default_basename(self):
-        """What should the default name be?
-        """
-        spath = self.options.handler.get_stylesheet_savefile()
-        return spath.split('.')[0]
+        return "%s - %s - Gramps" % (name, category)
     
     #------------------------------------------------------------------------
     #
@@ -223,7 +206,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
         appended to the Options section of the dialog. The text string
         is used to create a label for the passed widget. This allows the
         subclass to extend the Options section with its own widgets. The
-        subclass is reponsible for all managing of the widgets, including
+        subclass is responsible for all managing of the widgets, including
         extracting the final value before the report executes. This task
         should only be called in the add_user_options task."""
         self.widgets.append((label_text, widget))
@@ -233,7 +216,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
         text string and a Gtk Widget. When the interface is built,
         all widgets with the same frame_name are grouped into a
         GtkFrame. This allows the subclass to create its own sections,
-        filling them with its own widgets. The subclass is reponsible for
+        filling them with its own widgets. The subclass is responsible for
         all managing of the widgets, including extracting the final value
         before the report executes. This task should only be called in
         the add_user_options task."""
@@ -290,7 +273,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
         the builds a menu of all the available styles for the user to
         choose from."""
         # Build the default style set for this report.
-        self.default_style = BaseDoc.StyleSheet()
+        self.default_style = StyleSheet()
         self.options.make_default_style(self.default_style)
 
         if self.default_style.is_empty():
@@ -315,7 +298,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
         # Build the initial list of available styles sets.  This
         # includes the default style set and any style sets saved from
         # previous invocations of gramps.
-        self.style_sheet_list = BaseDoc.StyleSheetList(
+        self.style_sheet_list = StyleSheetList(
                             self.options.handler.get_stylesheet_savefile(),
                             self.default_style)
 
@@ -388,7 +371,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
                 else:
                     table.attach(widget, 2, 3, row, row+1,
                                  yoptions=gtk.SHRINK)
-                row = row + 1
+                row += 1
                 
     def setup_main_options(self):
         if "" in self.frames:
@@ -423,7 +406,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
         """Get the name of the directory to which the target dialog
         box should default.  This value can be set in the preferences
         panel."""
-        return Config.get(Config.REPORT_DIRECTORY)
+        return config.get('paths.report-directory')
 
     def set_default_directory(self, value):
         """Save the name of the current directory, so that any future
@@ -433,7 +416,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
         This means that the last directory used will only be
         remembered for this session of gramps unless the user saves
         his/her preferences."""
-        Config.set(Config.REPORT_DIRECTORY, value)
+        config.set('paths.report-directory', value)
 
     #------------------------------------------------------------------------
     #
@@ -442,13 +425,12 @@ class ReportDialog(ManagedWindow.ManagedWindow):
     #------------------------------------------------------------------------
     def setup_init(self):
         # add any elements that we are going to need:
-        hid = self.get_stylesheet_savefile()
+        hid = self.style_name
         if hid[-4:] == ".xml":
             hid = hid[0:-4]
         self.target_fileentry = FileEntry(hid, _("Save As"))
         spath = self.get_default_directory()
         self.target_fileentry.set_filename(spath)
-        self.target_fileentry.gtk_entry().set_position(len(spath))
         # need any labels at top:
         label = gtk.Label("<b>%s</b>" % _('Document Options'))
         label.set_use_markup(1)
@@ -485,7 +467,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
         to tell the calling routine to give up.  This function also
         saves the current directory so that any future reports will
         default to the most recently used directory."""
-        self.target_path = self.target_fileentry.get_full_path(0)
+        self.target_path = Utils.get_unicode_path_from_file_chooser(self.target_fileentry.get_full_path(0))
         if not self.target_path:
             return None
 
@@ -505,7 +487,7 @@ class ReportDialog(ManagedWindow.ManagedWindow):
                                 )
                     return None
 
-            # selected path is an exsting file and we need a file
+            # selected path is an existing file and we need a file
             if os.path.isfile(self.target_path):
                 a = OptionDialog(_('File already exists'),
                                  _('You can choose to either overwrite the '
@@ -523,10 +505,10 @@ class ReportDialog(ManagedWindow.ManagedWindow):
             parent_dir = os.path.dirname(os.path.normpath(self.target_path))
             if not os.access(parent_dir, os.W_OK):
                 ErrorDialog(_('Permission problem'),
-                            _('You do not have permission to create '
-                              '%s\n\n'
-                              'Please select another path or correct '
-                              'the permissions.') % self.target_path 
+                            _("You do not have permission to create "
+                              "%s\n\n"
+                              "Please select another path or correct "
+                              "the permissions.") % self.target_path 
                             )
                 return None
         
@@ -637,7 +619,7 @@ def report(dbstate, uistate, person, report_class, options_class,
                 (m1, m2) = msg.messages()
                 ErrorDialog(m1, m2)
             except IOError, msg:
-                ErrorDialog(_("Report could not be created"),str(msg))
+                ErrorDialog(_("Report could not be created"), str(msg))
             except Errors.ReportError, msg:
                 (m1, m2) = msg.messages()
                 ErrorDialog(m1, m2)
@@ -646,7 +628,7 @@ def report(dbstate, uistate, person, report_class, options_class,
 #           The following except statement will catch all "NoneType" exceptions.
 #           This is useful for released code where the exception is most likely
 #           a corrupt database. But it is less useful for developing new reports
-#           where the execption is most likely a report bug.                
+#           where the exception is most likely a report bug.                
 #            except AttributeError,msg:
 #                if str(msg).startswith("'NoneType' object has no attribute"):
 #                    # "'NoneType' object has no attribute ..." usually means
@@ -658,7 +640,10 @@ def report(dbstate, uistate, person, report_class, options_class,
             except:
                 LOG.error("Failed to run report.", exc_info=True)
             break
-        elif (response == gtk.RESPONSE_DELETE_EVENT or
-              response == gtk.RESPONSE_CANCEL):
+        elif response == gtk.RESPONSE_CANCEL:
             dialog.close()
             break
+        elif response == gtk.RESPONSE_DELETE_EVENT:
+            #just stop, in ManagedWindow, delete-event is already coupled to
+            #correct action.
+            break
