@@ -18,7 +18,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: _ReportOptions.py 12840 2009-07-28 03:52:09Z pez4brian $
+# $Id: _ReportOptions.py 13346 2009-10-08 01:12:51Z dsblank $
 
 # Written by Alex Roitman
 
@@ -54,8 +54,8 @@ except:
 #
 #-------------------------------------------------------------------------
 import const
-import Config
-import BaseDoc
+import config
+from gen.plug.docgen import PAPER_PORTRAIT
 from PluginUtils import _Options, GuiMenuOptions
 
 #-------------------------------------------------------------------------
@@ -76,10 +76,10 @@ class OptionList(_Options.OptionList):
         self.orientation = None
         self.custom_paper_size = [29.7, 21.0]
         self.margins = [2.54, 2.54, 2.54, 2.54]
-        self.template_name = None
         self.format_name = None
+        self.css_filename = None
     
-    def set_style_name(self,style_name):
+    def set_style_name(self, style_name):
         """
         Set the style name for the OptionList.
         @param style_name: name of the style to set.
@@ -95,7 +95,7 @@ class OptionList(_Options.OptionList):
         """
         return self.style_name
 
-    def set_paper_metric(self,paper_metric):
+    def set_paper_metric(self, paper_metric):
         """
         Set the paper metric for the OptionList.
         @param paper_metric: whether to use metric.
@@ -111,7 +111,7 @@ class OptionList(_Options.OptionList):
         """
         return self.paper_metric
 
-    def set_paper_name(self,paper_name):
+    def set_paper_name(self, paper_name):
         """
         Set the paper name for the OptionList.
         @param paper_name: name of the paper to set.
@@ -131,7 +131,7 @@ class OptionList(_Options.OptionList):
         """
         Set the orientation for the OptionList.
         @param orientation: orientation to set. Possible values are
-            BaseDoc.PAPER_LANDSCAPE or BaseDoc.PAPER_PORTRAIT
+            PAPER_LANDSCAPE or PAPER_PORTRAIT
         @type orientation: int
         """
         self.orientation = orientation
@@ -140,12 +140,12 @@ class OptionList(_Options.OptionList):
         """
         Return the orientation for the OptionList.
         @returns: returns the selected orientation. Valid values are
-            BaseDoc.PAPER_LANDSCAPE or BaseDoc.PAPER_PORTRAIT
+            PAPER_LANDSCAPE or PAPER_PORTRAIT
         @rtype: int
         """
         return self.orientation
 
-    def set_custom_paper_size(self,paper_size):
+    def set_custom_paper_size(self, paper_size):
         """
         Set the custom paper size for the OptionList.
         @param paper_size: paper size to set in cm.
@@ -161,7 +161,7 @@ class OptionList(_Options.OptionList):
         """
         return self.custom_paper_size
 
-    def set_margins(self,margins):
+    def set_margins(self, margins):
         """
         Set the margins for the OptionList.
         @param margins: margins to set. Possible values are floats in cm
@@ -177,7 +177,7 @@ class OptionList(_Options.OptionList):
         """
         return copy.copy(self.margins)
 
-    def set_margin(self,pos,value):
+    def set_margin(self, pos, value):
         """
         Set a margin for the OptionList.
         @param pos: Position of margin [left, right, top, bottom]
@@ -187,7 +187,7 @@ class OptionList(_Options.OptionList):
         """
         self.margins[pos] = value
 
-    def get_margin(self,pos):
+    def get_margin(self, pos):
         """
         Return a margin for the OptionList.
         @param pos: Position of margin [left, right, top, bottom]
@@ -197,23 +197,23 @@ class OptionList(_Options.OptionList):
         """
         return self.margins[pos]
 
-    def set_template_name(self,template_name):
+    def set_css_filename(self, css_filename):
         """
         Set the template name for the OptionList.
         @param template_name: name of the template to set.
         @type template_name: str
         """
-        self.template_name = template_name
+        self.css_filename = css_filename
 
-    def get_template_name(self):
+    def get_css_filename(self):
         """
         Return the template name of the OptionList.
         @returns: template name
         @rtype: str
         """
-        return self.template_name
+        return self.css_filename
 
-    def set_format_name(self,format_name):
+    def set_format_name(self, format_name):
         """
         Set the format name for the OptionList.
         @param format_name: name of the format to set.
@@ -238,16 +238,16 @@ class OptionListCollection(_Options.OptionListCollection):
     """
     Implements a collection of option lists.
     """
-    def __init__(self,filename):
-        _Options.OptionListCollection.__init__(self,filename)
+    def __init__(self, filename):
+        _Options.OptionListCollection.__init__(self, filename)
 
     def init_common(self):
         # Default values for common options
         self.default_style_name = "default"
-        self.default_paper_metric = Config.get(Config.PAPER_METRIC)
-        self.default_paper_name = Config.get(Config.PAPER_PREFERENCE)
-        self.default_template_name = ""
-        self.default_orientation = BaseDoc.PAPER_PORTRAIT
+        self.default_paper_metric = config.get('preferences.paper-metric')
+        self.default_paper_name = config.get('preferences.paper-preference')
+        self.default_orientation = PAPER_PORTRAIT
+        self.default_css_filename = ""
         self.default_custom_paper_size = [29.7, 21.0]
         self.default_margins = [2.54, 2.54, 2.54, 2.54]
         self.default_format_name = 'print'
@@ -257,11 +257,11 @@ class OptionListCollection(_Options.OptionListCollection):
         self.last_orientation = self.default_orientation
         self.last_custom_paper_size = copy.copy(self.default_custom_paper_size)
         self.last_margins = copy.copy(self.default_margins)
-        self.last_template_name = self.default_template_name
+        self.last_css_filename = self.default_css_filename
         self.last_format_name = self.default_format_name
         self.option_list_map = {}
 
-    def set_last_paper_metric(self,paper_metric):
+    def set_last_paper_metric(self, paper_metric):
         """
         Set the last paper metric used for the any report in this collection.
         @param paper_metric: whether to use metric.
@@ -277,7 +277,7 @@ class OptionListCollection(_Options.OptionListCollection):
         """
         return self.last_paper_metric
 
-    def set_last_paper_name(self,paper_name):
+    def set_last_paper_name(self, paper_name):
         """
         Set the last paper name used for the any report in this collection.
         @param paper_name: name of the paper to set.
@@ -310,7 +310,7 @@ class OptionListCollection(_Options.OptionListCollection):
         """
         return self.last_orientation
 
-    def set_last_custom_paper_size(self,custom_paper_size):
+    def set_last_custom_paper_size(self, custom_paper_size):
         """
         Set the last custom paper size used for the any report in this collection.
         @param custom_paper_size: size to set in cm (width, height)
@@ -327,7 +327,7 @@ class OptionListCollection(_Options.OptionListCollection):
         """
         return copy.copy(self.last_custom_paper_size)
 
-    def set_last_margins(self,margins):
+    def set_last_margins(self, margins):
         """
         Set the last margins used for the any report in this collection.
         @param margins: margins to set in cm (left, right, top, bottom)
@@ -344,7 +344,7 @@ class OptionListCollection(_Options.OptionListCollection):
         """
         return copy.copy(self.last_margins)
 
-    def set_last_margin(self,pos,value):
+    def set_last_margin(self, pos, value):
         """
         Set the last margin used for the any report in this collection.
         @param pos: pos to set (0-4) (left, right, top, bottom)
@@ -354,7 +354,7 @@ class OptionListCollection(_Options.OptionListCollection):
         """
         self.last_margins[pos] = value
 
-    def get_last_margin(self,pos):
+    def get_last_margin(self, pos):
         """
         Return the last margins used for the any report in this
         collection.
@@ -365,21 +365,21 @@ class OptionListCollection(_Options.OptionListCollection):
         """
         return self.last_margins[pos]
 
-    def set_last_template_name(self,template_name):
+    def set_last_css_filename(self, css_filename):
         """
-        Set the last template used for the any report in this collection.
-        
-        template_name: name of the style to set.
-        """
-        self.last_template_name = template_name
+        Set the last css used for the any report in this collection.
 
-    def get_last_template_name(self):
+        css_filename: name of the style to set.
+        """
+        self.last_css_name = css_filename
+
+    def get_last_css_filename(self):
         """
         Return the last template used for the any report in this collection.
         """
-        return self.last_template_name
+        return self.last_css_filename
 
-    def set_last_format_name(self,format_name):
+    def set_last_format_name(self, format_name):
         """
         Set the last format used for the any report in this collection.
         
@@ -393,7 +393,7 @@ class OptionListCollection(_Options.OptionListCollection):
         """
         return self.last_format_name
 
-    def write_common(self,f):
+    def write_common(self, f):
         f.write('<last-common>\n')
         if self.get_last_paper_metric() != self.default_paper_metric:
             f.write('  <metric value="%d"/>\n' % self.get_last_paper_metric() )
@@ -402,15 +402,15 @@ class OptionListCollection(_Options.OptionListCollection):
             f.write('  <size value="%f %f"/>\n' % (size[0], size[1]) )
         if self.get_last_paper_name() != self.default_paper_name:
             f.write('  <paper name="%s"/>\n' % escxml(self.get_last_paper_name()) )
-        if self.get_last_template_name() != self.default_template_name:
-            f.write('  <template name="%s"/>\n' % escxml(self.get_last_template_name()) )
+        if self.get_last_css_filename() != self.default_css_filename:
+            f.write('  <css name="%s"/>\n' % escxml(self.get_last_css_filename()) )
         if self.get_last_format_name() != self.default_format_name:
             f.write('  <format name="%s"/>\n' % escxml(self.get_last_format_name()) )
         if self.get_last_orientation() != self.default_orientation:
             f.write('  <orientation value="%d"/>\n' % self.get_last_orientation() )
         f.write('</last-common>\n')
 
-    def write_module_common(self,f, option_list):
+    def write_module_common(self, f, option_list):
         if option_list.get_style_name() \
                and option_list.get_style_name() != self.default_style_name:
             f.write('  <style name="%s"/>\n' % escxml(option_list.get_style_name()) )
@@ -424,9 +424,9 @@ class OptionListCollection(_Options.OptionListCollection):
         if option_list.get_paper_name() \
                and option_list.get_paper_name() != self.default_paper_name:
             f.write('  <paper name="%s"/>\n' % escxml(option_list.get_paper_name()) )
-        if option_list.get_template_name() \
-               and option_list.get_template_name() != self.default_template_name:
-            f.write('  <template name="%s"/>\n' % escxml(option_list.get_template_name()) )
+        if option_list.get_css_filename() \
+               and option_list.get_css_filename() != self.default_css_filename:
+            f.write('  <css name="%s"/>\n' % escxml(option_list.get_css_filename()))
         if option_list.get_format_name() \
                and option_list.get_format_name() != self.default_format_name:
             f.write('  <format name="%s"/>\n' % escxml(option_list.get_format_name()) )
@@ -450,7 +450,7 @@ class OptionListCollection(_Options.OptionListCollection):
                 the_file = open(self.filename)
                 p.parse(the_file)
                 the_file.close()
-        except (IOError,OSError,SAXParseException):
+        except (IOError, OSError, SAXParseException):
             pass
 
 #-------------------------------------------------------------------------
@@ -463,17 +463,17 @@ class OptionParser(_Options.OptionParser):
     SAX parsing class for the OptionListCollection XML file.
     """
     
-    def __init__(self,collection):
+    def __init__(self, collection):
         """
         Create a OptionParser class that populates the passed collection.
 
         collection:   BookList to be loaded from the file.
         """
-        _Options.OptionParser.__init__(self,collection)
+        _Options.OptionParser.__init__(self, collection)
         self.common = False
         self.list_class = OptionList
 
-    def startElement(self,tag,attrs):
+    def startElement(self, tag, attrs):
         """
         Overridden class that handles the start of a XML element
         """
@@ -487,11 +487,11 @@ class OptionParser(_Options.OptionParser):
                 self.collection.set_last_paper_name(attrs['name'])
             else:
                 self.option_list.set_paper_name(attrs['name'])
-        elif tag == "template":
+        elif tag == "css":
             if self.common:
-                self.collection.set_last_template_name(attrs['name'])
+                self.collection.set_last_css_filename(attrs['name'])
             else:
-                self.option_list.set_template_name(attrs['name'])
+                self.option_list.set_css_filename(attrs['name'])
         elif tag == "format":
             if self.common:
                 self.collection.set_last_format_name(attrs['name'])
@@ -524,16 +524,16 @@ class OptionParser(_Options.OptionParser):
                 self.option_list.set_margin(pos, value)
         else:
             # Tag is not report-specific, so we let the base class handle it.
-            _Options.OptionParser.startElement(self,tag,attrs)
+            _Options.OptionParser.startElement(self, tag, attrs)
 
-    def endElement(self,tag):
+    def endElement(self, tag):
         "Overridden class that handles the end of a XML element"
         # First we try report-specific tags
         if tag == "last-common":
             self.common = False
         else:
             # Tag is not report-specific, so we let the base class handle it.
-            _Options.OptionParser.endElement(self,tag)
+            _Options.OptionParser.endElement(self, tag)
             
 #------------------------------------------------------------------------
 #
@@ -564,7 +564,7 @@ class OptionHandler(_Options.OptionHandler):
     """
     Implements handling of the options for the plugins.
     """
-    def __init__(self,module_name, options_dict):
+    def __init__(self, module_name, options_dict):
         _Options.OptionHandler.__init__(self, module_name, options_dict, None)
 
     def init_subclass(self):
@@ -577,7 +577,7 @@ class OptionHandler(_Options.OptionHandler):
         Specific initialization for reports.
         """
         # These are needed for running reports.
-        # We will not need to save/retreive them, just keep around.
+        # We will not need to save/retrieve them, just keep around.
         self.doc = EmptyDoc() # Nasty hack. Text reports replace this
         self.output = None
 
@@ -587,8 +587,8 @@ class OptionHandler(_Options.OptionHandler):
         self.paper_name = self.option_list_collection.get_last_paper_name()
         self.orientation = self.option_list_collection.get_last_orientation()
         self.custom_paper_size = self.option_list_collection.get_last_custom_paper_size()
+        self.css_filename = self.option_list_collection.get_last_css_filename()
         self.margins = self.option_list_collection.get_last_margins()
-        self.template_name = self.option_list_collection.get_last_template_name()
         self.format_name = self.option_list_collection.get_last_format_name()
 
     def set_common_options(self):
@@ -600,8 +600,8 @@ class OptionHandler(_Options.OptionHandler):
             self.custom_paper_size = self.saved_option_list.get_custom_paper_size()
         if self.saved_option_list.get_margins():
             self.margins = self.saved_option_list.get_margins()
-        if self.saved_option_list.get_template_name():
-            self.template_name = self.saved_option_list.get_template_name()
+        if self.saved_option_list.get_css_filename():
+            self.css_filename = self.saved_option_list.get_css_filename()
         if self.saved_option_list.get_paper_metric():
             self.paper_metric = self.saved_option_list.get_paper_metric()
         if self.saved_option_list.get_paper_name():
@@ -615,9 +615,9 @@ class OptionHandler(_Options.OptionHandler):
         self.saved_option_list.set_orientation(self.orientation)
         self.saved_option_list.set_custom_paper_size(self.custom_paper_size)
         self.saved_option_list.set_margins(self.margins)
-        self.saved_option_list.set_template_name(self.template_name)
         self.saved_option_list.set_paper_metric(self.paper_metric)
         self.saved_option_list.set_paper_name(self.paper_name)
+        self.saved_option_list.set_css_filename(self.css_filename)
         self.saved_option_list.set_format_name(self.format_name)
         self.option_list_collection.set_option_list(self.module_name,
                                                     self.saved_option_list)
@@ -626,37 +626,38 @@ class OptionHandler(_Options.OptionHandler):
         self.option_list_collection.set_last_orientation(self.orientation)
         self.option_list_collection.set_last_custom_paper_size(self.custom_paper_size)
         self.option_list_collection.set_last_margins(self.margins)
-        self.option_list_collection.set_last_template_name(self.template_name)
         self.option_list_collection.set_last_paper_metric(self.paper_metric)
         self.option_list_collection.set_last_paper_name(self.paper_name)
+        self.option_list_collection.set_last_css_filename(self.css_filename)
         self.option_list_collection.set_last_format_name(self.format_name)
 
     def get_stylesheet_savefile(self):
         """Where to save user defined styles for this report."""
-        return "%s.xml" % self.module_name
+        filename = "%s.xml" % self.module_name
+        return os.path.join(const.HOME_DIR, filename) 
 
     def get_default_stylesheet_name(self):
         return self.style_name
 
-    def set_default_stylesheet_name(self,style_name):
+    def set_default_stylesheet_name(self, style_name):
         self.style_name = style_name
 
     def get_format_name(self):
         return self.format_name
 
-    def set_format_name(self,format_name):
+    def set_format_name(self, format_name):
         self.format_name = format_name
 
     def get_paper_metric(self):
         return self.paper_metric
 
-    def set_paper_metric(self,paper_metric):
+    def set_paper_metric(self, paper_metric):
         self.paper_metric = paper_metric
 
     def get_paper_name(self):
         return self.paper_name
 
-    def set_paper_name(self,paper_name):
+    def set_paper_name(self, paper_name):
         self.paper_name = paper_name
 
     def get_paper(self):
@@ -665,17 +666,17 @@ class OptionHandler(_Options.OptionHandler):
         """
         return self.paper
 
-    def set_paper(self,paper):
+    def set_paper(self, paper):
         """
         This method is for temporary storage, not for saving/restoring.
         """
         self.paper = paper
 
-    def get_template_name(self):
-        return self.template_name
+    def get_css_filename(self):
+        return self.css_filename
 
-    def set_template_name(self,template_name):
-        self.template_name = template_name
+    def set_css_filename(self, css_filename):
+        self.css_filename = css_filename
 
     def get_orientation(self):
         return self.orientation
@@ -686,7 +687,7 @@ class OptionHandler(_Options.OptionHandler):
     def get_custom_paper_size(self):
         return copy.copy(self.custom_paper_size)
 
-    def set_custom_paper_size(self,custom_paper_size):
+    def set_custom_paper_size(self, custom_paper_size):
         self.custom_paper_size = copy.copy(custom_paper_size)
 
     def get_margins(self):
@@ -762,7 +763,7 @@ class ReportOptions(_Options.Options):
         """
         return self.handler.doc
 
-    def set_document(self,val):
+    def set_document(self, val):
         """
         Set document to a given instance.
         
@@ -778,7 +779,7 @@ class ReportOptions(_Options.Options):
         """
         return self.handler.output
 
-    def set_output(self,val):
+    def set_output(self, val):
         """
         Set output destination to a given string.
         
@@ -791,10 +792,10 @@ class ReportOptions(_Options.Options):
 # MenuReportOptions
 #
 #-------------------------------------------------------------------------
-class MenuReportOptions(GuiMenuOptions,ReportOptions):
+class MenuReportOptions(GuiMenuOptions, ReportOptions):
     """
 
-    The MenuReportOptions class implementes the ReportOptions
+    The MenuReportOptions class implements the ReportOptions
     functionality in a generic way so that the user does not need to
     be concerned with the graphical representation of the options.
     
