@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ScratchPad.py 13701 2009-12-04 09:22:33Z romjerome $
+# $Id: ScratchPad.py 14545 2010-03-01 12:52:33Z bmcage $
 
 #------------------------------------------------------------------------
 #
@@ -30,12 +30,6 @@ import os
 from xml.sax.saxutils import escape
 from time import strftime as strftime
 
-try:
-    import fcntl
-    use_lock = True
-except:
-    use_lock = False
-
 #-------------------------------------------------------------------------
 #
 # GTK/Gnome modules
@@ -43,7 +37,6 @@ except:
 #-------------------------------------------------------------------------
 import gtk
 from gtk.gdk import ACTION_COPY, BUTTON1_MASK, ACTION_MOVE
-from gtk import glade
 
 #-------------------------------------------------------------------------
 #
@@ -51,14 +44,15 @@ from gtk import glade
 #
 #-------------------------------------------------------------------------
 import const
-import Config
+import config
 import gen.lib
 import TreeTips
 import DateHandler
 import GrampsDisplay
 import ManagedWindow
-from TransUtils import sgettext as _
-from Utils import mac
+from gen.ggettext import sgettext as _
+from constfunc import mac
+from glade import Glade
 from DdTargets import DdTargets
 
 #-------------------------------------------------------------------------
@@ -79,13 +73,6 @@ _stock_image = os.path.join(const.IMAGE_DIR,'stock_link.png')
 LINK_PIC = gtk.gdk.pixbuf_new_from_file(_stock_image)
 BLANK_PIC = gtk.gdk.Pixbuf(0,0,8,1,1)
 
-#-------------------------------------------------------------------------
-#
-# The file used to store the state of the Clipboard (was scratchpad) between sessions
-#
-#-------------------------------------------------------------------------
-SCRATCHPAD_FILE = os.path.join(const.HOME_DIR,"scratchpad.dat")
-
 #-------------------------------------------------------------------------
 #
 # wrapper classes to provide object specific listing in the ListView
@@ -142,7 +129,7 @@ class ScratchPadGrampsTypeWrapper(ScratchPadWrapper):
                           'Source': self._db.get_source_from_handle}
 
         for (classname, handle) in self._obj.get_referenced_handles_recursively():
-            if classname in valid_func_map.keys():
+            if classname in valid_func_map:
                 if not valid_func_map[classname](handle):
                     return False
             
@@ -323,8 +310,8 @@ class ScratchPadNote(ScratchPadWrapper):
         value = self._db.get_note_from_handle(handle)
 
         self._title = value.get_gramps_id()
-        #String must be unicode for truncation to work for non ascii characters
         note = value.get().replace('\n', ' ')
+        #String must be unicode for truncation to work for non ascii characters 
         note = unicode(note)
         if len(note) > 80:
             self._value = note[:80]+"..."
@@ -485,8 +472,7 @@ class ScratchPadSourceRef(ScratchPadGrampsTypeWrapper):
         base = self._db.get_source_from_handle(self._obj.get_reference_handle())
         self._title = base.get_title()
         
-        notelist = [ self._db.get_note_from_handle(hndl) 
-                     for hndl in self._obj.get_note_list() ]
+        notelist = map(self._db.get_note_from_handle, self._obj.get_note_list())
         srctxtlist = [ note for note in notelist 
                        if note.get_type() == gen.lib.NoteType.SOURCE_TEXT]
 
@@ -496,7 +482,7 @@ class ScratchPadSourceRef(ScratchPadGrampsTypeWrapper):
         text = ""
         if len(srctxtlist) > 0:
             text = " ".join(srctxtlist[0].get().split())
-        #String must be unicode for truncation to work for non ascii characters
+        #String must be unicode for truncation to work for non ascii characters 
             text = unicode(text)
             if len(text) > 60:
                 text =  text[:60]+"..."
@@ -962,33 +948,52 @@ class ScratchPadListView(object):
 
     def database_changed(self,db):
         self._db = db
+        # Note: delete event is emitted before the delete, so checking
+        #        if valid on this is useless !
         db_signals = (
             'person-update',
             'person-rebuild',
             'family-update',
-            'family-delete',
             'family-rebuild',
             'source-update',
             'source-rebuild',
             'place-update',
-            'place-delete',
             'place-rebuild',
             'media-update',
-            'media-delete',
             'media-rebuild',
             'event-update',
             'event-rebuild',
             'repository-update',
-            'repository-rebuild'
+            'repository-rebuild',
+            'note-rebuild'
             )
 
         for signal in db_signals:
             self._db.connect(signal,self.remove_invalid_objects)
 
-        self._db.connect('person-delete', gen_del_obj(self.delete_object, 'person-link'))
-        self._db.connect('source-delete', gen_del_obj(self.delete_object, 'source-link'))
-        self._db.connect('repository-delete', gen_del_obj(self.delete_object, 'repo-link'))
-        self._db.connect('event-delete', gen_del_obj(self.delete_object, 'pevent'))
+        self._db.connect('person-delete', 
+                         gen_del_obj(self.delete_object, 'person-link'))
+        self._db.connect('person-delete', 
+                         gen_del_obj(self.delete_object_ref, 'personref'))
+        self._db.connect('source-delete',
+                         gen_del_obj(self.delete_object, 'source-link'))
+        self._db.connect('source-delete',
+                         gen_del_obj(self.delete_object_ref, 'srcref'))
+        self._db.connect('repository-delete',
+                         gen_del_obj(self.delete_object, 'repo-link'))
+        self._db.connect('event-delete',
+                         gen_del_obj(self.delete_object, 'pevent'))
+        self._db.connect('event-delete',
+                         gen_del_obj(self.delete_object_ref, 'eventref'))
+        self._db.connect('media-delete',
+                         gen_del_obj(self.delete_object, 'mediaobj'))
+        self._db.connect('media-delete',
+                         gen_del_obj(self.delete_object_ref, 'mediaref'))
+        self._db.connect('place-delete',
+                         gen_del_obj(self.delete_object, 'place-link'))
+        self._db.connect('note-delete',
+                         gen_del_obj(self.delete_object, 'note-link'))
+        # family-delete not needed, cannot be dragged!
 
         self.remove_invalid_objects()
 
@@ -1010,6 +1015,16 @@ class ScratchPadListView(object):
                     if data[2] in handle_list:
                         model.remove(o.iter)
     
+    def delete_object_ref(self, handle_list, link_type):
+        model = self._widget.get_model()
+
+        if model:
+            for o in model:
+                if o[0] == link_type:
+                    data = o[1]._obj.get_reference_handle()
+                    if data in handle_list:
+                        model.remove(o.iter)
+                        
     # Method to manage the wrapper classes.
     
     def register_wrapper_classes(self):
@@ -1167,7 +1182,6 @@ class ScratchPadListView(object):
         # remember time for double drop workaround.
         self._previous_drop_time = realTime
 
-
     # proxy methods to provide access to the real widget functions.
     
     def set_model(self,model=None):
@@ -1223,20 +1237,18 @@ class ScratchPadWindow(ManagedWindow.ManagedWindow):
         self.database_changed(self.dbstate.db)
         self.dbstate.connect('database-changed', self.database_changed)
 
-        self.width_key = Config.CLIPBOARD_WIDTH
-        self.height_key = Config.CLIPBOARD_HEIGHT
-        self.glade_file = os.path.join(const.GLADE_DIR, "scratchpad.glade")
-
-        self.top = glade.XML(self.glade_file,"scratch_pad","gramps")
-        self.set_window(self.top.get_widget("scratch_pad"),
-                        None, None, msg=_("Clipboard"))
+        self.width_key = 'interface.clipboard-width'
+        self.height_key = 'interface.clipboard-height'
+        
+        self.top = Glade()
+        self.set_window(self.top.toplevel, None, None, msg=_("Clipboard"))
         self._set_size()
 
-        self.clear_all_btn = self.top.get_widget("btn_clear_all")
-        self.clear_btn = self.top.get_widget("btn_clear")
+        self.clear_all_btn = self.top.get_object("btn_clear_all")
+        self.clear_btn = self.top.get_object("btn_clear")
         
         self.object_list = ScratchPadListView(
-            self.dbstate,self.top.get_widget('objectlist'))
+            self.dbstate,self.top.get_object('objectlist'))
         self.object_list.get_selection().connect('changed',
                                                  self.set_clear_btn_sensitivity)
         self.set_clear_btn_sensitivity(sel=self.object_list.get_selection())
@@ -1253,7 +1265,11 @@ class ScratchPadWindow(ManagedWindow.ManagedWindow):
         
         self.object_list.set_model(ScratchPadWindow.otree)
         
-        self.top.signal_autoconnect({
+        #Database might have changed, objects might have been removed,
+        #we need to reevaluate if all data is valid
+        self.object_list.remove_invalid_objects()
+        
+        self.top.connect_signals({
             "on_close_scratchpad" : self.close,
             "on_clear_clicked": self.on_clear_clicked,
             "on_help_clicked": self.on_help_clicked,
