@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Spell.py 12560 2009-05-21 17:58:31Z gbritton $
+# $Id: Spell.py 15085 2010-04-11 14:18:59Z dsblank $
 
 """
 Provide an interface to the gtkspell interface. This requires
@@ -32,7 +32,7 @@ present, we default to no spell checking.
 # Python classes
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 import locale
 
 #-------------------------------------------------------------------------
@@ -70,7 +70,7 @@ if not HAVE_GTKSPELL:
 # GRAMPS classes
 #
 #-------------------------------------------------------------------------
-import Config
+import config
 
 #-------------------------------------------------------------------------
 #
@@ -171,8 +171,7 @@ LANGUAGES = {
 class Spell(object):
     """Attach a gtkspell instance to the passed TextView instance.
     """
-    lang = locale.getlocale()[0]
-    
+    lang = locale.getlocale()[0] or "en"
     _installed_languages = {'off': _('None')}
     
     if HAVE_ENCHANT and HAVE_GTKSPELL:
@@ -194,30 +193,53 @@ class Spell(object):
             _installed_languages[language] = " ".join(name.split('_'))
 
     elif not HAVE_ENCHANT and HAVE_GTKSPELL:
-        #we try a hack to get the languages. We do this by trying all 
-        #languages we know of.
-        for lang_code, lang_name in LANGUAGES.items():
-            try:
-                #work around gtkspell bug with tv
-                tv = gtk.TextView()
-                gtkspell.Spell(tv).set_language(lang_code)
-                _installed_languages[lang_code] = lang_name
-            except RuntimeError:
-                #FIXME: this does not work anymore since 10/2008!!!
-                #if pyenchant is installed we can avoid it, otherwise perhaps
-                # future gtkspell3 will offer a solution.
-                pass
+        # if lang is None, default to en:
+        tested = False
+        #we try a hack to get the locale language. 
+        for (lang_code, lang_name) in LANGUAGES.items():
+            # if this lang is the current locale:
+            if (lang == lang_code):
+                tested = True
+                # if it is english, we know it works:
+                if lang == "en":
+                    _installed_languages[lang] = lang_name
+                    print _("Warning: spelling checker language limited to "
+                            "locale '%s'; install pyenchant/python-enchant "
+                            "for better options.") % "en"
+                elif locale.getlocale()[1] == "UTF8":
+                    # Only worked with UTF8 versions of language.
+                    # But, we need to test it:
+                    try:
+                        #work around gtkspell bug with tv
+                        tv = gtk.TextView()
+                        gtkspell.Spell(tv).set_language(lang_code)
+                        _installed_languages[lang_code] = lang_name
+                        print _("Warning: spelling checker language limited to "
+                                "locale '%s'; install pyenchant/python-enchant "
+                                "for better options.") % lang
+                    except:
+                        # FIXME: this does not work anymore since 10/2008!!!
+                        # if pyenchant is installed we can avoid it, otherwise
+                        # perhaps future gtkspell3 will offer a solution.
+                        print _("Warning: spelling checker disabled; "
+                                "install pyenchant/python-enchant to enable.")
+                # if we matched, we're done looking
+                break
+        if not tested:
+            # if we didn't see a match on lang, then there is no spell check
+            print _("Warning: spelling checker disabled; "
+                    "install pyenchant/python-enchant to enable.")
 
     def __init__(self, textview):
         self.textview = textview
         
-        if self.lang and Config.get(Config.SPELLCHECK):
+        if self.lang and config.get('behavior.spellcheck'):
             # if LANG is not a correct key (pt_BR or pt_PT),
             #  try only the language part of LANG
-            if self.lang not in self._installed_languages.keys():
+            if self.lang not in self._installed_languages:
                 self.lang = self.lang.split('_')[0]
             # if this still doesn't work we fall back to 'off'
-            if self.lang not in self._installed_languages.keys():
+            if self.lang not in self._installed_languages:
                 self.lang = 'off'
         else:
             self.lang = 'off'
