@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Utils.py 15231 2010-04-19 13:08:00Z ldnp $
+# $Id: Utils.py 16575 2011-02-05 09:00:43Z romjerome $
 
 """
 Non GUI/GTK related utility functions
@@ -37,6 +37,8 @@ import random
 import time
 import shutil
 import uuid
+import logging
+LOG = logging.getLogger(".")
 
 #-------------------------------------------------------------------------
 #
@@ -322,20 +324,60 @@ def find_folder( filename):
     # not found
     return ''
 
-def get_unicode_path(path):
+def get_unicode_path_from_file_chooser(path):
     """
     Return the Unicode version of a path string.
 
     :type  path: str
     :param path: The path to be converted to Unicode
     :rtype:      unicode
-    :returns:     The Unicode version of path.
+    :returns:    The Unicode version of path.
     """
-    # Don't make unicode of unicode as this does not work
-    # with parameter for encoding.
-    if type(path) == type(u""):
+    # make omly unicode of path of type 'str'
+    if not (isinstance(path,  str)):
         return path
-    return unicode(path, sys.getfilesystemencoding())
+
+    if constfunc.win():
+        # in windows filechooser returns officially utf-8, not filesystemencoding
+        try:
+            return unicode(path)
+        except:
+            LOG.warn("Problem encountered converting string: %s." % path)
+            return unicode(path, sys.getfilesystemencoding(), errors='replace')
+    else:
+        try:
+            return unicode(path, sys.getfilesystemencoding())
+        except:
+            LOG.warn("Problem encountered converting string: %s." % path)
+            return unicode(path, sys.getfilesystemencoding(), errors='replace')    
+
+def get_unicode_path_from_env_var(path):
+    """
+    Return the Unicode version of a path string.
+
+    :type  path: str
+    :param path: The path to be converted to Unicode
+    :rtype:      unicode
+    :returns:    The Unicode version of path.
+    """
+    # make omly unicode of path of type 'str'
+    if not (isinstance(path,  str)):
+        return path
+
+    if constfunc.win():
+        # In Windows path/filename returned from a emvironment variable is in filesystemencoding
+        try:
+            new_path = unicode(path, sys.getfilesystemencoding())
+            return new_path
+        except:
+            LOG.warn("Problem encountered converting string: %s." % path)
+            return unicode(path, sys.getfilesystemencoding(), errors='replace')
+    else:
+        try:
+            return unicode(path)
+        except:
+            LOG.warn("Problem encountered converting string: %s." % path)
+            return unicode(path, sys.getfilesystemencoding(), errors='replace')    
 
 
 #-------------------------------------------------------------------------
@@ -623,7 +665,7 @@ class ProbablyAlive(object):
                             val = d.get_year() - years
                             d.set_year(val)
                             return (d, d.copy_offset_ymd(self.MAX_AGE_PROB_ALIVE),
-                                    _("descendent birth date"),
+                                    _("descendant birth date"),
                                     child)
                     child_death_ref = child.get_death_ref()
                     if child_death_ref:
@@ -632,7 +674,7 @@ class ProbablyAlive(object):
                         if dobj.get_start_date() != gen.lib.Date.EMPTY:
                             return (dobj.copy_offset_ymd(- self.AVG_GENERATION_GAP), 
                                     dobj.copy_offset_ymd(- self.AVG_GENERATION_GAP + self.MAX_AGE_PROB_ALIVE),
-                                    _("descendent death date"),
+                                    _("descendant death date"),
                                     child)
                     date1, date2, explain, other = descendants_too_old (child, years + self.AVG_GENERATION_GAP)
                     if date1 and date2:
@@ -648,7 +690,7 @@ class ProbablyAlive(object):
                                 val = d.get_year() - years
                                 d.set_year(val)
                                 return (d, d.copy_offset_ymd(self.MAX_AGE_PROB_ALIVE),
-                                        _("descendent birth-related date"),
+                                        _("descendant birth-related date"),
                                         child)
 
                         elif ev and ev.type.is_death_fallback():
@@ -656,7 +698,7 @@ class ProbablyAlive(object):
                             if dobj.get_start_date() != gen.lib.Date.EMPTY:
                                 return (dobj.copy_offset_ymd(- self.AVG_GENERATION_GAP), 
                                         dobj.copy_offset_ymd(- self.AVG_GENERATION_GAP + self.MAX_AGE_PROB_ALIVE),
-                                        _("descendent death-related date"),
+                                        _("descendant death-related date"),
                                         child)
 
             return (None, None, "", None)
@@ -803,7 +845,7 @@ def probably_alive(person, db,
     """
     Return true if the person may be alive on current_date.
 
-    This works by a process of emlimination. If we can't find a good
+    This works by a process of elimination. If we can't find a good
     reason to believe that someone is dead then we assume they must
     be alive.
 
@@ -823,35 +865,9 @@ def probably_alive(person, db,
     if not birth or not death:
         # no evidence, must consider alive
         return (True, None, None, _("no evidence"), None)
-    # must have est dates from here:
-    # SPECIAL CASE: Today:
-    if current_date.match(gen.lib.date.Today(), "=="):
-        if person.get_death_ref():
-            # if death in the future: (impossible, unless guess)
-            # if return_range:
-            # return (True, birth, death, ("future death, ") + explain, relative)
-            # else:
-            # return True
-            if return_range:
-                return (False, birth, death, explain, relative)
-            else:
-                return False
+    # must have dates from here:
     if limit:
         death += limit # add these years to death
-    # if the current - birth is too big, not alive:
-    # FIXME: use match here:
-    if (current_date - birth)[0] > pb.MAX_AGE_PROB_ALIVE:
-        if return_range:
-            return (False, birth, death, explain, relative)
-        else:
-            return False
-    # FIXME: use match here:
-    # if the current_date is before birth, not alive:
-    if (birth - current_date)[0] > 0:
-        if return_range:
-            return (False, birth, death, explain, relative)
-        else:
-            return False
     # Finally, check to see if current_date is between dates
     result = (current_date.match(birth, ">=") and 
               current_date.match(death, "<="))
@@ -956,6 +972,7 @@ def get_empty_tempdir(dirname):
     if os.path.isdir(dirpath):
         shutil.rmtree(dirpath)
     os.makedirs(dirpath)
+    dirpath = get_unicode_path_from_env_var(dirpath)
     return dirpath
 
 def rm_tempdir(path):
@@ -1351,10 +1368,10 @@ def navigation_label(db, nav_type, handle):
         obj = db.get_note_from_handle(handle)
         if obj:
             label = obj.get()
-            label = " ".join(label.split())
             # When strings are cut, make sure they are unicode
             #otherwise you may end of with cutting within an utf-8 sequence
-            label = get_unicode_path(label)
+            label = unicode(label)
+            label = " ".join(label.split())
             if len(label) > 40:
                 label = label[:40] + "..."
 
