@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: attribute.py 12758 2009-07-03 09:23:07Z bmcage $
+# $Id: attribute.py 16826 2011-03-15 21:54:37Z m_d_n $
 
 """
 Attribute class for GRAMPS.
@@ -65,7 +65,7 @@ class Attribute(SecondaryObject, PrivacyBase, SourceBase, NoteBase):
         NoteBase.__init__(self, source)
         
         if source:
-            self.type = source.type
+            self.type = AttributeType(source.type)
             self.value = source.value
         else:
             self.type = AttributeType()
