@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: calendar.py 11681 2009-01-22 10:15:01Z romjerome $
+# $Id: calendar.py 16676 2011-02-19 14:14:14Z ldnp $
 
 """
 Provide calendar to sdn (serial date number) conversion.
@@ -550,11 +550,26 @@ def islamic_ymd(sdn):
     return (year, month, day)
 
 def swedish_sdn(year, month, day):
-    """Convert a Swedish (almost Julian) date to an SDN number."""
-    return julian_sdn(year, month, day)-1
+    """Convert a Swedish date to an SDN number."""
+    datum = (year, month, day)
+    # Swedish Calendar
+    if (1700,3,1) <= datum <= (1712,2,30):
+        return julian_sdn(year, month, day) -1
+    # Gregorian Calendar (1753-03-01)
+    elif (1753, 3, 1) <= datum:
+        return gregorian_sdn(year, month, day)
+    else:
+        return julian_sdn(year, month, day)
 
 def swedish_ymd(sdn):
-    """Convert an SDN number to a Swedish (almost Julian) calendar date."""
+    """Convert an SDN number to a Swedish calendar date."""
     if sdn == 2346425:
-        return (1712,2,30)
-    return julian_ymd(sdn+1)
+         return (1712,2,30)
+    # Swedish Calendar
+    elif 2342042 <= sdn < 2346425:
+        return julian_ymd(sdn+1)
+    # Gregorian Calendar (1753-03-01)
+    elif 2361390 <= sdn:
+        return gregorian_ymd(sdn)
+    else:
+        return julian_ymd(sdn)
