@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: childref.py 12984 2009-08-13 08:52:05Z acraphae $
+# $Id: childref.py 16826 2011-03-15 21:54:37Z m_d_n $
 
 """
 Child Reference class for GRAMPS.
@@ -55,8 +55,8 @@ class ChildRef(SecondaryObject, PrivacyBase, SourceBase, NoteBase, RefBase):
         NoteBase.__init__(self, source)
         RefBase.__init__(self, source)
         if source:
-            self.frel = source.frel
-            self.mrel = source.mrel
+            self.frel = ChildRefType(source.frel)
+            self.mrel = ChildRefType(source.mrel)
         else:
             self.frel = ChildRefType()
             self.mrel = ChildRefType()
