@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: date.py 14145 2010-01-27 03:38:30Z pez4brian $
+# $Id: date.py 16467 2011-01-25 12:43:09Z bmcage $
 
 """Support for dates."""
 
@@ -1702,6 +1702,16 @@ def Today():
     current_date.set_yr_mon_day(*time.localtime(time.time())[0:3])
     return current_date
 
+def NextYear():
+    """
+    Returns a Date object set to next year
+    """
+    import time
+    next_year = Date()
+    thisyear = time.localtime(time.time())
+    next_year.set_yr_mon_day(thisyear[0]+1, thisyear[1], thisyear[3])
+    return next_year
+
 #-------------------------------------------------------------------------
 #
 # Date Functions
