@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: note.py 12704 2009-06-24 21:56:07Z bmcage $
+# $Id: note.py 16218 2010-11-19 18:37:12Z ldnp $
 
 """
 Note class for GRAMPS.
@@ -133,10 +133,10 @@ class Note(BasicPrimaryObject):
         """Return the text string associated with the note.
 
         :returns: The *clear* text of the note contents.
-        :rtype: str
+        :rtype: unicode
         
         """
-        return str(self.text)
+        return unicode(self.text)
 
     def set_styledtext(self, text):
         """Set the text associated with the note to the passed string.
