@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: url.py 12704 2009-06-24 21:56:07Z bmcage $
+# $Id: url.py 16826 2011-03-15 21:54:37Z m_d_n $
 
 """
 Url class for GRAMPS.
@@ -59,7 +59,7 @@ class Url(SecondaryObject, PrivacyBase):
         if source:
             self.path = source.path
             self.desc = source.desc
-            self.type = source.type
+            self.type = UrlType(source.type)
         else:
             self.path = ""
             self.desc = ""
