@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
+# Copyright (C) 2008  Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +19,9 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-__all__ = [ "filter", "living", "private", "proxybase" ]
+__all__ = [ "filter", "living", "private", "proxybase", "referenced" ]
 
 from filter import FilterProxyDb
 from living import LivingProxyDb
 from private import PrivateProxyDb
+from referenced import ReferencedProxyDb
