@@ -18,7 +18,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: living.py 13629 2009-11-18 22:45:39Z bmcage $
+# $Id: living.py 15556 2010-06-11 00:39:15Z dsblank $
 
 """
 Proxy class for the GRAMPS databases. Filter out all living people.
@@ -29,7 +29,6 @@ Proxy class for the GRAMPS databases. Filter out all living people.
 # Python libraries
 #
 #-------------------------------------------------------------------------
-from gettext import gettext as _
 
 #-------------------------------------------------------------------------
 #
@@ -37,8 +36,10 @@ from gettext import gettext as _
 #
 #-------------------------------------------------------------------------
 from proxybase import ProxyDbBase
-from gen.lib import Date, Person, Name
+from gen.lib import Person, Name
+from gen.lib.date import Today
 from Utils import probably_alive
+import config
 
 #-------------------------------------------------------------------------
 #
@@ -63,7 +64,8 @@ class LivingProxyDb(ProxyDbBase):
         @param mode: The method for handling living people. 
          LivingProxyDb.MODE_EXCLUDE_ALL will remove living people altogether. 
          LivingProxyDb.MODE_INCLUDE_LAST_NAME_ONLY will remove all information 
-         and change their given name to "Living".
+         and change their given name to "[Living]" or what has been set in 
+         Preferences -> Text.
          LivingProxyDb.MODE_INCLUDE_FULL_NAME_ONLY will remove all information
          but leave the entire name intact.
         @type mode: int
@@ -77,8 +79,7 @@ class LivingProxyDb(ProxyDbBase):
         ProxyDbBase.__init__(self, dbase)
         self.mode = mode
         if current_year is not None:
-            self.current_date = Date()
-            self.current_date.set_year(current_year)
+            self.current_date = Today()
         else:
             self.current_date = None
         self.years_after_death = years_after_death
@@ -96,34 +97,6 @@ class LivingProxyDb(ProxyDbBase):
                 person = self.__restrict_person(person)
         return person
 
-    def get_source_from_handle(self, handle):
-        """
-        Finds a Source in the database from the passed gramps ID.
-        If no such Source exists, None is returned.
-        """
-        return self.db.get_source_from_handle(handle)
-
-    def get_object_from_handle(self, handle):
-        """
-        Finds an Object in the database from the passed gramps ID.
-        If no such Object exists, None is returned.
-        """
-        return self.db.get_object_from_handle(handle)
-
-    def get_place_from_handle(self, handle):
-        """
-        Finds a Place in the database from the passed gramps ID.
-        If no such Place exists, None is returned.
-        """
-        return self.db.get_place_from_handle(handle)
-
-    def get_event_from_handle(self, handle):
-        """
-        Finds a Event in the database from the passed gramps ID.
-        If no such Event exists, None is returned.
-        """
-        return self.db.get_event_from_handle(handle)
-
     def get_family_from_handle(self, handle):
         """
         Finds a Family in the database from the passed handle.
@@ -133,20 +106,6 @@ class LivingProxyDb(ProxyDbBase):
         family = self.__remove_living_from_family(family)
         return family
 
-    def get_repository_from_handle(self, handle):
-        """
-        Finds a Repository in the database from the passed gramps' ID.
-        If no such Repository exists, None is returned.
-        """
-        return self.db.get_repository_from_handle(handle)
-
-    def get_note_from_handle(self, handle):
-        """
-        Finds a Note in the database from the passed gramps' ID.
-        If no such Note exists, None is returned.
-        """
-        return self.db.get_note_from_handle(handle)
-
     def get_person_from_gramps_id(self, val):
         """
         Finds a Person in the database from the passed GRAMPS ID.
@@ -170,119 +129,13 @@ class LivingProxyDb(ProxyDbBase):
         family = self.__remove_living_from_family(family)
         return family
 
-    def get_event_from_gramps_id(self, val):
-        """
-        Finds an Event in the database from the passed GRAMPS ID.
-        If no such Event exists, None is returned.
-        """
-        return self.db.get_event_from_gramps_id(val)
-
-    def get_place_from_gramps_id(self, val):
-        """
-        Finds a Place in the database from the passed gramps' ID.
-        If no such Place exists, None is returned.
-        """
-        return self.db.get_place_from_gramps_id(val)
-
-    def get_source_from_gramps_id(self, val):
-        """
-        Finds a Source in the database from the passed gramps' ID.
-        If no such Source exists, None is returned.
-        """
-        return self.db.get_source_from_gramps_id(val)
-
-    def get_object_from_gramps_id(self, val):
-        """
-        Finds a MediaObject in the database from the passed gramps' ID.
-        If no such MediaObject exists, None is returned.
-        """
-        return self.db.get_object_from_gramps_id(val)
-
-    def get_repository_from_gramps_id(self, val):
-        """
-        Finds a Repository in the database from the passed gramps' ID.
-        If no such Repository exists, None is returned.
-        """
-        return self.db.get_repository_from_gramps_id(val)
-
-    def get_note_from_gramps_id(self, val):
-        """
-        Finds a Note in the database from the passed gramps' ID.
-        If no such Note exists, None is returned.
-        """
-        return self.db.get_note_from_gramps_id(val)
-
-    def get_person_handles(self, sort_handles=True):
-        """
-        Return a list of database handles, one handle for each Person in
-        the database. If sort_handles is True, the list is sorted by surnames
-        """
-        handles = []
+    def include_person(self, handle):
         if self.mode == self.MODE_EXCLUDE_ALL:
-            for handle in self.db.get_person_handles(sort_handles):
-                person = self.db.get_person_from_handle(handle)
-                if not self.__is_living(person):
-                    handles.append(handle)
-        else:
-            handles = self.db.get_person_handles(sort_handles)
-        return handles
-
-    def get_place_handles(self, sort_handles=True):
-        """
-        Return a list of database handles, one handle for each Place in
-        the database. If sort_handles is True, the list is sorted by
-        Place title.
-        """
-        return self.db.get_place_handles(sort_handles)
-
-    def get_source_handles(self, sort_handles=True):
-        """
-        Return a list of database handles, one handle for each Source in
-        the database. If sort_handles is True, the list is sorted by
-        Source title.
-        """
-        return self.db.get_source_handles(sort_handles)
-
-    def get_media_object_handles(self, sort_handles=True):
-        """
-        Return a list of database handles, one handle for each MediaObject in
-        the database. If sort_handles is True, the list is sorted by title.
-        """
-        return self.db.get_media_object_handles(sort_handles)
-
-    def get_event_handles(self):
-        """
-        Return a list of database handles, one handle for each Event in
-        the database. 
-        """
-        return self.db.get_event_handles()
-
-    def get_family_handles(self):
-        """
-        Return a list of database handles, one handle for each Family in
-        the database.
-        """
-        return self.db.get_family_handles()
-
-    def get_repository_handles(self):
-        """
-        Return a list of database handles, one handle for each Repository in
-        the database.
-        """
-        return self.db.get_repository_handles()
-
-    def get_note_handles(self):
-        """
-        Return a list of database handles, one handle for each Note in
-        the database.
-        """
-        return self.db.get_note_handles()
-
-    def get_researcher(self):
-        """returns the Researcher instance, providing information about
-        the owner of the database"""
-        return self.db.get_researcher()
-
+            person = self.get_unfiltered_person(handle)
+            if person and self.__is_living(person):
+                return False
+        return True        
+        
     def get_default_person(self):
         """returns the default Person of the database"""
         person_handle = self.db.get_default_handle()
@@ -303,52 +156,10 @@ class LivingProxyDb(ProxyDbBase):
             return True
         return False
 
-    def has_event_handle(self, handle):
-        """
-        returns True if the handle exists in the current Event database.
-        """
-        return self.db.has_event_handle(handle)
-
-    def has_source_handle(self, handle):
-        """
-        returns True if the handle exists in the current Source database.
-        """
-        return self.db.has_source_handle(handle)
-
-    def has_place_handle(self, handle):
-        """
-        returns True if the handle exists in the current Place database.
-        """
-        return self.db.has_place_handle(handle)
-
-    def has_family_handle(self, handle):            
-        """
-        returns True if the handle exists in the current Family database.
-        """
-        return self.db.has_family_handle(handle)
-
-    def has_object_handle(self, handle):
-        """
-        returns True if the handle exists in the current MediaObjectdatabase.
-        """
-        return self.db.has_object_handle(handle)
-
-    def has_repository_handle(self, handle):
-        """
-        returns True if the handle exists in the current Repository database.
-        """
-        return self.db.has_repository_handle(handle)
-
-    def has_note_handle(self, handle):
-        """
-        returns True if the handle exists in the current Note database.
-        """
-        return self.db.has_note_handle(handle)
-
     def find_backlink_handles(self, handle, include_classes=None):
         """
         Find all objects that hold a reference to the object handle.
-        Returns an interator over alist of (class_name, handle) tuples.
+        Returns an iterator over a list of (class_name, handle) tuples.
 
         @param handle: handle of the object to search for.
         @type handle: database handle
@@ -356,7 +167,7 @@ class LivingProxyDb(ProxyDbBase):
                                 Default: None means include all classes.
         @type include_classes: list of class names
         
-        This default implementation does a sequencial scan through all
+        This default implementation does a sequential scan through all
         the primary object databases and is very slow. Backends can
         override this method to provide much faster implementations that
         make use of additional capabilities of the backend.
@@ -364,7 +175,7 @@ class LivingProxyDb(ProxyDbBase):
         Note that this is a generator function, it returns a iterator for
         use in loops. If you want a list of the results use:
 
-        >    result_list = [i for i in find_backlink_handles(handle)]
+        >    result_list = list(find_backlink_handles(handle))
         """
         handle_itr = self.db.find_backlink_handles(handle, include_classes)
         for (class_name, handle) in handle_itr:
@@ -381,7 +192,7 @@ class LivingProxyDb(ProxyDbBase):
         Returns False if the person is not considered living.
         """
         return probably_alive( person,
-                               self.db,
+                               self.basedb,
                                self.current_date,
                                self.years_after_death )
     
@@ -399,7 +210,7 @@ class LivingProxyDb(ProxyDbBase):
         father_handle = family.get_father_handle()
         if father_handle:
             father = self.db.get_person_from_handle(father_handle)
-            if  self.__is_living(father):
+            if father and self.__is_living(father):
                 parent_is_living = True
                 if self.mode == self.MODE_EXCLUDE_ALL:
                     family.set_father_handle(None)
@@ -407,7 +218,7 @@ class LivingProxyDb(ProxyDbBase):
         mother_handle = family.get_mother_handle()
         if mother_handle:
             mother = self.db.get_person_from_handle(mother_handle)
-            if self.__is_living(mother):
+            if mother and self.__is_living(mother):
                 parent_is_living = True
                 if self.mode == self.MODE_EXCLUDE_ALL:
                     family.set_mother_handle(None)
@@ -420,7 +231,7 @@ class LivingProxyDb(ProxyDbBase):
             for child_ref in family.get_child_ref_list():
                 child_handle = child_ref.get_reference_handle()
                 child = self.db.get_person_from_handle(child_handle)
-                if self.__is_living(child):
+                if child and self.__is_living(child):
                     family.remove_child_ref(child_ref)
         
         return family
@@ -428,7 +239,7 @@ class LivingProxyDb(ProxyDbBase):
     def __restrict_person(self, person):
         """
         Remove information from a person and replace the first name with 
-        "Living".
+        "[Living]" or what has been set in Preferences -> Text.
         """
         new_person = Person()
         new_name = Name()
@@ -440,7 +251,7 @@ class LivingProxyDb(ProxyDbBase):
         new_name.set_surname_prefix(old_name.get_surname_prefix())
         new_name.set_type(old_name.get_type())
         if self.mode == self.MODE_INCLUDE_LAST_NAME_ONLY:
-            new_name.set_first_name(_(u'Living'))
+            new_name.set_first_name(config.get('preferences.private-given-text'))
         else: # self.mode == self.MODE_INCLUDE_FULL_NAME_ONLY
             new_name.set_first_name(old_name.get_first_name())
             new_name.set_suffix(old_name.get_suffix())
