@@ -2,6 +2,7 @@
 # Gramps - a GTK+/GNOME based genealogy program
 #
 # Copyright (C) 2000-2005  Donald N. Allingham
+# Copyright (C) 2009       Gary Burton
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: callback.py 10874 2008-07-17 18:10:32Z gbritton $
+# $Id: callback.py 16092 2010-10-31 08:38:05Z bmcage $
 
 """
     Introduction
@@ -39,6 +40,7 @@ import sys
 import types
 import traceback
 import inspect
+import copy
 
 log = sys.stderr.write
 
@@ -258,6 +260,8 @@ class Callback(object):
                     # signal name clash
                     sys.stderr.write("Warning: signal name clash: %s\n" % str(k))
                 self.__signal_map[k] = v
+        # Set to None to prevent a memory leak in this recursive function
+        trav = None
 
         # self.__signal_map now contains the connonical list
         # of signals that this instance can emit.
@@ -276,12 +280,13 @@ class Callback(object):
         returns a unique key that can be passed to disconnect().
         """
         # Check that signal exists.
-        if signal_name not in self.__signal_map.keys():
-            self._log("Warning: attempt to connect to unknown signal: %s\n" % str(signal_name))
+        if signal_name not in self.__signal_map:
+            self._log("Warning: attempt to connect to unknown signal: %s\n" 
+                % str(signal_name))
             return
         
         # Add callable to callback_map
-        if signal_name not in self.__callback_map.keys():
+        if signal_name not in self.__callback_map:
             self.__callback_map[signal_name] = []
 
         self._current_key += 1
@@ -298,7 +303,7 @@ class Callback(object):
         """
         
         # Find the key in the callback map.
-        for signal_name in self.__callback_map.keys():
+        for signal_name in self.__callback_map:
             for cb in self.__callback_map[signal_name]:
                 (skey, fn) = cb
                 if skey == key:
@@ -307,8 +312,16 @@ class Callback(object):
                               ": %s with key: %s\n" % (signal_name, 
                                                        str(key)))
                     self.__callback_map[signal_name].remove(cb)
-                    
-                    
+
+    def disconnect_all(self):# Find the key in the callback map.
+        for signal_name in self.__callback_map:
+            keymap = copy.copy(self.__callback_map[signal_name])
+            for key in keymap:
+                self.__callback_map[signal_name].remove(key)
+            self.__callback_map[signal_name] = None
+        self.__callback_map = None
+        del self.__callback_map
+
     def emit(self, signal_name, args=tuple()):
         """
         Emit the signal called signal_name. The args must be a tuple of
@@ -320,7 +333,7 @@ class Callback(object):
             return
         
         # Check signal exists
-        if signal_name not in self.__signal_map.keys():
+        if signal_name not in self.__signal_map:
             self._warn("Attempt to emit to unknown signal: %s\n"
                        "         from: file: %s\n"
                        "               line: %d\n"
@@ -390,8 +403,7 @@ class Callback(object):
                                        % ((str(signal_name), ) + inspect.stack()[1][1:4] +\
                                           (args[i], repr(type(args[i])), repr(arg_types[i]))))                   
                             return 
-
-            if signal_name in self.__callback_map.keys():
+            if signal_name in self.__callback_map:
                 self._log("emitting signal: %s\n" % (signal_name, ))
                 # Don't bother if there are no callbacks.
                 for (key, fn) in self.__callback_map[signal_name]:
@@ -399,7 +411,7 @@ class Callback(object):
                     try:
                         if isinstance(fn, types.FunctionType) or \
                                 isinstance(fn, types.MethodType): # call func
-                            fn(*args)                        
+                            fn(*args)
                         else:
                             self._warn("Badly formed entry in callback map.\n")
                     except:
