@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: configure.py 14347 2010-02-13 04:29:31Z dsblank $
+# $Id: configure.py 16284 2010-12-15 15:46:50Z dsblank $
 
 #-------------------------------------------------------------------------
 #
@@ -1000,7 +1000,7 @@ class GrampsPreferences(ConfigureDialog):
     def select_mediapath(self, *obj):
         f = gtk.FileChooserDialog(
             _("Select media directory"),
-            action=gtk.FILE_CHOOSER_ACTION_CREATE_FOLDER,
+            action=gtk.FILE_CHOOSER_ACTION_SELECT_FOLDER,
             buttons=(gtk.STOCK_CANCEL,
                      gtk.RESPONSE_CANCEL,
                      gtk.STOCK_APPLY,
@@ -1012,7 +1012,7 @@ class GrampsPreferences(ConfigureDialog):
 
         status = f.run()
         if status == gtk.RESPONSE_OK:
-            val = Utils.get_unicode_path(f.get_filename())
+            val = Utils.get_unicode_path_from_file_chooser(f.get_filename())
             if val:
                 self.path_entry.set_text(val)
         f.destroy()
