@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: dbman.py 14886 2010-03-21 09:36:51Z bmcage $
+# $Id: dbman.py 16148 2010-11-06 08:32:30Z bmcage $
 
 """
 Provide the management of databases. This includes opening, renaming,
@@ -68,7 +68,7 @@ import pango
 # gramps modules
 #
 #-------------------------------------------------------------------------
-from QuestionDialog import ErrorDialog, QuestionDialog
+from QuestionDialog import ErrorDialog, QuestionDialog, QuestionDialog2
 from gen.db import DbBsddb
 from gui.pluginmanager import GuiPluginManager
 from cli.clidbman import CLIDbManager, NAME_FILE, time_val
@@ -77,6 +77,7 @@ import RecentFiles
 from glade import Glade
 from gen.db.backup import restore
 from gen.db.exceptions import DbException
+from Utils import get_unicode_path_from_env_var
 
 
 _RETURN = gtk.gdk.keyval_from_name("Return")
@@ -233,7 +234,7 @@ class DbManager(CLIDbManager):
                 self.rcs.set_sensitive(False)
 
         if store.get_value(node, STOCK_COL) == gtk.STOCK_DIALOG_ERROR:
-            path = store.get_value(node, PATH_COL)
+            path = get_unicode_path_from_env_var(store.get_value(node, PATH_COL))
             backup = os.path.join(path, "person.gbkp")
             self.repair.set_sensitive(os.path.isfile(backup))
         else:
@@ -346,8 +347,8 @@ class DbManager(CLIDbManager):
                     self.top.destroy()
                     del self.selection
                     del self.name_renderer
-                    return (store.get_value(node, PATH_COL),
-                            store.get_value(node, NAME_COL))
+                    path = get_unicode_path_from_env_var(store.get_value(node, PATH_COL))
+                    return (path, store.get_value(node, NAME_COL))
             else:
                 self.top.destroy()
                 del self.selection
@@ -381,7 +382,7 @@ class DbManager(CLIDbManager):
         try:
             self.break_lock(self.lock_file)
             store, node = self.selection.get_selected()
-            dbpath = store.get_value(node, PATH_COL)
+            dbpath = get_unicode_path_from_env_var(store.get_value(node, PATH_COL))
             (tval, last) = time_val(dbpath)
             store.set_value(node, OPEN_COL, 0)
             store.set_value(node, STOCK_COL, "")
@@ -510,12 +511,12 @@ class DbManager(CLIDbManager):
         imports it into the db
         """
         new_path, newname = self._create_new_db("%s : %s" % (parent_name, name))
-        
+
         self.__start_cursor(_("Extracting archive..."))
         dbclass = DbBsddb
         dbase = dbclass()
         dbase.load(new_path, None)
-        
+
         self.__start_cursor(_("Importing archive..."))
         check_out(dbase, revision, db_path, None)
         self.__end_cursor()
@@ -626,6 +627,36 @@ class DbManager(CLIDbManager):
         """
         store, node = self.selection.get_selected()
         dirname = store[node][1]
+        
+        #First ask user if he is really sure :-)
+        yes_no = QuestionDialog2(
+            _("Repair family tree?"),
+            _(
+"If you click <b>Proceed</b>, Gramps will attempt to recover your family tree"
+" from the last good backup. There are several ways this can cause unwanted"
+" effects, so <b>backup</b> the family tree first.\n"
+"The Family tree you have selected is stored in %s.\n\n"
+"Before doing a repair, verify that the Family Tree can really no longer be "
+" opened, as the database back-end can recover from some errors automatically.\n\n"
+"<b>Details:</b> Repairing a Family Tree actually uses the last backup of"
+" the Family Tree, which Gramps stored on last use. If you have worked for"
+" several hours/days without closing Gramps, then all this information will"
+" be lost! If the repair fails, then the original family tree will be lost"
+" forever, hence a backup is needed. If the repair fails, or too much"
+" information is lost, you can fix the original family tree manually."
+" For details, see the webpage\n"
+"http://gramps-project.org/wiki/index.php?title=Recover_corrupted_family_tree\n"
+"Before doing a repair, try to open the family tree in the normal manner."
+" Several errors that trigger the repair button can be fixed automatically."
+" If this is the case, you can disable the repair button by removing the"
+" file <i>need_recover</i> in the family tree directory."
+) % dirname,
+            _("Proceed, I have taken a backup"),
+            _("Stop"))
+        prompt = yes_no.run()
+        if not prompt:
+            return
+        
         opened = store[node][5]
         if opened:
             self.dbstate.no_database()
@@ -787,7 +818,7 @@ def check_out(dbase, rev, path, callback):
     Checks out the revision from rcs, and loads the resulting XML file
     into the database.
     """
-    co_cmd   = [ "co", "-x,v", "-q%s" % rev] + [ os.path.join(path, ARCHIVE),
+    co_cmd   = [ "co", "-x,v", "-q%s" % rev] + [ os.path.join(path, ARCHIVE), 
                                                  os.path.join(path, ARCHIVE_V)]
 
     proc = subprocess.Popen(co_cmd, stderr = subprocess.PIPE)
