@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: editfamily.py 14884 2010-03-20 15:23:40Z dsblank $
+# $Id: editfamily.py 17221 2011-04-23 08:54:46Z m_d_n $
 
 #-------------------------------------------------------------------------
 #
@@ -95,8 +95,8 @@ class ChildEmbedList(EmbeddedList):
         'del'   : _('Remove the child from the family'),
         'edit'  : _('Edit the child reference'),
         'share' : _('Add an existing person as a child of the family'),
-        'up'	: _('Move the child up in the childrens list'),
-        'down'	: _('Move the child down in the childrens list'),
+        'up'	: _('Move the child up in the children list'),
+        'down'	: _('Move the child down in the children list'),
         }
 
     _column_names = [
@@ -425,6 +425,15 @@ class EditFamily(EditPrimary):
         else:
             self.add_parent = False
 
+    def _cleanup_on_exit(self):
+        """Unset all things that can block garbage collection.
+        Finalize rest
+        """
+        #FIXME, we rebind show_all below, this prevents garbage collection of
+        #  the dialog, fix the rebind
+        self.window.show_all = None
+        EditPrimary._cleanup_on_exit(self)
+
     def empty_object(self):
         return gen.lib.Family()
 
@@ -940,11 +949,23 @@ class EditFamily(EditPrimary):
             death_str = ""
         death_obj.set_text(death_str)
 
-    def fix_parent_handles(self, orig_handle, new_handle, trans):
+    def fix_parent_handles(self, orig_handle, new_handle, trans, remove_fam=True):
+        """
+        Adjust the reference of the parents to point to the right family.
+
+        The remove_fam parameter is needed for the special case that the
+        original mother is equal to the new father. If that is the case the call
+        to fix the fathers does not add the new family because that family
+        is already present in the family_list. The subsequent call to fix the
+        mothers would remove the family handle with the result that the data
+        is not in a good state: the family points to the person, but the person
+        does not point back to the family.
+        """
         if orig_handle != new_handle:
             if orig_handle:
                 person = self.db.get_person_from_handle(orig_handle)
-                person.family_list.remove(self.obj.handle)
+                if remove_fam:
+                    person.family_list.remove(self.obj.handle)
                 self.db.commit_person(person, trans)
             if new_handle:
                 person = self.db.get_person_from_handle(new_handle)
@@ -1051,10 +1072,12 @@ class EditFamily(EditPrimary):
 
             trans = self.db.transaction_begin()
 
+            remove_fam = not (original.get_mother_handle() ==
+                              self.obj.get_father_handle())
             self.fix_parent_handles(original.get_father_handle(),
                                     self.obj.get_father_handle(), trans)
             self.fix_parent_handles(original.get_mother_handle(),
-                                    self.obj.get_mother_handle(), trans)
+                                self.obj.get_mother_handle(), trans, remove_fam)
 
             orig_set = set(original.get_child_ref_list())
             new_set = set(self.obj.get_child_ref_list())
