@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: BookReport.py 14627 2010-03-05 15:24:47Z bmcage $
+# $Id: BookReport.py 15468 2010-05-24 01:41:21Z dsblank $
 
 # Written by Alex Roitman, 
 # largely based on the BaseDoc classes by Don Allingham
@@ -812,7 +812,7 @@ class BookReportSelector(ManagedWindow.ManagedWindow):
                 if menu_option:
                     menu_option.set_value(opt_dict[optname])
             
-            _initialize_options(item.option_class, self.dbstate)
+            _initialize_options(item.option_class, self.dbstate, self.uistate)
             item.set_style_name(saved_item.get_style_name())
             self.book.append_item(item)
             
