@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: AncestorTree.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: AncestorTree.py 15703 2010-08-11 07:02:14Z ldnp $
 
 """Reports/Graphical Reports/Ancestor Tree"""
 
@@ -236,7 +236,7 @@ class AncestorTree(Report):
         self.text[index] = subst.replace_and_clean(self.display)
 
         for line in self.text[index]:
-            this_box_width = self.doc.string_width(font,line)
+            this_box_width = self.doc.string_width(font,line) + (2 * em)
             self.box_width = max(self.box_width, this_box_width)
 
         self.lines = max(self.lines, len(self.text[index]))    
