@@ -16,14 +16,16 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
-
+#
+# $Id: Calendar.py 14185 2010-02-01 23:07:44Z robhealey1 $
+#
 #------------------------------------------------------------------------
 #
 # python modules
 #
 #------------------------------------------------------------------------
-from gettext import gettext as _
-from gettext import ngettext
+from gen.ggettext import gettext as _
+from gen.ggettext import ngettext
 import datetime
 import time
 
@@ -32,16 +34,21 @@ import time
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-import BaseDoc
-from BasicUtils import name_displayer
-from gen.plug import PluginManager
-from ReportBase import Report, ReportUtils, MenuReportOptions, CATEGORY_DRAW
-from gen.plug.menu import BooleanOption, StringOption, NumberOption, \
-                         EnumeratedListOption, FilterOption, PersonOption
+from gen.display.name import displayer as _nd 
+from Errors import ReportError
+import Relationship
+from gen.plug.docgen import (FontStyle, ParagraphStyle, GraphicsStyle,
+                             FONT_SERIF, PARA_ALIGN_CENTER,
+                             PARA_ALIGN_LEFT, PARA_ALIGN_RIGHT)
+from gen.plug.docgen.fontscale import string_trim
+from gen.plug.menu import (BooleanOption, StringOption, NumberOption, 
+                         EnumeratedListOption, FilterOption, PersonOption)
+from gui.utils import ProgressMeter
+from ReportBase import Report, ReportUtils, MenuReportOptions
+from Utils import probably_alive
+from DateHandler import displayer as _dd
 import GrampsLocale
 import gen.lib
-from Utils import probably_alive, ProgressMeter
-from FontScale import string_trim
 
 import libholiday
 from libholiday import g2iso
@@ -82,6 +89,8 @@ class Calendar(Report):
         self.filter = self.filter_option.get_filter()
         pid = menu.get_option_by_name('pid').get_value()
         self.center_person = database.get_person_from_gramps_id(pid)
+        if (self.center_person == None) :
+            raise ReportError(_("Person %s is not in the Database") % pid )
 
     def get_name(self, person, maiden_name = None):
         """ Return person's name, unless maiden_name given, 
@@ -105,7 +114,7 @@ class Calendar(Report):
         else:
             name = gen.lib.Name(primary_name)
         name.set_display_as(self.name_format)
-        return name_displayer.display_name(name)
+        return _nd.display_name(name)
         
     def draw_rectangle(self, style, sx, sy, ex, ey):
         """ This should be in BaseDoc """
@@ -173,7 +182,7 @@ class Calendar(Report):
         self.doc.draw_box("CAL-Title", "", 0, 0, width, header)
         self.doc.draw_line("CAL-Border", 0, header, width, header)
         year = self.year
-        title = "%s %d" % (GrampsLocale.long_months[month].capitalize(), year)
+        title = "%s %d" % (_dd.long_months[month].capitalize(), year)
         font_height = pt2cm(ptitle.get_font().get_size())
         self.doc.center_text("CAL-Title", title, width/2, font_height * 0.25)
         cell_width = width / 7
@@ -240,11 +249,10 @@ class Calendar(Report):
         This method runs through the data, and collects the relevant dates
         and text.
         """
-        people = self.database.get_person_handles(sort_handles=False)
-        self.progress.set_pass(_('Applying Filter...'), len(people))
+        people = self.database.iter_person_handles()
+        self.progress.set_pass(_('Applying Filter...'), self.database.get_number_of_people())
         people = self.filter.apply(self.database, people, self.progress)
-        pmgr = PluginManager.get_instance()
-        rel_calc = pmgr.get_relationship_calculator()
+        rel_calc = Relationship.get_relationship_calculator()
 
         self.progress.set_pass(_('Reading database...'), len(people))
         for person_handle in people:
@@ -397,7 +405,7 @@ class CalendarOptions(MenuReportOptions):
 
         # We must figure out the value of the first option before we can
         # create the EnumeratedListOption
-        fmt_list = name_displayer.get_name_format()
+        fmt_list = _nd.get_name_format()
         name_format = EnumeratedListOption(_("Name format"), fmt_list[0][0])
         for num, name, fmt_str, act in fmt_list:
             name_format.add_item(num, name)
@@ -450,7 +458,7 @@ class CalendarOptions(MenuReportOptions):
         text1.set_help(_("First line of text at bottom of calendar"))
         menu.add_option(category_name, "text1", text1)
 
-        text2 = StringOption(_("Text Area 2"), _("Produced with GRAMPS"))
+        text2 = StringOption(_("Text Area 2"), _("Produced with Gramps"))
         text2.set_help(_("Second line of text at bottom of calendar"))
         menu.add_option(category_name, "text2", text2)
 
@@ -468,17 +476,17 @@ class CalendarOptions(MenuReportOptions):
         self.__filter.set_filters(filter_list)
 
     def make_my_style(self, default_style, name, description, 
-                      size=9, font=BaseDoc.FONT_SERIF, justified ="left", 
-                      color=None, align=BaseDoc.PARA_ALIGN_CENTER, 
+                      size=9, font=FONT_SERIF, justified ="left", 
+                      color=None, align=PARA_ALIGN_CENTER, 
                       shadow = None, italic=0, bold=0, borders=0, indent=None):
         """ Create paragraph and graphic styles of the same name """
         # Paragraph:
-        f = BaseDoc.FontStyle()
+        f = FontStyle()
         f.set_size(size)
         f.set_type_face(font)
         f.set_italic(italic)
         f.set_bold(bold)
-        p = BaseDoc.ParagraphStyle()
+        p = ParagraphStyle()
         p.set_font(f)
         p.set_alignment(align)
         p.set_description(description)
@@ -489,14 +497,14 @@ class CalendarOptions(MenuReportOptions):
         if indent:
             p.set(first_indent=indent)
         if justified == "left":
-            p.set_alignment(BaseDoc.PARA_ALIGN_LEFT)       
+            p.set_alignment(PARA_ALIGN_LEFT)       
         elif justified == "right":
-            p.set_alignment(BaseDoc.PARA_ALIGN_RIGHT)       
+            p.set_alignment(PARA_ALIGN_RIGHT)       
         elif justified == "center":
-            p.set_alignment(BaseDoc.PARA_ALIGN_CENTER)       
+            p.set_alignment(PARA_ALIGN_CENTER)       
         default_style.add_paragraph_style(name, p)
         # Graphics:
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style(name)
         if shadow:
             g.set_shadow(*shadow)
@@ -529,25 +537,3 @@ class CalendarOptions(MenuReportOptions):
                            _('Text at bottom, line 3'), 9)
         self.make_my_style(default_style, "CAL-Border", 
                            _('Borders'), borders=True)
-
-#------------------------------------------------------------------------
-#
-# Register the plugins
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_report(
-    name = 'calendar', 
-    category = CATEGORY_DRAW, 
-    report_class = Calendar, 
-    options_class = CalendarOptions, 
-    modes = PluginManager.REPORT_MODE_GUI | \
-            PluginManager.REPORT_MODE_BKI | \
-            PluginManager.REPORT_MODE_CLI, 
-    translated_name = _("Calendar"), 
-    status = _("Stable"), 
-    author_name = "Douglas S. Blank", 
-    author_email = "dblank@cs.brynmawr.edu", 
-    description = _("Produces a graphical calendar"), 
-    )
-
