@@ -20,9 +20,8 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# To see things still missing, search for "TODO"...
 #
-# $Id: StatisticsChart.py 13410 2009-10-25 16:51:15Z bmcage $
+# $Id: StatisticsChart.py 14158 2010-01-28 19:35:51Z gbritton $
 
 """Reports/Graphical Reports/Statistics Report"""
 
@@ -32,7 +31,7 @@
 #
 #------------------------------------------------------------------------
 import time
-from TransUtils import sgettext as _
+from gen.ggettext import sgettext as _
 
 #------------------------------------------------------------------------
 #
@@ -42,21 +41,248 @@ from TransUtils import sgettext as _
 
 # Person and relation types
 from gen.lib import Person, FamilyRelType, EventType, EventRoleType
+from gen.lib.date import Date
 # gender and report type names
-import BaseDoc
-from gen.plug import PluginManager
+from gen.plug.docgen import (FontStyle, ParagraphStyle, GraphicsStyle,
+                            FONT_SANS_SERIF, FONT_SERIF,
+                            PARA_ALIGN_CENTER, PARA_ALIGN_LEFT)
 from gen.plug.menu import BooleanOption, NumberOption, EnumeratedListOption, \
                          FilterOption, PersonOption
-from ReportBase import Report, ReportUtils, MenuReportOptions, CATEGORY_DRAW
+from ReportBase import Report, ReportUtils, MenuReportOptions
 import DateHandler
-from Utils import ProgressMeter
+from gui.utils import ProgressMeter
+
+#------------------------------------------------------------------------
+#
+# Private Functions
+#
+#------------------------------------------------------------------------
+def draw_wedge(doc,  style,  centerx,  centery,  radius,  start_angle, 
+               end_angle,  short_radius=0):
+    from math import pi, cos, sin
+    
+    while end_angle < start_angle:
+        end_angle += 360
+
+    p = []
+    
+    degreestoradians = pi / 180.0
+    radiansdelta = degreestoradians / 2
+    sangle = start_angle * degreestoradians
+    eangle = end_angle * degreestoradians
+    while eangle < sangle:
+        eangle = eangle + 2 * pi
+    angle = sangle
+
+    if short_radius == 0:
+        if (end_angle - start_angle) != 360:
+            p.append((centerx, centery))
+    else:
+        origx = (centerx + cos(angle) * short_radius)
+        origy = (centery + sin(angle) * short_radius)
+        p.append((origx, origy))
+        
+    while angle < eangle:
+        x = centerx + cos(angle) * radius
+        y = centery + sin(angle) * radius
+        p.append((x, y))
+        angle = angle + radiansdelta
+    x = centerx + cos(eangle) * radius
+    y = centery + sin(eangle) * radius
+    p.append((x, y))
+
+    if short_radius:
+        x = centerx + cos(eangle) * short_radius
+        y = centery + sin(eangle) * short_radius
+        p.append((x, y))
+
+        angle = eangle
+        while angle >= sangle:
+            x = centerx + cos(angle) * short_radius
+            y = centery + sin(angle) * short_radius
+            p.append((x, y))
+            angle -= radiansdelta
+    doc.draw_path(style, p)
+
+    delta = (eangle - sangle) / 2.0
+    rad = short_radius + (radius - short_radius) / 2.0
+
+    return ( (centerx + cos(sangle + delta) * rad), 
+             (centery + sin(sangle + delta) * rad))
+
+
+def draw_pie_chart(doc, center_x, center_y, radius, data, start=0):
+    """
+    Draws a pie chart in the specified document. The data passed is plotted as
+    a pie chart. The data should consist of the actual data. Percentages of
+    each slice are determined by the routine.
+
+    @param doc: Document to which the pie chart should be added
+    @type doc: BaseDoc derived class
+    @param center_x: x coordinate in centimeters where the center of the pie
+       chart should be. 0 is the left hand edge of the document.
+    @type center_x: float
+    @param center_y: y coordinate in centimeters where the center of the pie
+       chart should be. 0 is the top edge of the document
+    @type center_y: float
+    @param radius: radius of the pie chart. The pie charts width and height
+       will be twice this value.
+    @type radius: float
+    @param data: List of tuples containing the data to be plotted. The values
+       are (graphics_format, value), where graphics_format is a BaseDoc
+       GraphicsStyle, and value is a floating point number. Any other items in
+       the tuple are ignored. This allows you to share the same data list with
+       the L{draw_legend} function.
+    @type data: list
+    @param start: starting point in degrees, where the default of 0 indicates
+       a start point extending from the center to right in a horizontal line.
+    @type start: float
+    """
+
+    total = 0.0
+    for item in data:
+        total += item[1]
+
+    for item in data:
+        incr = 360.0*(item[1]/total)
+        draw_wedge(doc, item[0], center_x, center_y, radius, start, start + incr)
+        start += incr
+
+def draw_legend(doc, start_x, start_y, data, title, label_style):
+    """
+    Draws a legend for a graph in the specified document. The data passed is
+    used to define the legend.  First item style is used for the optional
+    Legend title.
+
+    @param doc: Document to which the legend chart should be added
+    @type doc: BaseDoc derived class
+    @param start_x: x coordinate in centimeters where the left hand corner
+        of the legend is placed. 0 is the left hand edge of the document.
+    @type start_x: float
+    @param start_y: y coordinate in centimeters where the top of the legend
+        should be. 0 is the top edge of the document
+    @type start_y: float
+    @param data: List of tuples containing the data to be used to create the
+       legend. In order to be compatible with the graph plots, the first and
+       third values of the tuple used. The format is (graphics_format, value, 
+       legend_description).
+    @type data: list
+    """
+    style_sheet = doc.get_style_sheet()
+    if title:
+        gstyle = style_sheet.get_draw_style(label_style)
+        pstyle_name = gstyle.get_paragraph_style()
+        pstyle = style_sheet.get_paragraph_style(pstyle_name)
+        size = ReportUtils.pt2cm(pstyle.get_font().get_size())
+        doc.draw_text(label_style, title, start_x + (3*size), start_y - (size*0.25))
+        start_y += size * 1.3
+    
+    for (format, size, legend) in data:
+        gstyle = style_sheet.get_draw_style(format)
+        pstyle_name = gstyle.get_paragraph_style()
+        pstyle = style_sheet.get_paragraph_style(pstyle_name)
+        size = ReportUtils.pt2cm(pstyle.get_font().get_size())
+        doc.draw_box(format, "", start_x, start_y, (2*size), size)
+        doc.draw_text(label_style, legend, start_x + (3*size), start_y - (size*0.25))
+        start_y += size * 1.3
+
+_t = time.localtime(time.time())
+_TODAY = DateHandler.parser.parse("%04d-%02d-%02d" % _t[:3])
+
+def estimate_age(db, person, end_handle=None, start_handle=None, today=_TODAY):
+    """
+    Estimates the age of a person based off the birth and death
+    dates of the person. A tuple containing the estimated upper
+    and lower bounds of the person's age is returned. If either
+    the birth or death date is missing, a (-1, -1) is returned.
+    
+    @param db: GRAMPS database to which the Person object belongs
+    @type db: DbBase
+    @param person: Person object to calculate the age of
+    @type person: Person
+    @param end_handle: Determines the event handle that determines
+       the upper limit of the age. If None, the death event is used
+    @type end_handle: str
+    @param start_handle: Determines the event handle that determines
+       the lower limit of the event. If None, the birth event is
+       used
+    @type start_handle: str
+    @returns: tuple containing the lower and upper bounds of the
+       person's age, or (-1, -1) if it could not be determined.
+    @rtype: tuple
+    """
+
+    bhandle = None
+    if start_handle:
+        bhandle = start_handle
+    else:
+        bref = person.get_birth_ref()
+        if bref:
+            bhandle = bref.get_reference_handle()
+
+    dhandle = None
+    if end_handle:
+        dhandle = end_handle
+    else:
+        dref = person.get_death_ref()
+        if dref:
+            dhandle = dref.get_reference_handle()
+
+    # if either of the events is not defined, return an error message
+    if not bhandle:
+        return (-1, -1)
+
+    bdata = db.get_event_from_handle(bhandle).get_date_object()
+    if dhandle:
+        ddata = db.get_event_from_handle(dhandle).get_date_object()
+    else:
+        if today is not None:
+            ddata = today
+        else:
+            return (-1, -1)
+
+    # if the date is not valid, return an error message
+    if not bdata.get_valid() or not ddata.get_valid():
+        return (-1, -1)
+
+    # if a year is not valid, return an error message
+    if not bdata.get_year_valid() or not ddata.get_year_valid():
+        return (-1, -1)
+
+    bstart = bdata.get_start_date()
+    bstop  = bdata.get_stop_date()
+
+    dstart = ddata.get_start_date()
+    dstop  = ddata.get_stop_date()
+
+    def _calc_diff(low, high):
+        if (low[1], low[0]) > (high[1], high[0]):
+            return high[2] - low[2] - 1
+        else:
+            return high[2] - low[2]
+
+    if bstop == dstop == Date.EMPTY:
+        lower = _calc_diff(bstart, dstart)
+        age = (lower, lower)
+    elif bstop == Date.EMPTY:
+        lower = _calc_diff(bstart, dstart)
+        upper = _calc_diff(bstart, dstop)
+        age = (lower, upper)
+    elif dstop == Date.EMPTY:
+        lower = _calc_diff(bstop, dstart)
+        upper = _calc_diff(bstart, dstart)
+        age = (lower, upper)
+    else:
+        lower = _calc_diff(bstop, dstart)
+        upper = _calc_diff(bstart, dstop)
+        age = (lower, upper)
+    return age
 
 #------------------------------------------------------------------------
 #
 # Global options and their names
 #
 #------------------------------------------------------------------------
-
 class _options:
     # sort type identifiers
     SORT_VALUE = 0
@@ -179,7 +405,7 @@ class Extract(object):
         if date:
             month = date.get_month()
             if month:
-                return [DateHandler.displayer._months[month]]
+                return [DateHandler.displayer.long_months[month]]
         return [_("Date(s) missing")]
 
     def get_place(self, event):
@@ -222,10 +448,8 @@ class Extract(object):
 
     def get_event_ages(self, data):
         "return ages at given (person,event_handles)"
-        ages = []
         person, event_handles = data
-        for event_handle in event_handles:
-            ages.append(self.estimate_age(person, event_handle))
+        ages = [self.estimate_age(person, h) for h in event_handles]
         if ages:
             return ages
         return [_("Events missing")]
@@ -283,7 +507,7 @@ class Extract(object):
     def estimate_age(self, person, end=None, begin=None):
         """return estimated age (range) for given person or error message.
            age string is padded with spaces so that it can be sorted"""
-        age = ReportUtils.estimate_age(self.db, person, end, begin)
+        age = estimate_age(self.db, person, end, begin)
         if age[0] < 0 or age[1] < 0:
             # inadequate information
             return _("Date(s) missing")
@@ -356,9 +580,7 @@ class Extract(object):
 
     def get_event_handles(self, person):
         "return list of event handles for given person or None"
-        events = []
-        for event_ref in person.get_event_ref_list():
-            events.append(event_ref.ref)
+        events = [ref.ref for ref in person.get_event_ref_list()]
 
         if events:
             return (person, events)
@@ -381,7 +603,7 @@ class Extract(object):
                 value = [_("Personal information missing")]
             # list of information found
             for key in value:
-                if key in chart[1].keys():
+                if key in chart[1]:
                     chart[1][key] += 1
                 else:
                     chart[1][key] = 1
@@ -410,14 +632,14 @@ class Extract(object):
         data = []
         ext = self.extractors
         # which methods to use
-        for name in self.extractors.keys():
+        for name in self.extractors:
             option = menu.get_option_by_name(name)
             if option.get_value() == True:
                 # localized data title, value dict, type and data method
                 data.append((ext[name][1], {}, ext[name][2], ext[name][3]))
         
         # go through the people and collect data
-        for person_handle in filter_func.apply(db, db.get_person_handles(sort_handles=False)):
+        for person_handle in filter_func.apply(db, db.iter_person_handles()):
 
             person = db.get_person_from_handle(person_handle)
             # check whether person has suitable gender
@@ -536,19 +758,15 @@ class StatisticsChart(Report):
         """creates & stores a sorted index for the items"""
 
         # sort by item keys
-        index = data.keys()
-        index.sort()
-        if reverse:
-            index.reverse()
+        index = sorted(data, reverse=True if reverse else False)
 
         if sort == _options.SORT_VALUE:
             # set for the sorting function
             self.lookup_items = data
         
             # then sort by value
-            index.sort(self.lookup_compare)
-            if reverse:
-                index.reverse()
+            index.sort(self.lookup_compare, 
+                reverse=True if reverse else False)
 
         return index
 
@@ -559,9 +777,9 @@ class StatisticsChart(Report):
         for data in self.data:
             self.doc.start_page()
             if len(data[2]) < self.bar_items:
-                self.output_piechart(data[0], data[1], data[2], data[3])
+                self.output_piechart(*data[:4])
             else:
-                self.output_barchart(data[0], data[1], data[2], data[3])
+                self.output_barchart(*data[:4])
             self.doc.end_page()
         self.progress.step()
         self.progress.close()
@@ -595,15 +813,15 @@ class StatisticsChart(Report):
     
         # output data...
         radius = middle - 2*margin
-        yoffset = yoffset + margin + radius
-        ReportUtils.draw_pie_chart(self.doc, middle_w, yoffset, radius, chart_data, -90)
-        yoffset = yoffset + radius + 2*margin
+        yoffset += margin + radius
+        draw_pie_chart(self.doc, middle_w, yoffset, radius, chart_data, -90)
+        yoffset += radius + 2*margin
         if middle == middle_h:   # Landscape
             legendx = 1.0
             yoffset = margin
     
         text = _("%s (persons):") % typename
-        ReportUtils.draw_legend(self.doc, legendx, yoffset, chart_data, text,'SC-legend')
+        draw_legend(self.doc, legendx, yoffset, chart_data, text,'SC-legend')
 
 
     def output_barchart(self, title, typename, data, lookup):
@@ -620,9 +838,7 @@ class StatisticsChart(Report):
         pad =  row_h * 0.5
         
         # check maximum value
-        max_value = 0
-        for key in lookup:
-            max_value = max(data[key], max_value)
+        max_value = max(data[k] for k in lookup) if lookup else 0
         # horizontal area for the gfx bars
         margin = 1.0
         middle = width/2.0
@@ -681,12 +897,12 @@ class StatisticsChartOptions(MenuReportOptions):
         
         self.__filter = FilterOption(_("Filter"), 0)
         self.__filter.set_help(
-                         _("Determines what people are included in the report"))
+                         _("Determines what people are included in the report."))
         menu.add_option(category_name, "filter", self.__filter)
         self.__filter.connect('value-changed', self.__filter_changed)
         
         self.__pid = PersonOption(_("Filter Person"))
-        self.__pid.set_help(_("The center person for the filter"))
+        self.__pid.set_help(_("The center person for the filter."))
         menu.add_option(category_name, "pid", self.__pid)
         self.__pid.connect('value-changed', self.__update_filters)
         
@@ -707,7 +923,7 @@ class StatisticsChartOptions(MenuReportOptions):
         this_year = time.localtime()[0]
         year_from = NumberOption(_("People Born After"), 
                                  1700, 1, this_year)
-        year_from.set_help(_("Birth year from which to include people"))
+        year_from.set_help(_("Birth year from which to include people."))
         menu.add_option(category_name,"year_from", year_from)
         
         year_to = NumberOption(_("People Born Before"), 
@@ -718,7 +934,7 @@ class StatisticsChartOptions(MenuReportOptions):
         no_years = BooleanOption(_("Include people without known birth years"), 
                                  False)
         no_years.set_help(_("Whether to include people without "
-                            "known birth years"))
+                            "known birth years."))
         menu.add_option(category_name,"no_years", no_years)
 
         gender = EnumeratedListOption(_('Genders included'),
@@ -747,7 +963,7 @@ class StatisticsChartOptions(MenuReportOptions):
                 category_name = _("Charts 2")
             
             opt = BooleanOption(_Extract.extractors[key][1], False)
-            opt.set_help(_("Include charts with indicated data"))
+            opt.set_help(_("Include charts with indicated data."))
             menu.add_option(category_name,key, opt)
             idx += 1
         
@@ -781,21 +997,21 @@ class StatisticsChartOptions(MenuReportOptions):
     def make_default_style(self, default_style):
         """Make the default output style for the Statistics report."""
         # Paragraph Styles
-        f = BaseDoc.FontStyle()
+        f = FontStyle()
         f.set_size(10)
-        f.set_type_face(BaseDoc.FONT_SERIF)
-        p = BaseDoc.ParagraphStyle()
+        f.set_type_face(FONT_SERIF)
+        p = ParagraphStyle()
         p.set_font(f)
-        p.set_alignment(BaseDoc.PARA_ALIGN_LEFT)
+        p.set_alignment(PARA_ALIGN_LEFT)
         p.set_description(_("The style used for the items and values."))
         default_style.add_paragraph_style("SC-Text",p)
 
-        f = BaseDoc.FontStyle()
+        f = FontStyle()
         f.set_size(14)
-        f.set_type_face(BaseDoc.FONT_SANS_SERIF)
-        p = BaseDoc.ParagraphStyle()
+        f.set_type_face(FONT_SANS_SERIF)
+        p = ParagraphStyle()
         p.set_font(f)
-        p.set_alignment(BaseDoc.PARA_ALIGN_CENTER)
+        p.set_alignment(PARA_ALIGN_CENTER)
         p.set_description(_("The style used for the title of the page."))
         default_style.add_paragraph_style("SC-Title",p)
         
@@ -808,14 +1024,14 @@ class StatisticsChartOptions(MenuReportOptions):
             SC-color-N - The colors for drawing pies.
             SC-bar - A red bar with 0.5pt black line.
         """
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style("SC-Title")
         g.set_color((0,0,0))
         g.set_fill_color((255,255,255))
         g.set_line_width(0)
         default_style.add_draw_style("SC-title",g)
 
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style("SC-Text")
         g.set_color((0,0,0))
         g.set_fill_color((255,255,255))
@@ -824,88 +1040,65 @@ class StatisticsChartOptions(MenuReportOptions):
 
         width = 0.8
         # red
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style('SC-Text')
         g.set_color((0,0,0))
         g.set_fill_color((255,0,0))
         g.set_line_width(width)
         default_style.add_draw_style("SC-color-0",g)
         # orange
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style('SC-Text')
         g.set_color((0,0,0))
         g.set_fill_color((255,158,33))
         g.set_line_width(width)
         default_style.add_draw_style("SC-color-1",g)
         # green
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style('SC-Text')
         g.set_color((0,0,0))
         g.set_fill_color((0,178,0))
         g.set_line_width(width)
         default_style.add_draw_style("SC-color-2",g)
         # violet
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style('SC-Text')
         g.set_color((0,0,0))
         g.set_fill_color((123,0,123))
         g.set_line_width(width)
         default_style.add_draw_style("SC-color-3",g)
         # yellow
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style('SC-Text')
         g.set_color((0,0,0))
         g.set_fill_color((255,255,0))
         g.set_line_width(width)
         default_style.add_draw_style("SC-color-4",g)
         # blue
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style('SC-Text')
         g.set_color((0,0,0))
         g.set_fill_color((0,105,214))
         g.set_line_width(width)
         default_style.add_draw_style("SC-color-5",g)
         # gray
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style('SC-Text')
         g.set_color((0,0,0))
         g.set_fill_color((210,204,210))
         g.set_line_width(width)
         default_style.add_draw_style("SC-color-6",g)
 
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_color((0,0,0))
         g.set_fill_color((255,0,0))
         g.set_line_width(width)
         default_style.add_draw_style("SC-bar",g)
 
         # legend
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style('SC-Text')
         g.set_color((0,0,0))
         g.set_fill_color((255,255,255))
         g.set_line_width(0)
         default_style.add_draw_style("SC-legend",g)
-
-#------------------------------------------------------------------------
-#
-# Register report/options
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_report(
-    name = 'statistics_chart',
-    category = CATEGORY_DRAW,
-    report_class = StatisticsChart,
-    options_class = StatisticsChartOptions,
-    modes = PluginManager.REPORT_MODE_GUI | \
-            PluginManager.REPORT_MODE_BKI | \
-            PluginManager.REPORT_MODE_CLI,
-    translated_name = _("Statistics Charts"),
-    status = _("Stable"),
-    author_name = "Eero Tamminen",
-    author_email = "",
-    description = _("Produces statistical bar and pie charts of the people "
-                    "in the database"),
-    require_active = False,
-    )
