@@ -19,7 +19,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: ExportCsv.py 12842 2009-07-28 04:28:12Z pez4brian $
+# $Id: ExportCsv.py 14396 2010-02-16 02:18:24Z dsblank $
 
 "Export to CSV Spreadsheet."
 
@@ -29,25 +29,18 @@
 #
 #-------------------------------------------------------------------------
 import os
-from TransUtils import sgettext as _
+from gen.ggettext import sgettext as _
 import csv
 import cStringIO
 import codecs
 
-#-------------------------------------------------------------------------
-#
-# GNOME/GTK modules
-#
-#-------------------------------------------------------------------------
-from gtk import glade
-
 #------------------------------------------------------------------------
 #
 # Set up logging
 #
 #------------------------------------------------------------------------
 import logging
-log = logging.getLogger(".ExportCSV")
+LOG = logging.getLogger(".ExportCSV")
 
 #-------------------------------------------------------------------------
 #
@@ -55,12 +48,12 @@ log = logging.getLogger(".ExportCSV")
 #
 #-------------------------------------------------------------------------
 import gen.lib
-from Filters import GenericFilter, Rules, build_filter_menu
+from Filters import GenericFilter, Rules, build_filter_model
 import Utils
 from QuestionDialog import ErrorDialog
-from gen.plug import PluginManager, ExportPlugin
 import gen.proxy
 import DateHandler
+from glade import Glade
 
 #-------------------------------------------------------------------------
 #
@@ -147,8 +140,7 @@ class UnicodeWriter(object):
         self.queue.truncate(0)
 
     def writerows(self, rows):
-        for row in rows:
-            self.writerow(row)
+        map(self.writerow, rows)
 
     def close(self):
         self.stream.close()
@@ -172,10 +164,8 @@ class CSVWriterOptionBox(object):
         self.translate_headers = 1
 
     def get_option_box(self):
-        glade_file = os.path.join(os.path.dirname(__file__), "ExportCsv.glade")
-
-        self.topDialog = glade.XML(glade_file,"csvExport","gramps")
-        filter_obj = self.topDialog.get_widget("filter")
+        self.topDialog = Glade()
+        self.filters = self.topDialog.get_object("filter")
 
         all = GenericFilter()
         all.set_name(_("Entire Database"))
@@ -206,21 +196,22 @@ class CSVWriterOptionBox(object):
 
         from Filters import CustomFilters
         the_filters.extend(CustomFilters.get_filters('Person'))
-        self.filter_menu = build_filter_menu(the_filters)
-        filter_obj.set_menu(self.filter_menu)
+        self.filter_menu = build_filter_model(the_filters)
+        self.filters.set_model(self.filter_menu)
+        self.filters.set_active(0)
 
-        the_box = self.topDialog.get_widget('vbox1')
-        the_parent = self.topDialog.get_widget('dialog-vbox1')
+        the_box = self.topDialog.get_object('vbox1')
+        the_parent = self.topDialog.get_object('dialog-vbox1')
         the_parent.remove(the_box)
-        self.topDialog.get_widget("csvExport").destroy()
+        self.topDialog.toplevel.destroy()
         return the_box
 
     def parse_options(self):
-        self.include_individuals = self.topDialog.get_widget("individuals").get_active()
-        self.include_marriages = self.topDialog.get_widget("marriages").get_active()
-        self.include_children = self.topDialog.get_widget("children").get_active()
-        self.translate_headers = self.topDialog.get_widget("translate_headers").get_active()
-        self.cfilter = self.filter_menu.get_active().get_data("filter")
+        self.include_individuals = self.topDialog.get_object("individuals").get_active()
+        self.include_marriages = self.topDialog.get_object("marriages").get_active()
+        self.include_children = self.topDialog.get_object("children").get_active()
+        self.translate_headers = self.topDialog.get_object("translate_headers").get_active()
+        self.cfilter = self.filter_menu[self.filters.get_active()][1]
 
 #-------------------------------------------------------------------------
 #
@@ -261,8 +252,8 @@ class CSVWriter(object):
             if not option_box.cfilter.is_empty():
                 self.db = gen.proxy.FilterProxyDb(self.db, option_box.cfilter)
 
-        for p in self.db.get_person_handles(sort_handles=False):
-            self.plist[p] = 1
+        self.plist.update([p, 1] for p in self.db.iter_person_handles())
+
         # get the families for which these people are spouses:
         self.flist = {}
         for key in self.plist:
@@ -270,12 +261,12 @@ class CSVWriter(object):
             for family_handle in p.get_family_handle_list():
                 self.flist[family_handle] = 1
         # now add the families for which these people are a child:
-        family_handles = self.db.get_family_handles()
+        family_handles = self.db.iter_family_handles()
         for family_handle in family_handles:
             family = self.db.get_family_from_handle(family_handle)
             for child_ref in family.get_child_ref_list():
                 child_handle = child_ref.ref
-                if child_handle in self.plist.keys():
+                if child_handle in self.plist:
                     self.flist[family_handle] = 1
                         
     def update_empty(self):
@@ -318,8 +309,8 @@ class CSVWriter(object):
         if self.include_children:
             self.total += len(self.flist)
         ######################## 
-        print "Possible people to export:", len(self.plist)
-        print "Possible families to export:", len(self.flist)
+        LOG.debug("Possible people to export: %s", len(self.plist))
+        LOG.debug("Possible families to export: %s", len(self.flist))
         ########################### sort:
         sortorder = []
         for key in self.plist:
@@ -406,7 +397,9 @@ class CSVWriter(object):
             family = self.db.get_family_from_handle(key)
             if family:
                 marriage_id = family.get_gramps_id()
-                sortorder.append( (sortable_string_representation(marriage_id), key) )
+                sortorder.append(
+                    (sortable_string_representation(marriage_id), key)
+                    )
         sortorder.sort() # will sort on tuples
         flist = [data[1] for data in sortorder]
         ########################### 
@@ -480,20 +473,3 @@ class CSVWriter(object):
     
     def format_date(self, date):
         return DateHandler.get_date(date)
-
-#-------------------------------------------------------------------------
-#
-# Register the plugin
-#
-#-------------------------------------------------------------------------
-_name = _('Comma _Separated Values Spreadsheet (CSV)')
-_description = _('CSV is a common spreadsheet format.')
-_config = (_('CSV spreadsheet options'),CSVWriterOptionBox)
-
-pmgr = PluginManager.get_instance()
-plugin = ExportPlugin(name            = _name, 
-                      description     = _description,
-                      export_function = exportData,
-                      extension       = "csv",
-                      config          = _config )
-pmgr.register_plugin(plugin)
