@@ -20,7 +20,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-# $Id: ExportGedcom.py 16031 2010-10-24 07:20:15Z romjerome $
+# $Id: ExportGedcom.py 16240 2010-11-30 14:31:16Z dsblank $
 
 "Export to GEDCOM"
 
@@ -328,6 +328,8 @@ class GedcomWriter(UpdateCallback):
         assert(token)
         if textlines:
             # break the line into multiple lines if a newline is found
+            textlines = textlines.replace('\n\r', '\n')
+            textlines = textlines.replace('\r', '\n')
             textlist = textlines.split('\n')
             token_level = level
             for text in textlist:
