@@ -22,7 +22,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ExportXml.py 15692 2010-08-09 13:17:38Z dsblank $
+# $Id: ExportXml.py 16899 2011-03-23 20:29:47Z m_d_n $
 
 """
 Contains the interface to allow a database to get written using
@@ -77,15 +77,15 @@ try:
 except:
     _gzip_ok = 0
 
-# table for skipping control chars from XML
-strip_dict = dict.fromkeys(range(9)+range(12,20))
+# table for skipping control chars from XML except 09, 0A, 0D
+strip_dict = dict.fromkeys(range(9)+range(11,13)+range(14, 32))
 
 def escxml(d):
     return escape(d, 
                   {'"' : '&quot;',
                    '<' : '&lt;',
                    '>' : '&gt;',
-                   })
+                   }) if d else ""
 
 #-------------------------------------------------------------------------
 #
@@ -155,8 +155,8 @@ class GrampsXmlWriter(UpdateCallback):
                 g = open(filename,"w")
         except IOError,msg:
             LOG.warn(str(msg))
-            raise DbWriteFailure((_('Failure writing %s') % filename,
-                                       str(msg)))
+            raise DbWriteFailure(_('Failure writing %s') % filename,
+                                       str(msg))
             return 0
 
         self.g = codecs.getwriter("utf8")(g)
