@@ -3,10 +3,11 @@
 #
 # Copyright (C) 2007-2008  Stephane Charette
 # Copyright (C) 2007-2008  Brian G. Matherly
-# Copyright (C) 2009       Gary Burton 
+# Copyright (C) 2009-2010  Gary Burton 
+# Contribution 2009 by     Bob Ham <rah@bash.sh>
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Pubilc License as published by
+# it under the terms of the GNU General Public License as published by
 # the Free Software Foundation; either version 2 of the License, or
 # (at your option) any later version.
 #
@@ -20,7 +21,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: GVFamilyLines.py 13412 2009-10-25 17:06:50Z bmcage $
+# $Id: GVFamilyLines.py 14227 2010-02-05 12:39:04Z gburto01 $
 
 """
 Family Lines, a GraphViz-based plugin for Gramps.
@@ -31,7 +32,7 @@ Family Lines, a GraphViz-based plugin for Gramps.
 # python modules
 #
 #------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #------------------------------------------------------------------------
 #
@@ -48,13 +49,15 @@ log = logging.getLogger(".FamilyLines")
 #------------------------------------------------------------------------
 import gen.lib
 import Utils
+from gui.utils import ProgressMeter
 import ThumbNails
 from DateHandler import displayer as _dd
-from ReportBase import Report, ReportUtils, MenuReportOptions, CATEGORY_GRAPHVIZ
-from gen.plug import PluginManager
+from ReportBase import Report, ReportUtils, MenuReportOptions
 from gen.plug.menu import NumberOption, ColorOption, BooleanOption, \
                           EnumeratedListOption, PersonListOption, \
                           SurnameColorOption
+from gen.utils import get_birth_or_fallback, get_death_or_fallback
+from gen.display.name import displayer as name_displayer
 
 #------------------------------------------------------------------------
 #
@@ -396,7 +399,7 @@ class FamilyLinesReport(Report):
         from the database is going to be output into the report
         """
 
-        self.progress = Utils.ProgressMeter(_('Generating Family Lines'),
+        self.progress = ProgressMeter(_('Generating Family Lines'),
                                             _('Starting'))
 
         # starting with the people of interest, we then add parents:
@@ -762,7 +765,7 @@ class FamilyLinesReport(Report):
         for handle in self._people:
             self.progress.step()
             person = self._db.get_person_from_handle(handle)
-            name = person.get_primary_name().get_regular_name()
+            name = name_displayer.display_name(person.get_primary_name())
 
             # figure out what colour to use
             gender = person.get_gender()
@@ -779,8 +782,8 @@ class FamilyLinesReport(Report):
 
             # see if we have a birth/death or fallback dates we can use
             if self._incdates or self._incplaces:
-                bth_event = ReportUtils.get_birth_or_fallback(self._db, person)
-                dth_event = ReportUtils.get_death_or_fallback(self._db, person)
+                bth_event = get_birth_or_fallback(self._db, person)
+                dth_event = get_death_or_fallback(self._db, person)
             else:
                 bth_event = None
                 dth_event = None
@@ -851,7 +854,7 @@ class FamilyLinesReport(Report):
                                                               media.get_path()),
                                         rectangle=mediaList[0].get_rectangle())
 
-            # put the label together and ouput this person
+            # put the label together and output this person
             label = u""
             lineDelimiter = '\\n'
             if bUseHtmlOutput:
@@ -1020,14 +1023,14 @@ class FamilyLinesReport(Report):
                 if father_handle in self._people:
                     father = self._db.get_person_from_handle(father_handle)
                     comment = "father: %s" % father.get_primary_name().get_regular_name()
-                    self.doc.add_link(fgid, father.get_gramps_id(), comment=comment)
+                    self.doc.add_link(father.get_gramps_id(), fgid, comment=comment)
 
             # see if we have a mother to link to this family
             if mother_handle:
                 if mother_handle in self._people:
                     mother = self._db.get_person_from_handle(mother_handle)
                     comment = "mother: %s" % mother.get_primary_name().get_regular_name()
-                    self.doc.add_link(fgid, mother.get_gramps_id(), comment=comment)
+                    self.doc.add_link(mother.get_gramps_id(), fgid, comment=comment)
 
             if self._usesubgraphs and father_handle and mother_handle:
                 self.doc.end_subgraph()
@@ -1037,29 +1040,4 @@ class FamilyLinesReport(Report):
                 if childRef.ref in self._people:
                     child = self._db.get_person_from_handle(childRef.ref)
                     comment = "child:  %s" % child.get_primary_name().get_regular_name()
-                    self.doc.add_link(child.get_gramps_id(), fgid, comment=comment)
-
-
-#------------------------------------------------------------------------
-#
-# register_report() is defined in _PluginMgr.py and
-# is used to hook the plugin into GRAMPS so that it
-# appears in the "Reports" menu options
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_report(
-    name            = 'familylines_graph',
-    translated_name = _("Family Lines Graph"),
-    category        = CATEGORY_GRAPHVIZ,
-    report_class    = FamilyLinesReport,
-    options_class   = FamilyLinesOptions,
-    modes           = PluginManager.REPORT_MODE_GUI | \
-                      PluginManager.REPORT_MODE_CLI,
-    status          = _("Stable"),
-    author_name     = "Stephane Charette",
-    author_email    = "stephanecharette@gmail.com",
-    description     = _("Produces family line graphs using GraphViz"),
-    require_active = False
-    )
-
+                    self.doc.add_link(fgid, child.get_gramps_id(), comment=comment)
