@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ImportGeneWeb.py 14396 2010-02-16 02:18:24Z dsblank $
+# $Id: ImportGeneWeb.py 16005 2010-10-16 09:12:47Z romjerome $
 
 "Import from GeneWeb"
 
@@ -431,9 +431,11 @@ class GeneWebParser(object):
             field = fields[idx]
             idx += 1
             if field.startswith("+"):
+                field = field[1:]
                 mar_date = self.parse_date(self.decode(field))
                 LOG.debug(" Married at: %s" % field)
             elif field.startswith("-"):
+                field = field[1:]
                 div_date = self.parse_date(self.decode(field))
                 LOG.debug(" Div at: %s" % field)
             elif field == "#mp" and idx < len(fields):
@@ -465,13 +467,17 @@ class GeneWebParser(object):
                 gen.lib.EventType.MARRIAGE, None, mar_date, mar_place, mar_source)
             mar_ref = gen.lib.EventRef()
             mar_ref.set_reference_handle(mar.get_handle())
+            mar_ref.set_role(gen.lib.EventRoleType.FAMILY)
             self.current_family.add_event_ref(mar_ref)
+            self.current_family.set_relationship(
+                gen.lib.FamilyRelType(gen.lib.FamilyRelType.MARRIED))
 
         if div_date:
             div = self.create_event(
                 gen.lib.EventType.DIVORCE, None, div_date, None, None)
             div_ref = gen.lib.EventRef()
             div_ref.set_reference_handle(div.get_handle())
+            div_ref.set_role(gen.lib.EventRoleType.FAMILY)
             self.current_family.add_event_ref(div_ref)
 
         if sep_date or engaged:
@@ -479,6 +485,7 @@ class GeneWebParser(object):
                 gen.lib.EventType.ENGAGEMENT, None, sep_date, None, None)
             sep_ref = gen.lib.EventRef()
             sep_ref.set_reference_handle(sep.get_handle())
+            sep_ref.set_role(gen.lib.EventRoleType.FAMILY)
             self.current_family.add_event_ref(sep_ref)
 
         if not married:
