@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: ImportXml.py 13381 2009-10-17 22:53:30Z dsblank $
+# $Id: ImportXml.py 16633 2011-02-16 18:57:13Z m_d_n $
 
 #-------------------------------------------------------------------------
 #
@@ -29,8 +29,10 @@
 import os
 import sys
 from xml.parsers.expat import ExpatError, ParserCreate
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 import re
+import logging
+LOG = logging.getLogger(".ImportXML")
 
 #-------------------------------------------------------------------------
 #
@@ -38,17 +40,17 @@ import re
 #
 #-------------------------------------------------------------------------
 from QuestionDialog import ErrorDialog, WarningDialog
-import Mime
+import gen.mime
 import gen.lib
 import Utils
 import DateHandler
-from BasicUtils import name_displayer
+from gen.display.name import displayer as name_displayer
 from gen.db.dbconst import (PERSON_KEY, FAMILY_KEY, SOURCE_KEY, EVENT_KEY, 
                             MEDIA_KEY, PLACE_KEY, REPOSITORY_KEY, NOTE_KEY)
-from BasicUtils import UpdateCallback
+from gen.updatecallback import UpdateCallback
 import const
-from gen.plug import PluginManager, ImportPlugin
 import libgrampsxml
+from libmixin import DbMixin
 
 #-------------------------------------------------------------------------
 #
@@ -83,6 +85,10 @@ EVENT_PERSON_STR = _("%(event_name)s of %(person)s")
 #-------------------------------------------------------------------------
 def importData(database, filename, callback=None, cl=0):
 
+    if DbMixin not in database.__class__.__bases__:
+        database.__class__.__bases__ = (DbMixin,) +  \
+                                        database.__class__.__bases__
+
     filename = os.path.normpath(filename)
     basefile = os.path.dirname(filename)
     database.smap = {}
@@ -113,8 +119,8 @@ def importData(database, filename, callback=None, cl=0):
         info = parser.parse(xml_file, line_cnt, person_cnt)
     except IOError, msg:
         if cl:
-            print "Error reading %s" % filename
-            print msg
+            LOG.warn("Error reading %s" % filename)
+            LOG.warn(msg)
             import traceback
             traceback.print_exc()
             sys.exit(1)
@@ -125,12 +131,12 @@ def importData(database, filename, callback=None, cl=0):
             return
     except ExpatError, msg:
         if cl:
-            print "Error reading %s" % filename
-            print "The file is probably either corrupt or not a valid GRAMPS database."
+            LOG.warn("Error reading %s" % filename)
+            LOG.warn("The file is probably either corrupt or not a valid Gramps database.")
             sys.exit(1)
         else:
             ErrorDialog(_("Error reading %s") % filename, 
-                        _("The file is probably either corrupt or not a valid GRAMPS database."))
+                        _("The file is probably either corrupt or not a valid Gramps database."))
             return
 
     xml_file.close()
@@ -773,7 +779,7 @@ class GrampsParser(UpdateCallback):
         del self.func_map
         del self.func_list
         del self.p
-        self.db.transaction_commit(self.trans, _("GRAMPS XML import"))
+        self.db.transaction_commit(self.trans, _("Gramps XML import"))
         self.db.enable_signals()
         self.db.request_rebuild()
         return self.info
@@ -1281,16 +1287,20 @@ class GrampsParser(UpdateCallback):
             self.alt_name = bool(attrs.get("alt", 0))
             try:
                 sort_as = int(attrs["sort"])
-                display_as = int(attrs["display"])
-
                 # check if these pointers need to be remapped
                 # and set the name attributes
                 if sort_as in self.name_formats_map:
                     self.name.sort_as = self.name_formats_map[sort_as]
                 else:
                     self.name.sort_as = sort_as
+            except KeyError:
+                pass
+            try:
+                display_as = int(attrs["display"])
+                # check if these pointers need to be remapped
+                # and set the name attributes
                 if display_as in self.name_formats_map:
-                    self.name.sort_as = self.name_formats_map[display_as]
+                    self.name.display_as = self.name_formats_map[display_as]
                 else:
                     self.name_display_as = display_as
             except KeyError:
@@ -1304,9 +1314,9 @@ class GrampsParser(UpdateCallback):
             if self.db.has_name_group_key(key) :
                 present = self.db.get_name_group_mapping(key)
                 if not value == present:
-                    msg = _("Your family tree groups name %s together"
-                            " with %s, did not change this grouping to %s") % (
-                                                        key, present, value)
+                    msg = _("Your family tree groups name %(key)s together"
+                            " with %(parent)s, did not change this grouping to %(value)s") % {
+                            'key' : key, 'parent' : present, 'value' : value }
                     self.errmsg(msg)
             else:
                 self.db.set_name_group_mapping(key, value)
@@ -1674,7 +1684,7 @@ class GrampsParser(UpdateCallback):
                 attr.set_type(key)
                 attr.set_value(attrs[key])
                 self.photo.add_attribute(attr)
-        self.photo.set_mime_type(Mime.get_type(self.photo.get_path()))
+        self.photo.set_mime_type(gen.mime.get_type(self.photo.get_path()))
         self.db.add_object(self.photo, self.trans)
         #set correct change time
         self.db.commit_media_object(self.photo, self.trans, self.change)
@@ -1742,7 +1752,7 @@ class GrampsParser(UpdateCallback):
             rng_day = 0
 
         if "cformat" in attrs:
-            cal = gen.lib.Date.calendar_names.index(attrs['calendar'])
+            cal = gen.lib.Date.calendar_names.index(attrs['cformat'])
         else:
             cal = gen.lib.Date.CAL_GREGORIAN
 
@@ -2452,14 +2462,14 @@ def open_file(filename, cli):
             xml_file = open(filename, "r")
     except IOError, msg:
         if cli:
-            print "Error: %s could not be opened Exiting." % filename
-            print msg
+            LOG.warn("Error: %s could not be opened Exiting." % filename)
+            LOG.warn(msg)
         else:
             ErrorDialog(_("%s could not be opened") % filename, str(msg))
         xml_file = None
     except:
         if cli:
-            print "Error: %s could not be opened. Exiting." % filename
+            LOG.warn("Error: %s could not be opened. Exiting." % filename)
         else:
             ErrorDialog(_("%s could not be opened") % filename)
         xml_file = None
@@ -2473,23 +2483,23 @@ def version_is_valid(filename, cli):
     parser = VersionParser(filename)
     
     if parser.get_xmlns_version() > libgrampsxml.GRAMPS_XML_VERSION:
-        msg = _("The .gramps file you are importing was made by version %s of "
-                "GRAMPS, while you are running an older version %s. "
+        msg = _("The .gramps file you are importing was made by version %(newer)s of "
+                "Gramps, while you are running an older version %(older)s. "
                 "The file will not be imported. Please upgrade to the latest "
-                "version of GRAMPS and try again." 
-                ) % (parser.get_gramps_version(), const.VERSION)
+                "version of Gramps and try again." ) % {
+                'newer' : parser.get_gramps_version(), 'older' : const.VERSION }
         if cli:
-            print msg
+            LOG.warn(msg)
             return False
         else:
             ErrorDialog(msg)
             return False
     if parser.get_xmlns_version() < '1.0.0':
         msg = _("The .gramps file you are importing was made by version "
-                "%(oldgramps)s of GRAMPS, while you are running a more "
+                "%(oldgramps)s of Gramps, while you are running a more "
                 "recent version %(newgramps)s.\n\n"
                 "The file will not be imported. Please use an older version of"
-                " GRAMPS that supports version %(xmlversion)s of the xml.\nSee"
+                " Gramps that supports version %(xmlversion)s of the xml.\nSee"
                 "\n  http://gramps-project.org/wiki/index.php?title=GRAMPS_XML\n "
                 "for more info."
                 ) % {'oldgramps': parser.get_gramps_version(), 
@@ -2497,18 +2507,18 @@ def version_is_valid(filename, cli):
                      'xmlversion': parser.get_xmlns_version(),
                     }
         if cli:
-            print msg
+            LOG.warn(msg)
             return False
         else:
             ErrorDialog(_('The file will not be imported'), msg)
             return False
     elif parser.get_xmlns_version() < '1.1.0':
         msg = _("The .gramps file you are importing was made by version "
-                "%(oldgramps)s of GRAMPS, while you are running a much "
+                "%(oldgramps)s of Gramps, while you are running a much "
                 "more recent version %(newgramps)s.\n\n"
                 "Ensure after import everything is imported correctly. In the "
                 "event of problems, please submit a bug and use an older "
-                "version of GRAMPS in the meantime to import this file, which "
+                "version of Gramps in the meantime to import this file, which "
                 "is version %(xmlversion)s of the xml.\nSee"
                 "\n  http://gramps-project.org/wiki/index.php?title=GRAMPS_XML\n"
                 "for more info."
@@ -2517,24 +2527,9 @@ def version_is_valid(filename, cli):
                      'xmlversion': parser.get_xmlns_version(),
                     }
         if cli:
-            print msg
+            LOG.warn(msg)
             return True
         else:
             WarningDialog(_('Old xml file'), msg)
             return True
     return True
-
-#------------------------------------------------------------------------
-#
-# Register with the plugin system
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-plugin = ImportPlugin(name            = _('GRAMPS XML database'), 
-                      description     = _('The GRAMPS XML database is a text '
-                                          'version of a family tree. It is '
-                                          'read-write compatible with the '
-                                          'present GRAMPS database format.'),
-                      import_function = importData,
-                      extension       = "gramps" )
-pmgr.register_plugin(plugin)
