@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: AncestorReport.py 14091 2010-01-18 04:42:17Z pez4brian $
+# $Id: AncestorReport.py 16530 2011-02-01 14:58:54Z romjerome $
 
 """Reports/Text Reports/Ahnentafel Report"""
 
@@ -102,7 +102,7 @@ class AncestorReport(Report):
         language = menu.get_option_by_name('trans').get_value()
         translator = Translator(language)
         self._ = translator.gettext
-        self.__narrator = Narrator(self.database, 
+        self.__narrator = Narrator(self.database, use_fulldate=True,
                                    translator=translator)
 
     def apply_filter(self, person_handle, index, generation=1):
@@ -256,7 +256,7 @@ class AncestorOptions(MenuReportOptions):
         pid.set_help(_("The center person for the report"))
         menu.add_option(category_name, "pid", pid)
         
-        maxgen = NumberOption(_("Generations"), 10, 1, 15)
+        maxgen = NumberOption(_("Generations"), 10, 1, 100)
         maxgen.set_help(_("The number of generations to include in the report"))
         menu.add_option(category_name, "maxgen", maxgen)
         
