@@ -2,6 +2,7 @@
 #
 # Copyright (C) 2000-2007  Donald N. Allingham
 # Copyright (C) 2008-2009  Brian G. Matherly
+# Copyright (C) 2009           Rob G. Healey <robhealey1@gmail.com>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -16,31 +17,38 @@
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+#
+# $Id: BirthdayReport.py 14185 2010-02-01 23:07:44Z robhealey1 $
+#
 
 #------------------------------------------------------------------------
 #
 # python modules
 #
 #------------------------------------------------------------------------
-from gettext import gettext as _
-from gettext import ngettext
-import datetime
-import time
+from gen.ggettext import gettext as _
+from gen.ggettext import ngettext
+import datetime, time
 
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-import BaseDoc
-from BasicUtils import name_displayer
-from gen.plug import PluginManager
-from ReportBase import Report, ReportUtils, MenuReportOptions, CATEGORY_TEXT
-from gen.plug.menu import BooleanOption, StringOption, NumberOption, \
-                         EnumeratedListOption, FilterOption, PersonOption
+from gen.display.name import displayer as _nd
+from Errors import ReportError
+from gen.lib import NameType, EventType, Name, Date, Person
+import Relationship
+from gen.plug.docgen import (FontStyle, ParagraphStyle, GraphicsStyle,
+                             FONT_SERIF, PARA_ALIGN_RIGHT,
+                             PARA_ALIGN_LEFT, PARA_ALIGN_CENTER)
+from gen.plug.menu import (BooleanOption, StringOption, NumberOption, 
+                         EnumeratedListOption, FilterOption, PersonOption)
+from gui.utils import ProgressMeter
+from ReportBase import Report, ReportUtils, MenuReportOptions
+from Utils import probably_alive
 import GrampsLocale
-import gen.lib
-from Utils import probably_alive, ProgressMeter
+from DateHandler import displayer as _dd
 
 import libholiday
 
@@ -56,25 +64,27 @@ class CalendarReport(Report):
     def __init__(self, database, options_class):
         Report.__init__(self, database, options_class)
         menu = options_class.menu
+        mgobn = lambda name:options_class.menu.get_option_by_name(name).get_value()
 
-        self.titletext = menu.get_option_by_name('titletext').get_value()
-        self.relationships = \
-                            menu.get_option_by_name('relationships').get_value()
-        self.year = menu.get_option_by_name('year').get_value()
-        self.name_format = menu.get_option_by_name('name_format').get_value()
-        self.country = menu.get_option_by_name('country').get_value()
-        self.anniversaries = menu.get_option_by_name('anniversaries').get_value()
-        self.start_dow = menu.get_option_by_name('start_dow').get_value()
-        self.maiden_name = menu.get_option_by_name('maiden_name').get_value()
-        self.alive = menu.get_option_by_name('alive').get_value()
-        self.birthdays = menu.get_option_by_name('birthdays').get_value()
-        self.text1 = menu.get_option_by_name('text1').get_value()
-        self.text2 = menu.get_option_by_name('text2').get_value()
-        self.text3 = menu.get_option_by_name('text3').get_value()
+        self.titletext = mgobn('titletext')
+        self.relationships = mgobn('relationships')
+        self.year = mgobn('year')
+        self.name_format = mgobn('name_format')
+        self.country = mgobn('country')
+        self.anniversaries = mgobn('anniversaries')
+        self.start_dow = mgobn('start_dow')
+        self.maiden_name = mgobn('maiden_name')
+        self.alive = mgobn('alive')
+        self.birthdays = mgobn('birthdays')
+        self.text1 = mgobn('text1')
+        self.text2 = mgobn('text2')
+        self.text3 = mgobn('text3')
         self.filter_option =  menu.get_option_by_name('filter')
         self.filter = self.filter_option.get_filter()
-        pid = menu.get_option_by_name('pid').get_value()
+        pid = mgobn('pid')
         self.center_person = database.get_person_from_gramps_id(pid)
+        if (self.center_person == None) :
+            raise ReportError(_("Person %s is not in the Database") % pid )        
 
     def get_name(self, person, maiden_name = None):
         """ 
@@ -86,20 +96,20 @@ class CalendarReport(Report):
         married_name = None
         names = [primary_name] + person.get_alternate_names()
         for name in names:
-            if int(name.get_type()) == gen.lib.NameType.MARRIED:
+            if int(name.get_type()) == NameType.MARRIED:
                 married_name = name
                 break # use first
         # Now, decide which to use:
         if maiden_name is not None:
             if married_name is not None:
-                name = gen.lib.Name(married_name)
+                name = Name(married_name)
             else:
-                name = gen.lib.Name(primary_name)
+                name = Name(primary_name)
                 name.set_surname(maiden_name)
         else:
-            name = gen.lib.Name(primary_name)
+            name = Name(primary_name)
         name.set_display_as(self.name_format)
-        return name_displayer.display_name(name)
+        return _nd.display_name(name)
 
     def add_day_item(self, text, month, day):
         """ Add an item to a day. """
@@ -149,7 +159,7 @@ class CalendarReport(Report):
         if self.relationships:
             name = self.center_person.get_primary_name()
             self.doc.start_paragraph('BIR-Text3style')
-            self.doc.write_text(_("Relationships shown are to %s") % name_displayer.display_name(name))
+            self.doc.write_text(_("Relationships shown are to %s") % _nd.display_name(name))
             self.doc.end_paragraph()
         self.progress.set_pass(_('Formatting months...'), 12)
         for month in range(1, 13):
@@ -161,7 +171,7 @@ class CalendarReport(Report):
         """ Prints a month as a page """
         year = self.year
         self.doc.start_paragraph('BIR-Monthstyle')
-        self.doc.write_text(GrampsLocale.long_months[month].capitalize())
+        self.doc.write_text(_dd.long_months[month].capitalize())
         self.doc.end_paragraph()
         current_date = datetime.date(year, month, 1)
         current_ord = current_date.toordinal()
@@ -187,11 +197,11 @@ class CalendarReport(Report):
         This method runs through the data, and collects the relevant dates
         and text.
         """
-        people = self.database.get_person_handles(sort_handles=False)
-        self.progress.set_pass(_('Applying Filter...'), len(people))
+        people = self.database.iter_person_handles()
+        self.progress.set_pass(_('Applying Filter...'), 
+            self.database.get_number_of_people())
         people = self.filter.apply(self.database, people, self.progress)
-        pmgr = PluginManager.get_instance()
-        rel_calc = pmgr.get_relationship_calculator()
+        rel_calc = Relationship.get_relationship_calculator()
 
         self.progress.set_pass(_('Reading database...'), len(people))
         for person_handle in people:
@@ -208,13 +218,13 @@ class CalendarReport(Report):
                 month = birth_date.get_month()
                 day = birth_date.get_day()
 
-                prob_alive_date = gen.lib.Date(self.year, month, day)
+                prob_alive_date = Date(self.year, month, day)
 
                 nyears = self.year - year
                 # add some things to handle maiden name:
                 father_lastname = None # husband, actually
                 if self.maiden_name in ['spouse_first', 'spouse_last']: # get husband's last name:
-                    if person.get_gender() == gen.lib.Person.FEMALE:
+                    if person.get_gender() == Person.FEMALE:
                         family_list = person.get_family_handle_list()
                         if len(family_list) > 0:
                             if self.maiden_name == 'spouse_first':
@@ -275,12 +285,12 @@ class CalendarReport(Report):
                             are_married = None
                             for event_ref in fam.get_event_ref_list():
                                 event = self.database.get_event_from_handle(event_ref.ref)
-                                if event.type in [gen.lib.EventType.MARRIAGE, 
-                                                             gen.lib.EventType.MARR_ALT]:
+                                if event.type in [EventType.MARRIAGE, 
+                                                             EventType.MARR_ALT]:
                                     are_married = event
-                                elif event.type in [gen.lib.EventType.DIVORCE, 
-                                                               gen.lib.EventType.ANNULMENT, 
-                                                               gen.lib.EventType.DIV_FILING]:
+                                elif event.type in [EventType.DIVORCE, 
+                                                               EventType.ANNULMENT, 
+                                                               EventType.DIV_FILING]:
                                     are_married = None
                             if are_married is not None:
                                 for event_ref in fam.get_event_ref_list():
@@ -303,7 +313,7 @@ class CalendarReport(Report):
                                                        'person' : short_name, 
                                                        'nyears' : nyears})
  
-                                            prob_alive_date = gen.lib.Date(self.year, month, day)
+                                            prob_alive_date = Date(self.year, month, day)
                                             alive1 = probably_alive(person, self.database, \
                                                 prob_alive_date)
                                             alive2 = probably_alive(spouse, self.database, \
@@ -347,7 +357,7 @@ class CalendarOptions(MenuReportOptions):
 
         # We must figure out the value of the first option before we can
         # create the EnumeratedListOption
-        fmt_list = name_displayer.get_name_format()
+        fmt_list = _nd.get_name_format()
         name_format = EnumeratedListOption(_("Name format"), fmt_list[0][0])
         for num, name, fmt_str, act in fmt_list:
             name_format.add_item(num, name)
@@ -405,7 +415,7 @@ class CalendarOptions(MenuReportOptions):
         text1.set_help(_("First line of text at bottom of calendar"))
         menu.add_option(category_name, "text1", text1)
 
-        text2 = StringOption(_("Text Area 2"), _("Produced with GRAMPS"))
+        text2 = StringOption(_("Text Area 2"), _("Produced with Gramps"))
         text2.set_help(_("Second line of text at bottom of calendar"))
         menu.add_option(category_name, "text2", text2)
 
@@ -423,17 +433,17 @@ class CalendarOptions(MenuReportOptions):
         self.__filter.set_filters(filter_list)
 
     def make_my_style(self, default_style, name, description, 
-                      size=9, font=BaseDoc.FONT_SERIF, justified ="left", 
-                      color=None, align=BaseDoc.PARA_ALIGN_CENTER, 
+                      size=9, font=FONT_SERIF, justified ="left", 
+                      color=None, align=PARA_ALIGN_CENTER, 
                       shadow = None, italic=0, bold=0, borders=0, indent=None):
         """ Create paragraph and graphic styles of the same name """
         # Paragraph:
-        f = BaseDoc.FontStyle()
+        f = FontStyle()
         f.set_size(size)
         f.set_type_face(font)
         f.set_italic(italic)
         f.set_bold(bold)
-        p = BaseDoc.ParagraphStyle()
+        p = ParagraphStyle()
         p.set_font(f)
         p.set_alignment(align)
         p.set_description(description)
@@ -444,14 +454,14 @@ class CalendarOptions(MenuReportOptions):
         if indent:
             p.set(first_indent=indent)
         if justified == "left":
-            p.set_alignment(BaseDoc.PARA_ALIGN_LEFT)       
+            p.set_alignment(PARA_ALIGN_LEFT)       
         elif justified == "right":
-            p.set_alignment(BaseDoc.PARA_ALIGN_RIGHT)       
+            p.set_alignment(PARA_ALIGN_RIGHT)       
         elif justified == "center":
-            p.set_alignment(BaseDoc.PARA_ALIGN_CENTER)       
+            p.set_alignment(PARA_ALIGN_CENTER)       
         default_style.add_paragraph_style(name, p)
         # Graphics:
-        g = BaseDoc.GraphicsStyle()
+        g = GraphicsStyle()
         g.set_paragraph_style(name)
         if shadow:
             g.set_shadow(*shadow)
@@ -479,25 +489,3 @@ class CalendarOptions(MenuReportOptions):
                            _('Text at bottom, line 2'), 12, justified="center")
         self.make_my_style(default_style, "BIR-Text3style", 
                            _('Text at bottom, line 3'), 12, justified="center")
-
-#------------------------------------------------------------------------
-#
-# Register the plugins
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_report(
-    name = 'birthday_report', 
-    category = CATEGORY_TEXT, 
-    report_class = CalendarReport, 
-    options_class = CalendarOptions, 
-    modes = PluginManager.REPORT_MODE_GUI | \
-            PluginManager.REPORT_MODE_BKI | \
-            PluginManager.REPORT_MODE_CLI, 
-    translated_name = _("Birthday and Anniversary Report"), 
-    status = _("Stable"), 
-    author_name = "Douglas S. Blank", 
-    author_email = "dblank@cs.brynmawr.edu", 
-    description = _("Produces a report of birthdays and anniversaries"), 
-    )
-
