@@ -3,7 +3,7 @@
 #
 # Copyright (C) 2000-2002 Bruce J. DeGrasse
 # Copyright (C) 2000-2007 Donald N. Allingham
-# Copyright (C) 2007-2008 Brian G. Matherly
+# Copyright (C) 2007-2009 Brian G. Matherly
 # Copyright (C) 2007      Robert Cawley  <rjc@cawley.id.au>
 # Copyright (C) 2008-2009 James Friedmann <jfriedmannj@gmail.com>
 # Copyright (C) 2009      Benny Malengier <benny.malengier@gramps-project.org>
@@ -23,7 +23,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: DetDescendantReport.py 12842 2009-07-28 04:28:12Z pez4brian $
+# $Id: DetDescendantReport.py 15845 2010-09-01 16:17:36Z ldnp $
 
 """Reports/Text Reports/Detailed Descendant Report"""
 
@@ -32,22 +32,26 @@
 # standard python modules
 #
 #------------------------------------------------------------------------
-from gettext import gettext as _
+from gen.ggettext import gettext as _
 
 #------------------------------------------------------------------------
 #
 # GRAMPS modules
 #
 #------------------------------------------------------------------------
-import gen.lib
-from gen.plug import PluginManager
-from gen.plug.menu import BooleanOption, NumberOption, PersonOption
-from ReportBase import Report, ReportUtils, MenuReportOptions, CATEGORY_TEXT
-from ReportBase import Bibliography, Endnotes
-import BaseDoc
+from gen.display.name import displayer as _nd
+from Errors import ReportError
+from gen.lib import FamilyRelType, Person, NoteType
+from gen.plug.menu import (BooleanOption, NumberOption, PersonOption, 
+                           EnumeratedListOption)
+from gen.plug.docgen import (IndexMark, FontStyle, ParagraphStyle, 
+                             FONT_SANS_SERIF, FONT_SERIF, 
+                             INDEX_TYPE_TOC, PARA_ALIGN_CENTER)
+from ReportBase import (Report, ReportUtils, MenuReportOptions,
+                        Bibliography, Endnotes)
 import DateHandler
-from BasicUtils import name_displayer as _nd
-import Utils
+
+from libnarrate import Narrator
 
 #------------------------------------------------------------------------
 #
@@ -79,18 +83,19 @@ class DetDescendantReport(Report):
         
         gen           - Maximum number of generations to include.
         pagebgg       - Whether to include page breaks between generations.
+        pageben       - Whether to include page break before End Notes.
         firstName     - Whether to use first names instead of pronouns.
         fulldate      - Whether to use full dates instead of just year.
         listchildren  - Whether to list children.
-        inc_mates  - Whether to include information about spouses
-        inc_notes  - Whether to include notes.
-        inc_attrs  - Whether to include attributes
+        inc_mates     - Whether to include information about spouses
+        inc_notes     - Whether to include notes.
+        inc_attrs     - Whether to include attributes
         blankPlace    - Whether to replace missing Places with ___________.
         blankDate     - Whether to replace missing Dates with ___________.
         calcageflag   - Whether to compute age.
         dubperson     - Whether to omit duplicate ancestors (e.g. when distant cousins mary).
-        verbose       - Whether to use complete sentences
-        record_num    - Whether to use Record-style numbering instead of Henry-style.
+        verbose       - Whether to use complete sentences.
+        numbering     - The descendency numbering system to be utilized.
         childref      - Whether to add descendant references in child list.
         addimages     - Whether to include images.
         pid           - The Gramps ID of the center person for the report.
@@ -102,48 +107,60 @@ class DetDescendantReport(Report):
         menu = options_class.menu
         self.max_generations = menu.get_option_by_name('gen').get_value()
         self.pgbrk         = menu.get_option_by_name('pagebbg').get_value()
+        self.pgbrkenotes   = menu.get_option_by_name('pageben').get_value()
         self.fulldate      = menu.get_option_by_name('fulldates').get_value()
+        use_fulldate       = self.fulldate
         self.listchildren  = menu.get_option_by_name('listc').get_value()
         self.inc_notes     = menu.get_option_by_name('incnotes').get_value()
-        self.usecall       = menu.get_option_by_name('usecall').get_value()
+        use_call           = menu.get_option_by_name('usecall').get_value()
         blankplace         = menu.get_option_by_name('repplace').get_value()
         blankdate          = menu.get_option_by_name('repdate').get_value()
         self.calcageflag   = menu.get_option_by_name('computeage').get_value()
         self.dubperson     = menu.get_option_by_name('omitda').get_value()
         self.verbose       = menu.get_option_by_name('verbose').get_value()
-        self.record_num    = menu.get_option_by_name('record_num').get_value()
+        self.numbering     = menu.get_option_by_name('numbering').get_value()
         self.childref      = menu.get_option_by_name('desref').get_value()
         self.addimages     = menu.get_option_by_name('incphotos').get_value()
         self.inc_names     = menu.get_option_by_name('incnames').get_value()
         self.inc_events    = menu.get_option_by_name('incevents').get_value()
         self.inc_addr      = menu.get_option_by_name('incaddresses').get_value()
         self.inc_sources   = menu.get_option_by_name('incsources').get_value()
+        self.inc_srcnotes  = menu.get_option_by_name('incsrcnotes').get_value()
         self.inc_mates     = menu.get_option_by_name('incmates').get_value()
         self.inc_attrs     = menu.get_option_by_name('incattrs').get_value()
+        self.inc_paths     = menu.get_option_by_name('incpaths').get_value()
+        self.inc_ssign     = menu.get_option_by_name('incssign').get_value()
         pid                = menu.get_option_by_name('pid').get_value()
         self.center_person = database.get_person_from_gramps_id(pid)
+        if (self.center_person == None) :
+            raise ReportError(_("Person %s is not in the Database") % pid )
 
         self.gen_handles = {}
         self.prev_gen_handles = {}
         self.gen_keys = []
-        self.henry = {}
+        self.dnumber = {}
 
         if blankdate:
-            self.EMPTY_DATE = EMPTY_ENTRY
+            empty_date = EMPTY_ENTRY
         else:
-            self.EMPTY_DATE = ""
+            empty_date = ""
 
         if blankplace:
-            self.EMPTY_PLACE = EMPTY_ENTRY
+            empty_place = EMPTY_ENTRY
         else:
-            self.EMPTY_PLACE = ""
+            empty_place = ""
+            
+        self.__narrator = Narrator(self.database, self.verbose,
+                                   use_call, use_fulldate,
+                                   empty_date, empty_place, 
+                                   get_endnote_numbers=self.endnotes)
 
         self.bibli = Bibliography(Bibliography.MODE_PAGE)
 
-    def apply_filter(self,person_handle, index, pid, cur_gen=1):
+    def apply_henry_filter(self,person_handle, index, pid, cur_gen=1):
         if (not person_handle) or (cur_gen > self.max_generations):
             return
-        self.henry[person_handle] = pid
+        self.dnumber[person_handle] = pid
         self.map[index] = person_handle
 
         if len(self.gen_keys) < cur_gen:
@@ -156,13 +173,35 @@ class DetDescendantReport(Report):
         for family_handle in person.get_family_handle_list():
             family = self.database.get_family_from_handle(family_handle)
             for child_ref in family.get_child_ref_list():
-                ix = max(self.map.keys())
-                self.apply_filter(child_ref.ref, ix+1,
+                ix = max(self.map)
+                self.apply_henry_filter(child_ref.ref, ix+1,
                                   pid+HENRY[index], cur_gen+1)
                 index += 1
 
+    # Filter for d'Aboville numbering
+    def apply_daboville_filter(self,person_handle, index, pid, cur_gen=1):
+        if (not person_handle) or (cur_gen > self.max_generations):
+            return
+        self.dnumber[person_handle] = pid
+        self.map[index] = person_handle
+
+        if len(self.gen_keys) < cur_gen:
+            self.gen_keys.append([index])
+        else: 
+            self.gen_keys[cur_gen-1].append(index)
+
+        person = self.database.get_person_from_handle(person_handle)
+        index = 1
+        for family_handle in person.get_family_handle_list():
+            family = self.database.get_family_from_handle(family_handle)
+            for child_ref in family.get_child_ref_list():
+                ix = max(self.map)
+                self.apply_daboville_filter(child_ref.ref, ix+1,
+                                  pid+"."+str(index), cur_gen+1)
+                index += 1
+
     # Filter for Record-style (Modified Register) numbering
-    def mod_reg_filter_aux(self, person_handle, index, cur_gen=1):
+    def apply_mod_reg_filter_aux(self, person_handle, index, cur_gen=1):
         if (not person_handle) or (cur_gen > self.max_generations):
             return
         self.map[index] = person_handle
@@ -177,26 +216,30 @@ class DetDescendantReport(Report):
         for family_handle in person.get_family_handle_list():
             family = self.database.get_family_from_handle(family_handle)
             for child_ref in family.get_child_ref_list():
-                ix = max(self.map.keys())
-                self.mod_reg_filter_aux(child_ref.ref, ix+1, cur_gen+1)
+                ix = max(self.map)
+                self.apply_mod_reg_filter_aux(child_ref.ref, ix+1, cur_gen+1)
 
-    def mod_reg_filter(self,person_handle):
-        self.mod_reg_filter_aux(person_handle, 1, 1)
+    def apply_mod_reg_filter(self, person_handle):
+        self.apply_mod_reg_filter_aux(person_handle, 1, 1)
         mod_reg_number = 1
         for generation in xrange(len(self.gen_keys)):
             for key in self.gen_keys[generation]:
                 person_handle = self.map[key]
-                self.henry[person_handle] = mod_reg_number
+                self.dnumber[person_handle] = mod_reg_number
                 mod_reg_number += 1
 
     def write_report(self):
         """
         This function is called by the report system and writes the report.
         """
-        if self.record_num:
-            self.mod_reg_filter(self.center_person.get_handle())
+        if self.numbering == "Henry":
+            self.apply_henry_filter(self.center_person.get_handle(), 1, "1")
+        elif self.numbering == "d'Aboville":
+            self.apply_daboville_filter(self.center_person.get_handle(), 1, "1")
+        elif self.numbering == "Record (Modified Register)":
+            self.apply_mod_reg_filter(self.center_person.get_handle())
         else:
-            self.apply_filter(self.center_person.get_handle(), 1, "1")
+            raise AttributeError("no such numbering: '%s'" % self.numbering)
 
         name = _nd.display_name(self.center_person.get_primary_name())
 
@@ -204,12 +247,10 @@ class DetDescendantReport(Report):
 
         title = _("Descendant Report for %(person_name)s") % {
                     'person_name' : name }
-        mark = BaseDoc.IndexMark(title, BaseDoc.INDEX_TYPE_TOC, 1)
+        mark = IndexMark(title, INDEX_TYPE_TOC, 1)
         self.doc.write_text(title, mark)
         self.doc.end_paragraph()
 
-        keys = self.map.keys()
-        keys.sort()
         generation = 0
 
         for generation in xrange(len(self.gen_keys)):
@@ -217,7 +258,7 @@ class DetDescendantReport(Report):
                 self.doc.page_break()
             self.doc.start_paragraph("DDR-Generation")
             text = _("Generation %d") % (generation+1)
-            mark = BaseDoc.IndexMark(text, BaseDoc.INDEX_TYPE_TOC, 2)
+            mark = IndexMark(text, INDEX_TYPE_TOC, 2)
             self.doc.write_text(text, mark)
             self.doc.end_paragraph()
             if self.childref:
@@ -230,7 +271,44 @@ class DetDescendantReport(Report):
                 self.write_person(key)
 
         if self.inc_sources:
-            Endnotes.write_endnotes(self.bibli, self.database, self.doc)
+            if self.pgbrkenotes:
+                self.doc.page_break()
+            Endnotes.write_endnotes(self.bibli, self.database, self.doc,
+                                    printnotes=self.inc_srcnotes)
+
+    def write_path(self, person):
+        path = []
+        while True:
+            #person changes in the loop
+            family_handle = person.get_main_parents_family_handle()
+            if family_handle:
+                family = self.database.get_family_from_handle(family_handle)
+                mother_handle = family.get_mother_handle()
+                father_handle = family.get_father_handle()
+                if mother_handle and mother_handle in self.dnumber:
+                    person = self.database.get_person_from_handle(mother_handle)
+                    person_name = _nd.display_name(person.get_primary_name())
+                    path.append(person_name)
+                elif father_handle and father_handle in self.dnumber:
+                    person = self.database.get_person_from_handle(father_handle)
+                    person_name = _nd.display_name(person.get_primary_name())
+                    path.append(person_name)
+                else:
+                    break
+            else:
+                break
+
+        index = len(path)
+
+        if index:
+            self.doc.write_text("(")
+
+        for name in path:
+            if index == 1:
+                self.doc.write_text(name + "-" + str(index) + ") ")
+            else:
+                self.doc.write_text(name + "-" + str(index) + "; ")
+            index -= 1
 
     def write_person(self, key):
         """Output birth, death, parentage, marriage and notes information """
@@ -238,7 +316,7 @@ class DetDescendantReport(Report):
         person_handle = self.map[key]
         person = self.database.get_person_from_handle(person_handle)
 
-        val = self.henry[person_handle]
+        val = self.dnumber[person_handle]
         self.doc.start_paragraph("DDR-First-Entry","%s." % val)
 
         name = _nd.display_formal(person)
@@ -251,12 +329,13 @@ class DetDescendantReport(Report):
         else:
             self.doc.write_text_citation("%s. " % self.endnotes(person))
         self.doc.end_bold()
+
+        if self.inc_paths:
+            self.write_path(person)
         
         if self.dubperson:
             # Check for duplicate record (result of distant cousins marrying)
-            keys = self.map.keys()
-            keys.sort()
-            for dkey in keys:
+            for dkey in sorted(self.map):
                 if dkey >= key: 
                     break
                 if self.map[key] == self.map[dkey]:
@@ -282,7 +361,12 @@ class DetDescendantReport(Report):
     def write_event(self, event_ref):
         text = ""
         event = self.database.get_event_from_handle(event_ref.ref)
-        date = DateHandler.get_date(event)
+
+        if self.fulldate:
+            date = DateHandler.get_date(event)
+        else:
+            date = event.get_date_object().get_year()
+
         ph = event.get_place_handle()
         if ph:
             place = self.database.get_place_from_handle(ph).get_title()
@@ -339,9 +423,10 @@ class DetDescendantReport(Report):
             for notehandle in notelist:
                 note = self.database.get_note_from_handle(notehandle)
                 self.doc.write_styled_note(note.get_styledtext(), 
-                                           note.get_format(),"DDR-MoreDetails")
+                        note.get_format(),"DDR-MoreDetails",
+                        contains_html= note.get_type() == NoteType.HTML_CODE)
 
-    def write_parents(self, person, firstName):
+    def __write_parents(self, person):
         family_handle = person.get_main_parents_family_handle()
         if family_handle:
             family = self.database.get_family_from_handle(family_handle)
@@ -361,10 +446,7 @@ class DetDescendantReport(Report):
             else:
                 father_name = ""
                 father_mark = ""
-            alive = Utils.probably_alive(person, self.database)
-            text = ReportUtils.child_str(person, father_name, mother_name,
-                                         not alive,
-                                         firstName,self.verbose)
+            text = self.__narrator.get_child_string(father_name, mother_name)
             if text:
                 self.doc.write_text(text)
                 if father_mark:
@@ -384,11 +466,7 @@ class DetDescendantReport(Report):
             text = ""
             spouse_mark = ReportUtils.get_person_mark(self.database, spouse)
             
-            text = ReportUtils.married_str(self.database, person, family,
-                                            self.verbose,
-                                            self.endnotes,
-                                            self.EMPTY_DATE,self.EMPTY_PLACE,
-                                            is_first)
+            text = self.__narrator.get_married_string(family, is_first)
             
             if text:
                 self.doc.write_text_citation(text, spouse_mark)
@@ -398,7 +476,7 @@ class DetDescendantReport(Report):
         """
         Write information about the person's spouse/mate.
         """
-        if person.get_gender() == gen.lib.Person.MALE:
+        if person.get_gender() == Person.MALE:
             mate_handle = family.get_mother_handle()
         else:
             mate_handle = family.get_father_handle()
@@ -409,7 +487,7 @@ class DetDescendantReport(Report):
             self.doc.start_paragraph("DDR-MoreHeader")
             name = _nd.display_formal(mate)
             mark = ReportUtils.get_person_mark(self.database, mate)
-            if family.get_relationship() == gen.lib.FamilyRelType.MARRIED:
+            if family.get_relationship() == FamilyRelType.MARRIED:
                 self.doc.write_text(_("Spouse: %s") % name, mark)
             else:
                 self.doc.write_text(_("Relationship with: %s") % name, mark)
@@ -460,21 +538,35 @@ class DetDescendantReport(Report):
                 value = str(self.prev_gen_handles.get(child_handle))
                 child_name += " [%s]" % value
 
-            self.doc.start_paragraph("DDR-ChildList",
-                                     ReportUtils.roman(cnt).lower() + ".")
+            if self.inc_ssign:
+                prefix = " "
+                for family_handle in child.get_family_handle_list():
+                    family = self.database.get_family_from_handle(family_handle)
+                    if family.get_child_ref_list():
+                        prefix = "+ "
+                        break
+            else:
+                prefix = ""
+
+            if child_handle in self.dnumber:
+                self.doc.start_paragraph("DDR-ChildList",
+                        prefix
+                        + str(self.dnumber[child_handle])
+                        + " "
+                        + ReportUtils.roman(cnt).lower()
+                        + ".")
+            else:
+                self.doc.start_paragraph("DDR-ChildList",
+                              prefix + ReportUtils.roman(cnt).lower() + ".")
             cnt += 1
 
-            if child_handle in self.henry:
-                self.doc.write_text("%s [%s]. " % (child_name,
-                                                   self.henry[child_handle]),
-                                    child_mark )
-            else:
-                self.doc.write_text("%s. " % child_name, child_mark)
-                
-            self.doc.write_text(ReportUtils.born_str( self.database, child, 0, 
-                          self.verbose, self.EMPTY_DATE, self.EMPTY_PLACE))
-            self.doc.write_text(ReportUtils.died_str( self.database, child, 0, 
-                          self.verbose, self.EMPTY_DATE, self.EMPTY_PLACE))
+            self.doc.write_text("%s. " % child_name, child_mark)
+            self.__narrator.set_subject(child)
+            self.doc.write_text_citation(self.__narrator.get_born_string() or
+                                         self.__narrator.get_christened_string() or
+                                         self.__narrator.get_baptised_string())
+            self.doc.write_text_citation(self.__narrator.get_died_string() or 
+                                         self.__narrator.get_buried_string())
             self.doc.end_paragraph()
 
     def __write_family_events(self, family):
@@ -512,6 +604,7 @@ class DetDescendantReport(Report):
 
     def write_person_info(self, person):
         name = _nd.display_formal(person)
+        self.__narrator.set_subject(person)
         
         plist = person.get_media_list()
         if self.addimages and len(plist) > 0:
@@ -519,57 +612,32 @@ class DetDescendantReport(Report):
             ReportUtils.insert_image(self.database, self.doc, photo)
         
         self.doc.start_paragraph("DDR-Entry")
-        # Check birth record
-        first = ReportUtils.common_name(person, self.usecall)
         
         if not self.verbose:
-            self.write_parents(person, first)
+            self.__write_parents(person)
 
-        text = ReportUtils.born_str(self.database, person, first, self.verbose,
-                                    self.EMPTY_DATE, self.EMPTY_PLACE)
+        text = self.__narrator.get_born_string()
         if text:
-            birth_ref = person.get_birth_ref()
-            if birth_ref:
-                birth = self.database.get_event_from_handle(birth_ref.ref)
-                text = text.rstrip(". ")
-                text = text + self.endnotes(birth) + ". "
             self.doc.write_text_citation(text)
-            first = 0
 
-        text = ReportUtils.baptised_str(self.database, person, first, 
-                                        self.verbose, self.endnotes, 
-                                        self.EMPTY_DATE, self.EMPTY_PLACE)
+        text = self.__narrator.get_baptised_string()
         if text:
             self.doc.write_text_citation(text)
             
-        text = ReportUtils.christened_str(self.database, person, first, 
-                                          self.verbose, self.endnotes, 
-                                          self.EMPTY_DATE, self.EMPTY_PLACE)
+        text = self.__narrator.get_christened_string()
         if text:
             self.doc.write_text_citation(text)
     
-        span = self.calc_age(person)
-        text = ReportUtils.died_str(self.database, person, first, self.verbose,
-                                    self.EMPTY_DATE, self.EMPTY_PLACE, span)
-        if text:
-            death_ref = person.get_death_ref()
-            if death_ref:
-                death = self.database.get_event_from_handle(death_ref.ref)
-                text = text.rstrip(". ")
-                text = text + self.endnotes(death) + ". "
-            self.doc.write_text_citation(text)
-            first = 0
-
-        text = ReportUtils.buried_str(self.database, person, first, 
-                                      self.verbose, self.endnotes, 
-                                      self.EMPTY_DATE, self.EMPTY_PLACE)
+        text = self.__narrator.get_died_string(self.calcageflag)
         if text:
             self.doc.write_text_citation(text)
 
-        first = ReportUtils.common_name(person, self.usecall)
+        text = self.__narrator.get_buried_string()
+        if text:
+            self.doc.write_text_citation(text)
 
         if self.verbose:
-            self.write_parents(person, first)
+            self.__write_parents(person)
         self.write_marriage(person)
         self.doc.end_paragraph()
 
@@ -581,7 +649,8 @@ class DetDescendantReport(Report):
             for notehandle in notelist:
                 note = self.database.get_note_from_handle(notehandle)
                 self.doc.write_styled_note(note.get_styledtext(), 
-                                           note.get_format(),"DDR-Entry")
+                        note.get_format(),"DDR-Entry",
+                        contains_html= note.get_type() == NoteType.HTML_CODE)
 
         first = True
         if self.inc_names:
@@ -624,7 +693,12 @@ class DetDescendantReport(Report):
                 self.doc.start_paragraph('DDR-MoreDetails')
                 
                 text = ReportUtils.get_address_str(addr)
-                date = DateHandler.get_date(addr)
+                
+                if self.fulldate:
+                    date = DateHandler.get_date(addr)
+                else:
+                    date = addr.get_date_object().get_year()
+
                 self.doc.write_text(_('Address: '))
                 if date:
                     self.doc.write_text( '%s, ' % date )
@@ -650,22 +724,6 @@ class DetDescendantReport(Report):
                 self.doc.write_text_citation( text )
                 self.doc.end_paragraph()
 
-    def calc_age(self,ind):
-        """
-        Calulate age. 
-        
-        Returns a tuple (age,units) where units is an integer representing
-        time units:
-            no age info:    0
-            years:          1
-            months:         2
-            days:           3
-        """
-        if self.calcageflag:
-            return ReportUtils.old_calc_age(self.database, ind)
-        else:
-            return None
-
     def endnotes(self, obj):
         if not obj or not self.inc_sources:
             return ""
@@ -699,6 +757,15 @@ class DetDescendantOptions(MenuReportOptions):
         pid.set_help(_("The center person for the report"))
         menu.add_option(category_name, "pid", pid)
         
+        numbering = EnumeratedListOption(_("Numbering system"), "Henry")
+        numbering.set_items([
+                ("Henry",      _("Henry numbering")), 
+                ("d'Aboville", _("d'Aboville numbering")), 
+                ("Record (Modified Register)", 
+                               _("Record (Modified Register) numbering"))])
+        numbering.set_help(_("The numbering system to be used"))
+        menu.add_option(category_name, "numbering", numbering)
+        
         generations = NumberOption(_("Generations"), 10, 1, 100)
         generations.set_help(_("The number of generations to include in the " \
                                "report"))
@@ -709,13 +776,11 @@ class DetDescendantOptions(MenuReportOptions):
                      _("Whether to start a new page after each generation."))
         menu.add_option(category_name, "pagebbg", pagebbg)
 
-        record_num = BooleanOption(_("Use Record-style (Modified Register) " \
-                                     "numbering"),
-                                   False)
-        record_num.set_help(_("Whether to use Record-style numbering instead" \
-                              " of Henry-style."))
-        menu.add_option(category_name, "record_num", record_num)
-        
+        pageben = BooleanOption(_("Page break before end notes"),False)
+        pageben.set_help(
+                     _("Whether to start a new page before the end notes."))
+        menu.add_option(category_name,"pageben",pageben)        
+
         category_name = _("Content")
 
         usecall = BooleanOption(_("Use callname for common name"), False)
@@ -731,15 +796,15 @@ class DetDescendantOptions(MenuReportOptions):
         listc.set_help(_("Whether to list children."))
         menu.add_option(category_name, "listc", listc)
         
-        computeage = BooleanOption(_("Compute age"), True)
-        computeage.set_help(_("Whether to compute age."))
+        computeage = BooleanOption(_("Compute death age"),True)
+        computeage.set_help(_("Whether to compute a person's age at death."))
         menu.add_option(category_name, "computeage", computeage)
         
         omitda = BooleanOption(_("Omit duplicate ancestors"), True)
         omitda.set_help(_("Whether to omit duplicate ancestors."))
         menu.add_option(category_name, "omitda", omitda)
         
-        verbose = BooleanOption(_("Use Complete Sentences"), True)
+        verbose = BooleanOption(_("Use complete sentences"), True)
         verbose.set_help(
                  _("Whether to use complete sentences or succinct language."))
         menu.add_option(category_name, "verbose", verbose)
@@ -779,11 +844,28 @@ class DetDescendantOptions(MenuReportOptions):
         incsources = BooleanOption(_("Include sources"), False)
         incsources.set_help(_("Whether to include source references."))
         menu.add_option(category_name, "incsources", incsources)
+        
+        incsrcnotes = BooleanOption(_("Include sources notes"), False)
+        incsrcnotes.set_help(_("Whether to include source notes in the "
+            "Endnotes section. Only works if Include sources is selected."))
+        menu.add_option(category_name, "incsrcnotes", incsrcnotes)
 
         incmates = BooleanOption(_("Include spouses"), False)
         incmates.set_help(_("Whether to include detailed spouse information."))
         menu.add_option(category_name, "incmates", incmates)
 
+        incssign = BooleanOption(_("Include sign of succession ('+')" \
+                                   " in child-list"), True)
+        incssign.set_help(_("Whether to include a sign ('+') before the"
+                            " descendant number in the child-list to indicate"
+                            " a child has succession."))
+        menu.add_option(category_name, "incssign", incssign)
+
+        incpaths = BooleanOption(_("Include path to start-person"), False)
+        incpaths.set_help(_("Whether to include the path of descendancy " \
+                            "from the start-person to each descendant."))
+        menu.add_option(category_name, "incpaths", incpaths)
+
         category_name = _("Missing information")        
 
         repplace = BooleanOption(_("Replace missing places with ______"), False)
@@ -796,20 +878,20 @@ class DetDescendantOptions(MenuReportOptions):
 
     def make_default_style(self, default_style):
         """Make the default output style for the Detailed Ancestral Report"""
-        font = BaseDoc.FontStyle()
-        font.set(face=BaseDoc.FONT_SANS_SERIF, size=16, bold=1)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(face=FONT_SANS_SERIF, size=16, bold=1)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set_header_level(1)
         para.set_top_margin(0.25)
         para.set_bottom_margin(0.25)
-        para.set_alignment(BaseDoc.PARA_ALIGN_CENTER)
+        para.set_alignment(PARA_ALIGN_CENTER)
         para.set_description(_('The style used for the title of the page.'))
         default_style.add_paragraph_style("DDR-Title", para)
 
-        font = BaseDoc.FontStyle()
-        font.set(face=BaseDoc.FONT_SANS_SERIF, size=14, italic=1)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(face=FONT_SANS_SERIF, size=14, italic=1)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set_header_level(2)
         para.set_top_margin(0.25)
@@ -817,9 +899,9 @@ class DetDescendantOptions(MenuReportOptions):
         para.set_description(_('The style used for the generation header.'))
         default_style.add_paragraph_style("DDR-Generation", para)
 
-        font = BaseDoc.FontStyle()
-        font.set(face=BaseDoc.FONT_SANS_SERIF, size=10, italic=0, bold=1)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(face=FONT_SANS_SERIF, size=10, italic=0, bold=1)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set_left_margin(1.5)   # in centimeters
         para.set_top_margin(0.25)
@@ -827,9 +909,9 @@ class DetDescendantOptions(MenuReportOptions):
         para.set_description(_('The style used for the children list title.'))
         default_style.add_paragraph_style("DDR-ChildTitle", para)
 
-        font = BaseDoc.FontStyle()
+        font = FontStyle()
         font.set(size=10)
-        para = BaseDoc.ParagraphStyle()
+        para = ParagraphStyle()
         para.set_font(font)
         para.set(first_indent=-0.75, lmargin=2.25)
         para.set_top_margin(0.125)
@@ -837,32 +919,32 @@ class DetDescendantOptions(MenuReportOptions):
         para.set_description(_('The style used for the children list.'))
         default_style.add_paragraph_style("DDR-ChildList", para)
 
-        font = BaseDoc.FontStyle()
-        font.set(face=BaseDoc.FONT_SANS_SERIF, size=10, italic=0, bold=1)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(face=FONT_SANS_SERIF, size=10, italic=0, bold=1)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set(first_indent=0.0, lmargin=1.5)
         para.set_top_margin(0.25)
         para.set_bottom_margin(0.25)
         default_style.add_paragraph_style("DDR-NoteHeader", para)
 
-        para = BaseDoc.ParagraphStyle()
+        para = ParagraphStyle()
         para.set(lmargin=1.5)
         para.set_top_margin(0.25)
         para.set_bottom_margin(0.25)
         para.set_description(_('The basic style used for the text display.'))
         default_style.add_paragraph_style("DDR-Entry", para)
 
-        para = BaseDoc.ParagraphStyle()
+        para = ParagraphStyle()
         para.set(first_indent=-1.5, lmargin=1.5)
         para.set_top_margin(0.25)
         para.set_bottom_margin(0.25)        
         para.set_description(_('The style used for the first personal entry.'))
         default_style.add_paragraph_style("DDR-First-Entry", para)
 
-        font = BaseDoc.FontStyle()
-        font.set(size=10, face=BaseDoc.FONT_SANS_SERIF, bold=1)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(size=10, face=FONT_SANS_SERIF, bold=1)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set(first_indent=0.0, lmargin=1.5)
         para.set_top_margin(0.25)
@@ -870,9 +952,9 @@ class DetDescendantOptions(MenuReportOptions):
         para.set_description(_('The style used for the More About header.'))
         default_style.add_paragraph_style("DDR-MoreHeader", para)
 
-        font = BaseDoc.FontStyle()
-        font.set(face=BaseDoc.FONT_SERIF, size=10)
-        para = BaseDoc.ParagraphStyle()
+        font = FontStyle()
+        font.set(face=FONT_SERIF, size=10)
+        para = ParagraphStyle()
         para.set_font(font)
         para.set(first_indent=0.0, lmargin=1.5)
         para.set_top_margin(0.25)
@@ -881,24 +963,3 @@ class DetDescendantOptions(MenuReportOptions):
         default_style.add_paragraph_style("DDR-MoreDetails", para)
 
         Endnotes.add_endnote_styles(default_style)
-
-#------------------------------------------------------------------------
-#
-#
-#
-#------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_report(
-    name = 'det_descendant_report',
-    category = CATEGORY_TEXT,
-    report_class = DetDescendantReport,
-    options_class = DetDescendantOptions,
-    modes = PluginManager.REPORT_MODE_GUI | \
-            PluginManager.REPORT_MODE_BKI | \
-            PluginManager.REPORT_MODE_CLI,
-    translated_name = _("Detailed Descendant Report"),
-    status = _("Stable"),
-    description = _("Produces a detailed descendant report"),
-    author_name = "Bruce DeGrasse",
-    author_email = "bdegrasse1@attbi.com"
-    )
