@@ -19,24 +19,16 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: FindDupes.py 12842 2009-07-28 04:28:12Z pez4brian $
+# $Id: FindDupes.py 16299 2010-12-19 12:03:51Z ldnp $
 
 """Tools/Database Processing/Find Possible Duplicate People"""
 
-#-------------------------------------------------------------------------
-#
-# standard python models
-#
-#-------------------------------------------------------------------------
-import os
-
 #-------------------------------------------------------------------------
 #
 # GNOME libraries
 #
 #-------------------------------------------------------------------------
 import gtk
-from gtk import glade
 
 #-------------------------------------------------------------------------
 #
@@ -45,9 +37,9 @@ from gtk import glade
 #-------------------------------------------------------------------------
 import const
 import gen.lib
-import Utils
+from gui.utils import ProgressMeter
 import soundex
-from BasicUtils import name_displayer
+from gen.display.name import displayer as name_displayer
 from QuestionDialog import OkDialog
 import ListModel
 import Errors
@@ -55,9 +47,10 @@ from Merge import PersonCompare
 import GrampsDisplay
 import ManagedWindow
 from PluginUtils import Tool
-from gen.plug import PluginManager
-from QuestionDialog import ErrorDialog, RunDatabaseRepair
-from TransUtils import sgettext as _
+from QuestionDialog import RunDatabaseRepair
+from gen.ggettext import sgettext as _
+from glade import Glade
+
 #-------------------------------------------------------------------------
 #
 # Constants
@@ -71,6 +64,7 @@ _val2label = {
 
 WIKI_HELP_PAGE = '%s_-_Tools' % const.URL_MANUAL_PAGE
 WIKI_HELP_SEC = _('manual|Find_Possible_Duplicate_People...')
+
 #-------------------------------------------------------------------------
 #
 #
@@ -87,7 +81,7 @@ def is_initial(name):
 
 #-------------------------------------------------------------------------
 #
-#
+# The Actual tool.
 #
 #-------------------------------------------------------------------------
 class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
@@ -108,40 +102,35 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
         self.update = callback
         self.use_soundex = 1
 
-        base = os.path.dirname(__file__)
-        self.glade_file = "%s/%s" % (base,"merge.glade")
-        top = glade.XML(self.glade_file,"dialog","gramps")
+        top = Glade()
 
         # retrieve options
         threshold = self.options.handler.options_dict['threshold']
         use_soundex = self.options.handler.options_dict['soundex']
 
-        my_menu = gtk.Menu()
-        vals = _val2label.keys()
-        vals.sort()
-        for val in vals:
-            item = gtk.MenuItem(_val2label[val])
-            item.set_data("v",val)
-            item.show()
-            my_menu.append(item)
-        my_menu.set_active(vals.index(threshold))
+        my_menu = gtk.ListStore(str, object)
+        for val in sorted(_val2label):
+            my_menu.append([_val2label[val], val])
 
-        self.soundex_obj = top.get_widget("soundex")
+        self.soundex_obj = top.get_object("soundex")
         self.soundex_obj.set_active(use_soundex)
         self.soundex_obj.show()
         
-        self.menu = top.get_widget("menu")
-        self.menu.set_menu(my_menu)
+        self.menu = top.get_object("menu")
+        self.menu.set_model(my_menu)
+        self.menu.set_active(0)
 
-        window = top.get_widget('dialog')
-        self.set_window(window, top.get_widget('title'),
+        window = top.toplevel
+        window.show()
+        self.set_window(window, top.get_object('title'),
                         _('Find Possible Duplicate People'))
 
-        top.signal_autoconnect({
+        top.connect_signals({
             "on_merge_ok_clicked"   : self.on_merge_ok_clicked,
             "destroy_passed_object" : self.close,
             "on_help_clicked"       : self.on_help_clicked,
             "on_delete_merge_event" : self.close,
+            "on_delete_event"   : self.close,
             })
 
         self.show()
@@ -166,7 +155,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
             self.ancestors_of(f1.get_mother_handle(),id_list)
 
     def on_merge_ok_clicked(self, obj):
-        threshold = self.menu.get_menu().get_active().get_data("v")
+        threshold = self.menu.get_model()[self.menu.get_active()][1]
         self.use_soundex = int(self.soundex_obj.get_active())
         try:
             self.find_potentials(threshold)
@@ -182,7 +171,8 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
         if len(self.map) == 0:
             OkDialog(
                 _("No matches found"),
-                _("No potential duplicate people were found"))
+                _("No potential duplicate people were found"),
+                parent=self.window)
         else:
             try:
                 ShowMatches(self.dbstate,self.uistate,self.track,
@@ -191,20 +181,19 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
                 pass
     
     def find_potentials(self,thresh):
-        self.progress = Utils.ProgressMeter(_('Find Duplicates'),
+        self.progress = ProgressMeter(_('Find Duplicates'),
                                             _('Looking for duplicate people'))
 
         index = 0
         males = {}
         females = {}
 
-        self.person_list = self.db.get_person_handles(sort_handles=False)
-        length = len(self.person_list)
+        length = self.db.get_number_of_people()
 
         self.progress.set_pass(_('Pass 1: Building preliminary lists'),
                                length)
         
-        for p1_id in self.person_list:
+        for p1_id in self.db.iter_person_handles():
             self.progress.step()
             p1 = self.db.get_person_from_handle(p1_id)
             key = self.gen_key(p1.get_primary_name().get_surname())
@@ -222,7 +211,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
         self.progress.set_pass(_('Pass 2: Calculating potential matches'),
                                length)
 
-        for p1key in self.person_list:
+        for p1key in self.db.iter_person_handles():
             self.progress.step()
             p1 = self.db.get_person_from_handle(p1key)
 
@@ -232,9 +221,9 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
             else:
                 remaining = females[key]
 
-            index = 0
+            #index = 0
             for p2key in remaining:
-                index = index + 1
+                #index += 1
                 if p1key == p2key:
                     continue
                 p2 = self.db.get_person_from_handle(p2key)
@@ -252,8 +241,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
                     else:
                         self.map[p1key] = (p2key,chance)
 
-        self.list = self.map.keys()
-        self.list.sort()
+        self.list = sorted(self.map)
         self.length = len(self.list)
         self.progress.close()
 
@@ -303,25 +291,25 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
                                 birth2.get_date_object())
         if value == -1 :
             return -1
-        chance = chance + value
+        chance += value
 
         value = self.date_match(death1.get_date_object(),
                                 death2.get_date_object()) 
         if value == -1 :
             return -1
-        chance = chance + value
+        chance += value
 
         value = self.place_match(birth1.get_place_handle(),
                                  birth2.get_place_handle()) 
         if value == -1 :
             return -1
-        chance = chance + value
+        chance += value
 
         value = self.place_match(death1.get_place_handle(),
                                  death2.get_place_handle()) 
         if value == -1 :
             return -1
-        chance = chance + value
+        chance += value
 
         ancestors = []
         self.ancestors_of(p1.get_handle(),ancestors)
@@ -355,7 +343,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
             if value == -1:
                 return -1
 
-            chance = chance + value
+            chance += value
             
             mom1_id = f1.get_mother_handle()
             if mom1_id:
@@ -372,7 +360,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
             if value == -1:
                 return -1
             
-            chance = chance + value
+            chance += value
 
         for f1_id in p1.get_family_handle_list():
             f1 = self.db.get_family_from_handle(f1_id)
@@ -383,7 +371,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
                     father2_id = f2.get_father_handle()
                     if father1_id and father2_id:
                         if father1_id == father2_id:
-                            chance = chance + 1
+                            chance += 1
                         else:
                             father1 = self.db.get_person_from_handle(father1_id)
                             father2 = self.db.get_person_from_handle(father2_id)
@@ -391,13 +379,13 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
                             fname2 = get_name_obj(father2)
                             value = self.name_match(fname1,fname2)
                             if value != -1:
-                                chance = chance + value
+                                chance += value
                 else:
                     mother1_id = f1.get_mother_handle()
                     mother2_id = f2.get_mother_handle()
                     if mother1_id and mother2_id:
                         if mother1_id == mother2_id:
-                            chance = chance + 1
+                            chance += 1
                         else:
                             mother1 = self.db.get_person_from_handle(mother1_id)
                             mother2 = self.db.get_person_from_handle(mother2_id)
@@ -405,7 +393,7 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
                             mname2 = get_name_obj(mother2)
                             value = self.name_match(mname1,mname2)
                             if value != -1:
-                                chance = chance + value
+                                chance += value
         return chance
 
     def name_compare(self,s1,s2):
@@ -442,20 +430,20 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
         stop_date_1 = date1.get_stop_date()[0:3]
         stop_date_2 = date2.get_stop_date()[0:3]
         if date1.is_compound() and date2.is_compound():
-            if start_date_1 >= start_date_2 and start_date_1 <= stop_date_2 or \
-               start_date_2 >= start_date_1 and start_date_2 <= stop_date_1 or \
-               stop_date_1 >= start_date_2 and stop_date_1 <= stop_date_2 or \
-               stop_date_2 >= start_date_1 and stop_date_2 <= stop_date_1:
+            if start_date_2 <= start_date_1 <= stop_date_2 or \
+               start_date_1 <= start_date_2 <= stop_date_1 or \
+               start_date_2 <= stop_date_1 <= stop_date_2 or \
+               start_date_1 <= stop_date_2 <= stop_date_1:
                 return 0.5
             else:
                 return -1
         elif date2.is_compound():
-            if start_date_1 >= start_date_2 and start_date_1 <= stop_date_2:
+            if start_date_2 <= start_date_1 <= stop_date_2:
                 return 0.5
             else:
                 return -1
         else:
-            if start_date_2 >= start_date_1 and start_date_2 <= stop_date_1:
+            if start_date_1 <= start_date_2 <= stop_date_1:
                 return 0.5
             else:
                 return -1
@@ -515,36 +503,24 @@ class Merge(Tool.Tool,ManagedWindow.ManagedWindow):
         for name in list1:
             for name2 in list2:
                 if name == name2:
-                    value = value + 0.5
-                    break
-                if name[0] == name2[0] and self.name_compare(name, name2):
-                    value = value + 0.25
-                    break
-        if value == 0:
-            return -1
-        else:
-            return min(value,1)
+                    value += 0.5
+                elif name[0] == name2[0] and self.name_compare(name, name2):
+                    value += 0.25
+        return min(value,1) if value else -1
         
     def list_reduce(self,list1,list2):
         value = 0
         for name in list1:
             for name2 in list2:
                 if is_initial(name) and name[0] == name2[0]:
-                    value = value + 0.25
-                    break
-                if is_initial(name2) and name2[0] == name[0]:
-                    value = value + 0.25
-                    break
-                if name == name2:
-                    value = value + 0.5
-                    break
-                if name[0] == name2[0] and self.name_compare(name, name2):
-                    value = value + 0.25
-                    break
-        if value == 0:
-            return -1
-        else:
-            return min(value,1)
+                    value += 0.25
+                elif is_initial(name2) and name2[0] == name[0]:
+                    value += 0.25
+                elif name == name2:
+                    value += 0.5
+                elif name[0] == name2[0] and self.name_compare(name, name2):
+                    value += 0.25
+        return min(value,1) if value else -1
         
 
 class ShowMatches(ManagedWindow.ManagedWindow):
@@ -561,23 +537,26 @@ class ShowMatches(ManagedWindow.ManagedWindow):
         self.dbstate = dbstate
         self.uistate = uistate
         
-        base = os.path.dirname(__file__)
-        self.glade_file = "%s/%s" % (base,"merge.glade")
-        top = glade.XML(self.glade_file,"mergelist","gramps")
-        window = top.get_widget("mergelist")
-        self.set_window(window, top.get_widget('title'),
+        top = Glade(toplevel="mergelist")
+        window = top.toplevel
+        window.show()
+        self.set_window(window, top.get_object('title'),
                         _('Potential Merges'))
         
-        self.mlist = top.get_widget("mlist")
-        top.signal_autoconnect({
+        self.mlist = top.get_object("mlist")
+        top.connect_signals({
             "destroy_passed_object" : self.close,
             "on_do_merge_clicked"   : self.on_do_merge_clicked,
             "on_help_show_clicked"  : self.on_help_clicked,
             "on_delete_show_event"  : self.close,
             })
 
-        mtitles = [(_('Rating'),3,75),(_('First Person'),1,200),
-                   (_('Second Person'),2,200),('',-1,0)]
+        mtitles = [
+                (_('Rating'),3,75),
+                (_('First Person'),1,200),
+                (_('Second Person'),2,200),
+                ('',-1,0)
+                ]
         self.list = ListModel.ListModel(self.mlist,mtitles,
                                         event_func=self.on_do_merge_clicked)
         
@@ -593,10 +572,10 @@ class ShowMatches(ManagedWindow.ManagedWindow):
         GrampsDisplay.help(WIKI_HELP_PAGE , WIKI_HELP_SEC)    
     def redraw(self):
         list = []
-        for p1key in self.map.keys():
+        for p1key, p1data in self.map.iteritems():
             if p1key in self.dellist:
                 continue
-            (p2key,c) = self.map[p1key]
+            (p2key,c) = p1data
             if p1key == p2key:
                 continue
             list.append((c,p1key,p2key))
@@ -626,8 +605,8 @@ class ShowMatches(ManagedWindow.ManagedWindow):
 
     def on_update(self):
         self.dellist[self.p2] = self.p1
-        for key in self.dellist.keys():
-            if self.dellist[key] == self.p2:
+        for key, data in self.dellist.iteritems():
+            if data == self.p2:
                 self.dellist[key] = self.p1
         self.update()
         self.redraw()
@@ -687,23 +666,3 @@ class MergeOptions(Tool.ToolOptions):
             'threshold' : ("=num","Threshold for tolerance",
                            "Floating point number")
             }
-
-#-------------------------------------------------------------------------
-#
-#
-#
-#-------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_tool(
-    name = 'dupfind',
-    category = Tool.TOOL_DBPROC,
-    tool_class = Merge,
-    options_class = MergeOptions,
-    modes = PluginManager.TOOL_MODE_GUI,
-    translated_name = _("Find Possible Duplicate People"),
-    status = _("Stable"),
-    author_name = "Donald N. Allingham",
-    author_email = "don@gramps-project.org",
-    description = _("Searches the entire database, looking for "
-                    "individual entries that may represent the same person.")
-    )
