@@ -20,7 +20,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: RemoveUnused.py 14104 2010-01-21 18:42:53Z gbritton $
+# $Id: RemoveUnused.py 15609 2010-06-30 07:37:55Z ldnp $
 
 "Find unused objects and remove with the user's permission."
 
@@ -421,11 +421,9 @@ class RemoveUnused(Tool.Tool, ManagedWindow.ManagedWindow, UpdateCallback):
         text = note.get()
 
         # convert whitespace to a single space
-        text = " ".join(text.split())
+        text = u" ".join(text.split())
 
         # if the note is too long, truncate it
-        # but first set type of text to unicode, otherwise the sliceing might go wrong.
-        text = unicode(text)
         if len(text) > 80:
             text = text[:80] + "..."
 
