@@ -19,7 +19,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: Verify.py 13410 2009-10-25 16:51:15Z bmcage $
+# $Id: Verify.py 16727 2011-02-28 13:47:53Z dsblank $
 
 """
 A plugin to verify the data against user-adjusted tests.
@@ -45,7 +45,6 @@ import Errors
 #
 #------------------------------------------------------------------------
 import gtk
-from gtk import glade
 import gobject
 
 #------------------------------------------------------------------------
@@ -55,13 +54,15 @@ import gobject
 #------------------------------------------------------------------------
 import const
 import gen.lib
+from gui.editors import EditPerson, EditFamily
 import Utils
 import GrampsDisplay
 from ManagedWindow import ManagedWindow
-from BasicUtils import UpdateCallback
+from gen.updatecallback import UpdateCallback
 from PluginUtils import Tool
-from gen.plug import PluginManager
-from TransUtils import sgettext as _
+from gen.ggettext import sgettext as _
+from glade import Glade
+
 #-------------------------------------------------------------------------
 #
 # Constants
@@ -117,28 +118,37 @@ def get_date_from_event_handle(db,event_handle):
     if not event_handle:
         return 0
     event =  find_event(db,event_handle)
-    date_obj = event.get_date_object()
-    if date_obj.get_day() == 0 or date_obj.get_month() == 0:
+    if event:
+        date_obj = event.get_date_object()
+        if date_obj.get_day() == 0 or date_obj.get_month() == 0:
+            return 0
+        return date_obj.get_sort_value()
+    else:
         return 0
-    return date_obj.get_sort_value()
 
 def get_date_from_event_type(db,person,event_type):
     if not person:
         return 0
     for event_ref in person.get_event_ref_list():
         event = find_event(db,event_ref.ref)
-        if event.get_type() == event_type:
-            date_obj = event.get_date_object()
-            if date_obj.get_day() == 0 or date_obj.get_month() == 0:
-                return 0
-            return date_obj.get_sort_value()
+        if event:
+            if event.get_type() == event_type:
+                date_obj = event.get_date_object()
+                if date_obj.get_day() == 0 or date_obj.get_month() == 0:
+                    return 0
+                return date_obj.get_sort_value()
     return 0
 
 def get_bapt_date(db,person):
     return get_date_from_event_type(db,person,gen.lib.EventType.BAPTISM)
 
 def get_bury_date(db,person):
-    return get_date_from_event_type(db,person,gen.lib.EventType.BURIAL)
+    # check role on burial event
+    for event_ref in person.get_event_ref_list():
+        event = find_event(db, event_ref.ref)
+        if event and event.get_type() == gen.lib.EventType.BURIAL and \
+        event_ref.get_role() == gen.lib.EventRoleType.PRIMARY:
+            return get_date_from_event_type(db,person,gen.lib.EventType.BURIAL)
 
 def get_birth_date(db,person,estimate=False):
     if not person:
@@ -223,11 +233,11 @@ def get_marriage_date(db,family):
 #-------------------------------------------------------------------------
 class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
 
-    def __init__(self, dbstate, uistate, options_class, name,callback=None):
+    def __init__(self, dbstate, uistate, options_class, name, callback=None):
         self.label = _('Database Verify tool')
         Tool.Tool.__init__(self, dbstate, options_class, name)
-        ManagedWindow.__init__(self,uistate,[],self.__class__)
-        UpdateCallback.__init__(self,self.uistate.pulse_progressbar)
+        ManagedWindow.__init__(self, uistate,[], self.__class__)
+        UpdateCallback.__init__(self, self.uistate.pulse_progressbar)
 
         self.dbstate = dbstate
         if uistate:
@@ -236,11 +246,11 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
             self.add_results = self.add_results_cli
             self.run_tool(cli=True)
 
-    def add_results_cli(self,results):
+    def add_results_cli(self, results):
         # print data for the user, no GUI
-        (msg,gramps_id, name,the_type,rule_id,severity, handle) = results
+        (msg,gramps_id, name, the_type, rule_id, severity, handle) = results
         if severity == Rule.WARNING:
-            print "W: %s, %s: %s, %s" % (msg,the_type,gramps_id, name)
+            print "W: %s, %s: %s, %s" % (msg,the_type, gramps_id, name)
         elif severity == Rule.ERROR:
             print "E: %s, %s: %s, %s" % (msg,the_type,gramps_id, name)
         else:
@@ -248,56 +258,28 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
 
     def init_gui(self):
         # Draw dialog and make it handle everything
-        base = os.path.dirname(__file__)
-        self.glade_file = base + os.sep + "verify.glade"
         self.vr = None 
-
-        self.top = glade.XML(self.glade_file,"verify_settings","gramps")
-        self.top.signal_autoconnect({
+        self.top = Glade()
+        self.top.connect_signals({
             "destroy_passed_object" : self.close,
             "on_help_clicked"       : self.on_help_clicked,
-            "on_verify_ok_clicked"  : self.on_apply_clicked
+            "on_verify_ok_clicked"  : self.on_apply_clicked,
+            "on_delete_event"       : self.close,
         })
 
-        window = self.top.get_widget('verify_settings')
-        self.set_window(window,self.top.get_widget('title'),self.label)
+        window = self.top.toplevel
+        self.set_window(window,self.top.get_object('title'),self.label)
 
-        self.top.get_widget("oldage").set_value(
-            self.options.handler.options_dict['oldage'])
-        self.top.get_widget("hwdif").set_value(
-            self.options.handler.options_dict['hwdif'])
-        self.top.get_widget("cspace").set_value(
-            self.options.handler.options_dict['cspace'])
-        self.top.get_widget("cbspan").set_value(
-            self.options.handler.options_dict['cbspan'])
-        self.top.get_widget("yngmar").set_value(
-            self.options.handler.options_dict['yngmar'])
-        self.top.get_widget("oldmar").set_value(
-            self.options.handler.options_dict['oldmar'])
-        self.top.get_widget("oldmom").set_value(
-            self.options.handler.options_dict['oldmom'])
-        self.top.get_widget("yngmom").set_value(
-            self.options.handler.options_dict['yngmom'])
-        self.top.get_widget("olddad").set_value(
-            self.options.handler.options_dict['olddad'])
-        self.top.get_widget("yngdad").set_value(
-            self.options.handler.options_dict['yngdad'])
-        self.top.get_widget("wedder").set_value(
-            self.options.handler.options_dict['wedder'])
-        self.top.get_widget("mxchildmom").set_value(
-            self.options.handler.options_dict['mxchildmom'])
-        self.top.get_widget("mxchilddad").set_value(
-            self.options.handler.options_dict['mxchilddad'])
-        self.top.get_widget("lngwdw").set_value(
-            self.options.handler.options_dict['lngwdw'])
-        self.top.get_widget("oldunm").set_value(
-            self.options.handler.options_dict['oldunm'])
-        self.top.get_widget("estimate").set_active(
-            self.options.handler.options_dict['estimate_age'])
-        self.top.get_widget("invdate").set_active(
-            self.options.handler.options_dict['invdate'])
-                                                          
-        self.show()
+        for option in self.options.handler.options_dict:
+            if option in ['estimate_age', 'invdate']:
+                self.top.get_object(option).set_active(
+                    self.options.handler.options_dict[option]
+                    )
+            else:
+                self.top.get_object(option).set_value(
+                    self.options.handler.options_dict[option]
+                    )
+        self.window.show()
 
     def build_menu_names(self, obj):
         return (_("Tool settings"),self.label)
@@ -307,41 +289,14 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
         GrampsDisplay.help(webpage=WIKI_HELP_PAGE, section=WIKI_HELP_SEC)
 
     def on_apply_clicked(self, obj):
-        self.options.handler.options_dict['oldage'] = self.top.get_widget(
-            "oldage").get_value_as_int()
-        self.options.handler.options_dict['hwdif']  = self.top.get_widget(
-            "hwdif").get_value_as_int()
-        self.options.handler.options_dict['cspace'] = self.top.get_widget(
-            "cspace").get_value_as_int()
-        self.options.handler.options_dict['cbspan'] = self.top.get_widget(
-            "cbspan").get_value_as_int()
-        self.options.handler.options_dict['yngmar'] = self.top.get_widget(
-            "yngmar").get_value_as_int()
-        self.options.handler.options_dict['oldmar'] = self.top.get_widget(
-            "oldmar").get_value_as_int()
-        self.options.handler.options_dict['oldmom'] = self.top.get_widget(
-            "oldmom").get_value_as_int()
-        self.options.handler.options_dict['yngmom'] = self.top.get_widget(
-            "yngmom").get_value_as_int()
-        self.options.handler.options_dict['olddad'] = self.top.get_widget(
-            "olddad").get_value_as_int()
-        self.options.handler.options_dict['yngdad'] = self.top.get_widget(
-            "yngdad").get_value_as_int()
-        self.options.handler.options_dict['wedder'] = self.top.get_widget(
-            "wedder").get_value_as_int()
-        self.options.handler.options_dict['mxchildmom'] = self.top.get_widget(
-            "mxchildmom").get_value_as_int()
-        self.options.handler.options_dict['mxchilddad'] = self.top.get_widget(
-            "mxchilddad").get_value_as_int()
-        self.options.handler.options_dict['lngwdw'] = self.top.get_widget(
-            "lngwdw").get_value_as_int()
-        self.options.handler.options_dict['oldunm'] = self.top.get_widget(
-            "oldunm").get_value_as_int()
+        for option in self.options.handler.options_dict:
+            if option in ['estimate_age', 'invdate']:
+                self.options.handler.options_dict[option] = \
+                self.top.get_object(option).get_active()
+            else:
+                self.options.handler.options_dict[option] = \
+                    self.top.get_object(option).get_value_as_int()
 
-        self.options.handler.options_dict['estimate_age'] = \
-                      self.top.get_widget("estimate").get_active()
-        self.options.handler.options_dict['invdate'] = \
-                      self.top.get_widget("invdate").get_active()
         try:
             self.vr = VerifyResults(self.dbstate, self.uistate, self.track)
             self.add_results = self.vr.add_results
@@ -373,24 +328,11 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
 
     def run_tool(self,cli=False):
 
-        person_handles = self.db.get_person_handles(sort_handles=False)
-        oldage = self.options.handler.options_dict['oldage']
-        hwdif = self.options.handler.options_dict['hwdif']
-        cspace = self.options.handler.options_dict['cspace']
-        cbspan = self.options.handler.options_dict['cbspan']
-        yngmar = self.options.handler.options_dict['yngmar']
-        oldmar = self.options.handler.options_dict['oldmar']
-        oldmom = self.options.handler.options_dict['oldmom']
-        yngmom = self.options.handler.options_dict['yngmom']
-        olddad = self.options.handler.options_dict['olddad']
-        yngdad = self.options.handler.options_dict['yngdad']
-        wedder = self.options.handler.options_dict['wedder']
-        mxchildmom = self.options.handler.options_dict['mxchildmom']
-        mxchilddad = self.options.handler.options_dict['mxchilddad']
-        lngwdw = self.options.handler.options_dict['lngwdw']
-        oldunm = self.options.handler.options_dict['oldunm']
-        estimate_age = self.options.handler.options_dict['estimate_age']
-        invdate = self.options.handler.options_dict['invdate']
+        person_handles = self.db.iter_person_handles()
+        
+        for option, value in \
+          self.options.handler.options_dict.iteritems():
+            exec '%s = %s' % (option, value)
 
         self.vr.real_model.clear()
 
@@ -427,7 +369,7 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
                 self.update()
 
         # Family-based rules
-        for family_handle in self.db.get_family_handles():
+        for family_handle in self.db.iter_family_handles():
             family = find_family(self.db,family_handle)
 
             rule_list = [
@@ -446,6 +388,7 @@ class Verify(Tool.Tool, ManagedWindow, UpdateCallback):
                 DeadParent(self.db,family,estimate_age),
                 LargeChildrenSpan(self.db,family,cbspan,estimate_age),
                 LargeChildrenAgeDiff(self.db,family,cspace,estimate_age),
+                MarriedRelation(self.db,family),
                 ]
 
             for rule in rule_list:
@@ -479,33 +422,31 @@ class VerifyResults(ManagedWindow):
         ManagedWindow.__init__(self,uistate,track,self.__class__)
 
         self.dbstate = dbstate
-
-        base = os.path.dirname(__file__)
-        self.glade_file = base + os.sep + "verify.glade"
-
-        self.top = glade.XML(self.glade_file,"verify_result","gramps")
-        window = self.top.get_widget("verify_result")
-        self.set_window(window,self.top.get_widget('title'),self.title)
+        self.top = Glade(toplevel="verify_result")
+        window = self.top.toplevel
+        self.set_window(window,self.top.get_object('title2'),self.title)
     
-        self.top.signal_autoconnect({
+        self.top.connect_signals({
             "destroy_passed_object"  : self.close,
+            "on_verify_ok_clicked"   : self.__dummy,
+            "on_help_clicked"        : self.__dummy,
             })
 
-        self.warn_tree = self.top.get_widget('warn_tree')
+        self.warn_tree = self.top.get_object('warn_tree')
         self.warn_tree.connect('button_press_event', self.double_click)
 
         self.selection = self.warn_tree.get_selection()
         
-        self.hide_button = self.top.get_widget('hide_button')
+        self.hide_button = self.top.get_object('hide_button')
         self.hide_button.connect('toggled',self.hide_toggled)
 
-        self.mark_button = self.top.get_widget('mark_all')
+        self.mark_button = self.top.get_object('mark_all')
         self.mark_button.connect('clicked',self.mark_clicked)
 
-        self.unmark_button = self.top.get_widget('unmark_all')
+        self.unmark_button = self.top.get_object('unmark_all')
         self.unmark_button.connect('clicked',self.unmark_clicked)
 
-        self.invert_button = self.top.get_widget('invert_all')
+        self.invert_button = self.top.get_object('invert_all')
         self.invert_button.connect('clicked',self.invert_clicked)
 
         self.real_model = gtk.ListStore(gobject.TYPE_BOOLEAN, 
@@ -559,9 +500,15 @@ class VerifyResults(ManagedWindow):
         name_column.set_sort_column_id(VerifyResults.OBJ_NAME_COL)
         self.warn_tree.append_column(name_column)
        
-        self.window.show_all()
+        self.window.show()
         self.window_shown = False
 
+    def __dummy(self, obj):
+        """dummy callback, needed because VerifyResults is in same glade file
+        as Verify, so callbacks of Verify must be defined.
+        """
+        pass
+
     def load_ignored(self,db_filename):
         md5sum = md5(db_filename)
         self.ignores_filename = os.path.join(
@@ -632,7 +579,7 @@ class VerifyResults(ManagedWindow):
             button.set_label(_("_Hide marked"))
         
     def selection_toggled(self,cell,path_string):
-        sort_path = tuple([int (i) for i in path_string.split(':')])
+        sort_path = tuple(map(int, path_string.split(':')))
         filt_path = self.sort_model.convert_path_to_child_path(sort_path)
         real_path = self.filt_model.convert_path_to_child_path(filt_path)
         row = self.real_model[real_path]
@@ -677,14 +624,12 @@ class VerifyResults(ManagedWindow):
             handle = row[VerifyResults.OBJ_HANDLE_COL]
             if the_type == 'Person':
                 try:
-                    from Editors import EditPerson
                     person = self.dbstate.db.get_person_from_handle(handle)
                     EditPerson(self.dbstate, self.uistate, [], person)
                 except Errors.WindowActiveError:
                     pass
             elif the_type == 'Family':
                 try:
-                    from Editors import EditFamily
                     family = self.dbstate.db.get_family_from_handle(handle)
                     EditFamily(self.dbstate, self.uistate, [], family)
                 except Errors.WindowActiveError:
@@ -712,7 +657,7 @@ class VerifyResults(ManagedWindow):
                                     True, not ignore])
         
         if not self.window_shown:
-            self.show()
+            self.window.show()
             self.window_shown = True
 
     def build_menu_names(self, obj):
@@ -1569,22 +1514,19 @@ class InvalidDeathDate(PersonRule):
 
     def get_message(self):
         return _("Invalid death date")
+        
+class MarriedRelation(FamilyRule):
+    ID = 31
+    SEVERITY = Rule.WARNING
+    def __init__(self,db, obj):
+        FamilyRule.__init__(self,db, obj)
 
-#-------------------------------------------------------------------------
-#
-#
-#
-#-------------------------------------------------------------------------
-pmgr = PluginManager.get_instance()
-pmgr.register_tool(
-    name = 'verify',
-    category = Tool.TOOL_UTILS,
-    tool_class = Verify,
-    options_class = VerifyOptions,
-    modes = PluginManager.TOOL_MODE_GUI | PluginManager.TOOL_MODE_CLI,
-    translated_name = _("Verify the Data"),
-    status=(_("Stable")),
-    author_name = "Alex Roitman",
-    author_email = "shura@gramps-project.org",
-    description = _("Verifies the data against user-defined tests")
-    )
+    def broken(self):          
+        marr_date = get_marriage_date(self.db,self.obj)
+        marr_date_ok = marr_date > 0
+        married = self.obj.get_relationship() == gen.lib.FamilyRelType.MARRIED
+        if not married and marr_date_ok:
+            return self.get_message
+
+    def get_message(self):
+        return _("Marriage date but not married")
