@@ -26,7 +26,7 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
 
-# $Id: geoview.py 14895 2010-03-21 16:21:07Z noirauds $
+# $Id: geoview.py 16824 2011-03-14 09:50:39Z noirauds $
 
 """
 Geo View
@@ -106,7 +106,7 @@ from htmlrenderer import HtmlView
 #
 #-------------------------------------------------------------------------
 #covert to unicode for better hadnling of path in Windows
-GEOVIEW_SUBPATH = unicode(Utils.get_empty_tempdir('geoview'), sys.getfilesystemencoding())
+GEOVIEW_SUBPATH = Utils.get_empty_tempdir('geoview')
 NB_MARKERS_PER_PAGE = 200
 
 #-------------------------------------------------------------------------
@@ -612,14 +612,14 @@ class GeoView(HtmlView):
         box.pack_start(self.savezoom, False, False, padding=2)
         box.pack_start(self.provider, False, False, padding=2)
         box.show_all()
-        self.title = gtk.Label('')
-        self.title.set_single_line_mode(True)
+        self.title_name = gtk.Label('')
+        self.title_name.set_single_line_mode(True)
         font = pango.FontDescription("monospace")
         font.set_weight(pango.WEIGHT_HEAVY)
         font.set_style(pango.STYLE_NORMAL)
-        self.title.modify_font(font)
+        self.title_name.modify_font(font)
         self.box1.pack_start(box, False, False, padding=2)
-        self.box1.pack_start(self.title, False, False, padding=2)
+        self.box1.pack_start(self.title_name, False, False, padding=2)
         self.box1.show_all()
         if self.displaytype == "places":
             self.build_filters_container(self.filter, PlaceSidebarFilter)
@@ -996,7 +996,8 @@ class GeoView(HtmlView):
                 elif year != "no":
                     self.last_selected_year = year
                     self._call_js_selectmarkers(year)
-        self.renderer.execute_script("javascript:addcrosshair('%d','%s')" % 
+        if self.javascript_ready:
+            self.renderer.execute_script("javascript:addcrosshair('%d','%s')" %
                       (self._config.get("preferences.crosshair"),
                        self.crosspath))
 
@@ -1227,12 +1228,16 @@ class GeoView(HtmlView):
         """
         Change the lock/unlock icon depending on the button state.
         """
+        child = self.savezoom.child
+        if child:
+            self.savezoom.remove(child)
         image = gtk.Image()
         if config.get('geoview.lock'):
             image.set_from_stock('geo-fixed-zoom', gtk.ICON_SIZE_MENU)
         else:
             image.set_from_stock('geo-free-zoom', gtk.ICON_SIZE_MENU)
-        self.savezoom.set_image(image)
+        image.show()
+        self.savezoom.add(image)
 
     def _save_zoom(self, button): # pylint: disable-msg=W0613
         """
@@ -1268,12 +1273,16 @@ class GeoView(HtmlView):
         """
         Change the provider icon depending on the button state.
         """
+        child = self.provider.child
+        if child:
+            self.provider.remove(child)
         image = gtk.Image()
         if self._config.get('preferences.alternate-provider'):
             image.set_from_stock('gramps-geo-altmap', gtk.ICON_SIZE_MENU)
         else:
             image.set_from_stock('gramps-geo-mainmap', gtk.ICON_SIZE_MENU)
-        self.provider.set_image(image)
+        image.show()
+        self.provider.add(image)
 
     def _createpageplaceswithoutcoord(self):
         """
@@ -1667,7 +1676,7 @@ class GeoView(HtmlView):
         """
         Show the current title map in the gtk label above the map.
         """
-        self.title.set_text(title)
+        self.title_name.set_text(title)
 
     def _create_markers(self, formatype, firstm, lastm):
         """
